@@ -22,7 +22,6 @@
 #include <gdk/gdk.h>
 #include "xfcolor.h"
 
-void
-open_colorselect(XFCE_palette *p, int color_index);
+void open_colorselect (XFCE_palette * p, int color_index);
 
 #endif
