@@ -2,6 +2,8 @@
 #  include <config.h>
 #endif
 
+#ifndef __CONFIGURE_H__
+#define __CONFIGURE_H__
 /***************************************************************************
  * Please translate the strings into the language which you use for 
  * your pop-up menus.
@@ -22,9 +24,10 @@
 #define CLOSE_STRING4 "quit"
 
 /* #ifdef __alpha */
-#if defined(__alpha) && !defined(linux)
+#if defined(__alpha) && !(defined(linux) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)) && !defined(__DECC)
 #define NEEDS_ALPHA_HEADER
 #undef BROKEN_SUN_HEADERS
 #endif /* (__alpha) */
 
+#endif
 /* end of configure.h */
