@@ -19,7 +19,6 @@
 #ifndef __FILESELECT_H__
 #define __FILESELECT_H__
 
-char *
-open_fileselect (char *);
+char *open_fileselect (char *);
 
 #endif
