@@ -21,11 +21,14 @@
 #ifndef __MY_STRING_H__
 #define __MY_STRING_H__
 
+char *my_memmove (char *, char *, int);
 char *skiphead (char *);
 char *skiptail (char *);
 char *nextl (char *s);
 char *cleanup (char *);
 char my_casecmp (char, char);
+char my_strncmp (char *, char *, int);
+char my_strcmp (char *, char *);
 char my_strncasecmp (char *, char *, int);
 char my_strcasecmp (char *, char *);
 char *tohex (char *, short int);
