@@ -24,6 +24,6 @@
 extern void sendinfo (int *, char *, unsigned long);
 extern int readpacket (int, unsigned long *, unsigned long **);
 
-int fd[2];
+extern int fd_internal_pipe[2];
 
 #endif
