@@ -5,6 +5,10 @@
 #include <sys/select.h>
 #endif
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 /**************************************************************************
  * 
  * Sleep for n microseconds
