@@ -18,11 +18,14 @@
 
 #include <sys/stat.h>
 #include <unistd.h>
+#include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <signal.h>
 #include <stdarg.h>
+#include <math.h>
+#include <glib.h>
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -51,106 +54,117 @@
 #include <gdk_imlib.h>
 #endif
 
+#define empty_cursor_width 16
+#define empty_cursor_height 16
+
 static char *question[] = {
-"32 32 5 1",
-". c none",
-"# c #183c59",
-"a c #bebebe",
-"b c #ffffff",
-"c c #0000ff",
-"................................",
-"................................",
-"................................",
-"................................",
-"................................",
-".........##########.............",
-"........##aaaaaaaaab............",
-".......##aaaaccccaaab...........",
-"......##aaaccccccccaab..........",
-"......#aaaccccccccccaab.........",
-"......#aaaccccccccccaab.........",
-"......#aaacccaaaacccaab.........",
-"......#aaacccaaaacccaaab........",
-"......#aaacccaaaccccaaaab.......",
-"......#aaaaaaaacccccaaabb.......",
-"......#aaaaaaacccccaaab.........",
-"......##aaaaacccccaaabb.........",
-".......##aaaaccccaaaab..........",
-"........##aaacccaaaaab..........",
-".........##aacccaaaaab..........",
-"..........#aaaaaaaaaab..........",
-"..........#aaaaaaabbb...........",
-"..........#aacccaab.............",
-"..........#aacccaab.............",
-"..........#aacccaab.............",
-".........##aaaaaaab.............",
-".........#bbbbbbbbbb............",
-"................................",
-"................................",
-"................................",
-"................................",
-"................................"
+  "32 32 5 1",
+  ". c none",
+  "# c #183c59",
+  "a c #bebebe",
+  "b c #ffffff",
+  "c c #0000ff",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  ".........##########.............",
+  "........##aaaaaaaaab............",
+  ".......##aaaaccccaaab...........",
+  "......##aaaccccccccaab..........",
+  "......#aaaccccccccccaab.........",
+  "......#aaaccccccccccaab.........",
+  "......#aaacccaaaacccaab.........",
+  "......#aaacccaaaacccaaab........",
+  "......#aaacccaaaccccaaaab.......",
+  "......#aaaaaaaacccccaaabb.......",
+  "......#aaaaaaacccccaaab.........",
+  "......##aaaaacccccaaabb.........",
+  ".......##aaaaccccaaaab..........",
+  "........##aaacccaaaaab..........",
+  ".........##aacccaaaaab..........",
+  "..........#aaaaaaaaaab..........",
+  "..........#aaaaaaabbb...........",
+  "..........#aacccaab.............",
+  "..........#aacccaab.............",
+  "..........#aacccaab.............",
+  ".........##aaaaaaab.............",
+  ".........#bbbbbbbbbb............",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  "................................"
 };
 
 static char *warning[] = {
-"32 32 5 1",
-". c none",
-"# c #183c59",
-"a c #bebebe",
-"b c #ffffff",
-"c c #ff0000",
-"................................",
-"................................",
-"................................",
-"................................",
-"................................",
-".........##########.............",
-"........##aaaaaaaaab............",
-".......##aaaaacaaaaab...........",
-"......##aaaaacccaaaaab..........",
-"......#aaaaacccccaaaaab.........",
-"......#aaaaacccccaaaaab.........",
-"......#aaaaacccccaaa#ab.........",
-"......#aaaaacccccaa##aab........",
-"......#aaaaacccccaaa#aaab.......",
-"......#aaaaaacccaaaaaaabb.......",
-"......#aaaaaacccaaaaaab.........",
-"......##aaaaacccaaaaabb.........",
-".......##aaaacccaaaaab..........",
-"........##aaacccaaaaab..........",
-".........##aacccaaaaab..........",
-"..........#aaaaaaaaaab..........",
-"..........#aaaaaaabbb...........",
-"..........#aacccaab.............",
-"..........#aacccaab.............",
-"..........#aacccaab.............",
-".........##aaaaaaab.............",
-".........#bbbbbbbbbb............",
-"................................",
-"................................",
-"................................",
-"................................",
-"................................"
+  "32 32 5 1",
+  ". c none",
+  "# c #183c59",
+  "a c #bebebe",
+  "b c #ffffff",
+  "c c #ff0000",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  ".........##########.............",
+  "........##aaaaaaaaab............",
+  ".......##aaaaacaaaaab...........",
+  "......##aaaaacccaaaaab..........",
+  "......#aaaaacccccaaaaab.........",
+  "......#aaaaacccccaaaaab.........",
+  "......#aaaaacccccaaa#ab.........",
+  "......#aaaaacccccaa##aab........",
+  "......#aaaaacccccaaa#aaab.......",
+  "......#aaaaaacccaaaaaaabb.......",
+  "......#aaaaaacccaaaaaab.........",
+  "......##aaaaacccaaaaabb.........",
+  ".......##aaaacccaaaaab..........",
+  "........##aaacccaaaaab..........",
+  ".........##aacccaaaaab..........",
+  "..........#aaaaaaaaaab..........",
+  "..........#aaaaaaabbb...........",
+  "..........#aacccaab.............",
+  "..........#aacccaab.............",
+  "..........#aacccaab.............",
+  ".........##aaaaaaab.............",
+  ".........#bbbbbbbbbb............",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  "................................"
 };
 
+static unsigned char empty_cursor_bits[] = {
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
+static unsigned char empty_cursormask_bits[] = {
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
+
 GtkWidget *
 get_widget (GtkWidget * widget, gchar * widget_name)
 {
   GtkWidget *parent, *found_widget;
 
   for (;;)
-    {
-      if (GTK_IS_MENU (widget))
-	parent = gtk_menu_get_attach_widget (GTK_MENU (widget));
-      else
-	parent = widget->parent;
-      if (parent == NULL)
-	break;
-      widget = parent;
-    }
+  {
+    if (GTK_IS_MENU (widget))
+      parent = gtk_menu_get_attach_widget (GTK_MENU (widget));
+    else
+      parent = widget->parent;
+    if (parent == NULL)
+      break;
+    widget = parent;
+  }
 
-  found_widget = (GtkWidget *) gtk_object_get_data (GTK_OBJECT (widget),
-						    widget_name);
+  found_widget = (GtkWidget *) gtk_object_get_data (GTK_OBJECT (widget), widget_name);
   if (!found_widget)
     g_warning ("Widget not found: %s", widget_name);
   return found_widget;
@@ -163,14 +177,11 @@ set_notebook_tab (GtkWidget * notebook, gint page_num, GtkWidget * widget)
   GtkNotebookPage *page;
   GtkWidget *notebook_page;
 
-  page =
-    (GtkNotebookPage *) g_list_nth (GTK_NOTEBOOK (notebook)->children,
-				    page_num)->data;
+  page = (GtkNotebookPage *) g_list_nth (GTK_NOTEBOOK (notebook)->children, page_num)->data;
   notebook_page = page->child;
   gtk_widget_ref (notebook_page);
   gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), page_num);
-  gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), notebook_page,
-			    widget, page_num);
+  gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), notebook_page, widget, page_num);
   gtk_widget_unref (notebook_page);
 }
 
@@ -187,8 +198,7 @@ lock_size (GtkWidget * toplevel)
   geometry_mask = GDK_HINT_MAX_SIZE | GDK_HINT_MIN_SIZE | GDK_HINT_BASE_SIZE;
   geometry.min_width = geometry.max_width = geometry.base_width = uwidth;
   geometry.min_height = geometry.max_height = geometry.base_height = uheight;
-  gtk_window_set_geometry_hints (GTK_WINDOW (toplevel), toplevel, &geometry,
-				 geometry_mask);
+  gtk_window_set_geometry_hints (GTK_WINDOW (toplevel), toplevel, &geometry, geometry_mask);
 }
 
 void
@@ -200,7 +210,7 @@ set_icon (GtkWidget * toplevel, gchar * name, gchar ** data)
   if (!GTK_WIDGET_REALIZED (toplevel))
     gtk_widget_realize (toplevel);
 
-  icon = MyCreateGdkPixmapFromData (data, toplevel,&mask, FALSE);
+  icon = MyCreateGdkPixmapFromData (data, toplevel, &mask, FALSE);
   gdk_window_set_icon (toplevel->window, NULL, icon, mask);
   gdk_window_set_icon_name (toplevel->window, name);
 }
@@ -217,12 +227,10 @@ on_ok_show_message (GtkWidget * twidget, gpointer data)
 }
 
 static gboolean
-delete_event_show_message (GtkWidget * widget,
-                           GdkEvent  *event,
-                           gpointer data)
+delete_event_show_message (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
   gtk_main_quit ();
-  return(TRUE);
+  return (TRUE);
 }
 
 void
@@ -242,8 +250,7 @@ my_show_message (gchar * message)
 
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_container_border_width (GTK_CONTAINER (hbox), 5);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_show_message)->vbox), hbox,
-		      TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_show_message)->vbox), hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
   pixmap = MyCreateGdkPixmapFromData (warning, dialog_show_message, &mask, FALSE);
@@ -260,18 +267,13 @@ my_show_message (gchar * message)
 
   button = gtk_button_new_with_label (_("OK"));
   gtk_widget_set_usize (button, 80, -1);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_show_message)->action_area),
-		      button, FALSE, FALSE, 14);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_show_message)->action_area), button, FALSE, FALSE, 14);
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (on_ok_show_message),
-		      GTK_OBJECT (dialog_show_message));
-  gtk_signal_connect (GTK_OBJECT (dialog_show_message), "delete_event",
-		      GTK_SIGNAL_FUNC (delete_event_show_message), 
-                      GTK_OBJECT (dialog_show_message));
+  gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC (on_ok_show_message), GTK_OBJECT (dialog_show_message));
+  gtk_signal_connect (GTK_OBJECT (dialog_show_message), "delete_event", GTK_SIGNAL_FUNC (delete_event_show_message), GTK_OBJECT (dialog_show_message));
   gtk_window_set_modal (GTK_WINDOW (dialog_show_message), TRUE);
   gtk_window_set_title (GTK_WINDOW (dialog_show_message), _("Message"));
   gtk_widget_show (dialog_show_message);
@@ -294,12 +296,7 @@ my_show_message (gchar * message)
      gtk_widget_show (dialog);
  */
 GtkWidget *
-my_show_dialog (gchar * message,
-		gint nbuttons,
-		gchar * buttons[],
-		gint default_button,
-		GtkSignalFunc signal_handlers[], 
-                gpointer data)
+my_show_dialog (gchar * message, gint nbuttons, gchar * buttons[], gint default_button, GtkSignalFunc signal_handlers[], gpointer data)
 {
   GtkWidget *dialog, *hbox, *label, *button, *bbox, *pixmapwid;
   GdkPixmap *pixmap = NULL;
@@ -317,8 +314,7 @@ my_show_dialog (gchar * message,
 
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_container_border_width (GTK_CONTAINER (hbox), 5);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-		      TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
   pixmap = MyCreateGdkPixmapFromData (question, dialog, &mask, FALSE);
@@ -337,77 +333,66 @@ my_show_dialog (gchar * message,
   bbox = gtk_hbutton_box_new ();
   gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (bbox), 10);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), bbox,
-		      FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->action_area), bbox, FALSE, TRUE, 0);
   gtk_widget_show (bbox);
 
   for (i = 0; i < nbuttons; i++)
-    {
-      button = gtk_button_new_with_label (_(buttons[i]));
-      gtk_container_add (GTK_CONTAINER (bbox), button);
-      GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-      if (i == default_button - 1)
-	gtk_widget_grab_default (button);
-      gtk_widget_show (button);
+  {
+    button = gtk_button_new_with_label (_(buttons[i]));
+    gtk_container_add (GTK_CONTAINER (bbox), button);
+    GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+    if (i == default_button - 1)
+      gtk_widget_grab_default (button);
+    gtk_widget_show (button);
 
-      if (signal_handlers[i])
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
-			    signal_handlers[i], 
-                            GTK_OBJECT (dialog));
-      else
-        gtk_signal_connect (GTK_OBJECT (button), "clicked",
-			    GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			    GTK_OBJECT (dialog));
-    }
+    if (signal_handlers[i])
+      gtk_signal_connect (GTK_OBJECT (button), "clicked", signal_handlers[i], GTK_OBJECT (dialog));
+    else
+      gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy), GTK_OBJECT (dialog));
+  }
   return dialog;
 }
 
 static int rep_yesno_dialog = 0;
 
 static void
-on_yes_yesno_dialog (GtkWidget * twidget,
-                     gpointer data)
+on_yes_yesno_dialog (GtkWidget * twidget, gpointer data)
 {
   gtk_main_quit ();
   rep_yesno_dialog = 1;
 }
 
 static void
-on_no_yesno_dialog (GtkWidget * twidget,
-                    gpointer data)
+on_no_yesno_dialog (GtkWidget * twidget, gpointer data)
 {
   rep_yesno_dialog = 0;
   gtk_main_quit ();
 }
 
 static gboolean
-delete_event_yesno_dialog (GtkWidget * widget,
-                           GdkEvent  *event,
-                           gpointer data)
+delete_event_yesno_dialog (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
   rep_yesno_dialog = 0;
   gtk_main_quit ();
-  return(TRUE);
+  return (TRUE);
 }
 
-gint my_yesno_dialog (gchar * message)
+gint
+my_yesno_dialog (gchar * message)
 {
   /* FIXME : how make this short and ANSI ? */
   GtkWidget *dialog_yesno_dialog;
-  gchar *buttons[] = { _("Yes"), _("No") };
+  gchar *buttons[2];
+  GtkSignalFunc signal_handlers[2];
+  
+  signal_handlers[0] = GTK_SIGNAL_FUNC (on_yes_yesno_dialog);
+  signal_handlers[1] = GTK_SIGNAL_FUNC (on_no_yesno_dialog);
 
-  GtkSignalFunc signal_handlers[] = { on_yes_yesno_dialog, 
-                                      on_no_yesno_dialog };
-                                      
-  dialog_yesno_dialog = my_show_dialog (message, 
-                                        2, 
-                                        buttons, 
-                                        2, 
-                                        signal_handlers, 
-                                        NULL);
-  gtk_signal_connect (GTK_OBJECT (dialog_yesno_dialog), "delete_event",
-		      GTK_SIGNAL_FUNC (delete_event_yesno_dialog), 
-                      GTK_OBJECT (dialog_yesno_dialog));
+  buttons[0] = _("Yes");
+  buttons[1] = _("No");
+
+  dialog_yesno_dialog = my_show_dialog (message, 2, buttons, 2, signal_handlers, NULL);
+  gtk_signal_connect (GTK_OBJECT (dialog_yesno_dialog), "delete_event", GTK_SIGNAL_FUNC (delete_event_yesno_dialog), GTK_OBJECT (dialog_yesno_dialog));
   gtk_window_set_modal (GTK_WINDOW (dialog_yesno_dialog), TRUE);
   gtk_window_set_title (GTK_WINDOW (dialog_yesno_dialog), _("Question"));
   gtk_widget_show (dialog_yesno_dialog);
@@ -423,18 +408,12 @@ refresh_screen (void)
   unsigned long valuemask;
   Window w;
 
-  valuemask =
-    CWOverrideRedirect | CWBackingStore | CWSaveUnder | CWBackPixmap;
+  valuemask = CWOverrideRedirect | CWBackingStore | CWSaveUnder | CWBackPixmap;
   attributes.override_redirect = True;
   attributes.save_under = False;
   attributes.background_pixmap = None;
   attributes.backing_store = NotUseful;
-  w =
-    XCreateWindow (GDK_DISPLAY (), GDK_WINDOW_XWINDOW (GDK_ROOT_PARENT ()), 0,
-		   0, (unsigned int) gdk_screen_width (),
-		   (unsigned int) gdk_screen_height (), (unsigned int) 0,
-		   CopyFromParent, (unsigned int) CopyFromParent,
-		   (Visual *) CopyFromParent, valuemask, &attributes);
+  w = XCreateWindow (GDK_DISPLAY (), GDK_WINDOW_XWINDOW (GDK_ROOT_PARENT ()), 0, 0, (unsigned int) gdk_screen_width (), (unsigned int) gdk_screen_height (), (unsigned int) 0, CopyFromParent, (unsigned int) CopyFromParent, (Visual *) CopyFromParent, valuemask, &attributes);
   XMapWindow (GDK_DISPLAY (), w);
   XDestroyWindow (GDK_DISPLAY (), w);
   XFlush (GDK_DISPLAY ());
@@ -505,33 +484,33 @@ gnome_uri_list_extract_uris (const gchar * uri_list)
    * allow LF delimination as well as the specified CRLF.
    */
   while (p)
+  {
+    if (*p != '#')
     {
-      if (*p != '#')
-	{
-	  while (isspace ((int) (*p)))
-	    p++;
-
-	  q = p;
-	  while (*q && (*q != '\n') && (*q != '\r'))
-	    q++;
-
-	  if (q > p)
-	    {
-	      q--;
-	      while (q > p && isspace ((int) (*q)))
-		q--;
-
-	      retval = (char *) g_malloc (q - p + 2);
-	      strncpy (retval, p, q - p + 1);
-	      retval[q - p + 1] = '\0';
-
-	      result = g_list_prepend (result, retval);
-	    }
-	}
-      p = strchr (p, '\n');
-      if (p)
+      while (isspace ((int) (*p)))
 	p++;
+
+      q = p;
+      while (*q && (*q != '\n') && (*q != '\r'))
+	q++;
+
+      if (q > p)
+      {
+	q--;
+	while (q > p && isspace ((int) (*q)))
+	  q--;
+
+	retval = (char *) g_malloc (q - p + 2);
+	strncpy (retval, p, q - p + 1);
+	retval[q - p + 1] = '\0';
+
+	result = g_list_prepend (result, retval);
+      }
     }
+    p = strchr (p, '\n');
+    if (p)
+      p++;
+  }
 
   return g_list_reverse (result);
 }
@@ -558,28 +537,29 @@ gnome_uri_list_extract_filenames (const gchar * uri_list)
 
   tmp_list = result;
   while (tmp_list)
+  {
+    gchar *s = (char *) tmp_list->data;
+
+    node = tmp_list;
+    tmp_list = tmp_list->next;
+
+    if (!strncmp (s, "file:", 5))
     {
-      gchar *s = (char *) tmp_list->data;
-
-      node = tmp_list;
-      tmp_list = tmp_list->next;
-
-      if (!strncmp (s, "file:", 5))
-	{
-	  node->data = cleanup (g_strdup (s + 5));
-	}
-      else
-	{
-	  node->data = cleanup (g_strdup (s));
-	}
-      g_free (s);
+      node->data = cleanup (g_strdup (s + 5));
     }
+    else
+    {
+      node->data = cleanup (g_strdup (s));
+    }
+    g_free (s);
+  }
   return result;
 }
 
 void
 my_flush_events (void)
 {
+  gdk_flush ();
   while (gtk_events_pending ())
     gtk_main_iteration_do (TRUE);
   gdk_flush ();
@@ -601,6 +581,48 @@ cursor_reset (GtkWidget * widget)
   gdk_window_set_cursor (widget->window, NULL);
 }
 
+void
+cursor_hide(GtkWidget * widget)
+{
+  GdkCursor *cursor;
+  GdkPixmap *source, *mask;
+  GdkColor fg = { 0, 0, 0, 0 }; /* Transparent. */
+  GdkColor bg = { 0, 0, 0, 0 }; /* Transparent. */   
+
+  g_return_if_fail (widget->window != NULL);
+  source = gdk_bitmap_create_from_data (NULL, empty_cursor_bits, empty_cursor_width, empty_cursor_height);
+  mask = gdk_bitmap_create_from_data (NULL, empty_cursormask_bits, empty_cursor_width, empty_cursor_height);
+  cursor = gdk_cursor_new_from_pixmap (source, mask, &fg, &bg, 8, 8);
+  gdk_pixmap_unref (source);
+  gdk_pixmap_unref (mask);   
+  gdk_window_set_cursor (widget->window, cursor);
+}
+
+gint 
+my_get_adjustment_as_int (GtkAdjustment * adjustment)
+{
+  gfloat val;
+
+  g_return_val_if_fail (adjustment != NULL, 0);
+  g_return_val_if_fail (GTK_IS_ADJUSTMENT (adjustment), 0);
+
+  val = adjustment->value;
+  if (val - floor (val) < ceil (val) - val)
+    return floor (val);
+  else
+    return ceil (val);
+}
+
+void
+my_set_adjustment_bounds (GtkAdjustment * adjustment, gfloat lower, gfloat upper)
+{
+  g_return_if_fail (adjustment != NULL);
+  g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
+
+  adjustment->lower = lower;
+  adjustment->upper = upper + 1.0;
+}
+
 void
 terminate (char *fmt, ...)
 {
@@ -619,44 +641,45 @@ void
 on_signal (int sig_num)
 {
   switch (sig_num)
-    {
-    case SIGHUP:
-      terminate ("sighup caught");
-      break;
-    case SIGINT:
-      terminate ("sigint caught");
-      break;
-    case SIGQUIT:
-      terminate ("sigquit caught");
-      break;
-    case SIGABRT:
-      terminate ("sigabrt caught");
-      break;
-    case SIGPIPE:
-      terminate ("sigpipe caught");
-      break;
-    case SIGBUS:
-      terminate ("sigbus caught");
-      break;
-    case SIGSEGV:
-      terminate ("sigsegv caught");
-      break;
-    case SIGTERM:
-      terminate ("sigterm caught");
-      break;
-    case SIGFPE:
-      terminate ("sigfpe caught");
-      break;
-    default:
-      terminate ("unknown signal");
-      break;
-    }
+  {
+  case SIGHUP:
+    terminate ("sighup caught");
+    break;
+  case SIGINT:
+    terminate ("sigint caught");
+    break;
+  case SIGQUIT:
+    terminate ("sigquit caught");
+    break;
+  case SIGABRT:
+    terminate ("sigabrt caught");
+    break;
+  case SIGPIPE:
+    terminate ("sigpipe caught");
+    break;
+  case SIGBUS:
+    terminate ("sigbus caught");
+    break;
+  case SIGSEGV:
+    terminate ("sigsegv caught");
+    break;
+  case SIGTERM:
+    terminate ("sigterm caught");
+    break;
+  case SIGFPE:
+    terminate ("sigfpe caught");
+    break;
+  default:
+    terminate ("unknown signal");
+    break;
+  }
 }
 
 void
 signal_setup (void)
 {
   /* Handle some signals */
+#ifndef DEBUG
   signal (SIGHUP, on_signal);
   signal (SIGINT, on_signal);
   signal (SIGQUIT, on_signal);
@@ -665,24 +688,42 @@ signal_setup (void)
   signal (SIGSEGV, on_signal);
   signal (SIGTERM, on_signal);
   signal (SIGFPE, on_signal);
+#endif
 }
 
 void
 xfce_init (int *argc, char **argv[])
 {
+#ifdef HAVE_GDK_IMLIB
+  int pixmaps, images;
+#endif
   signal_setup ();
 
   gtk_set_locale ();
   bindtextdomain (PACKAGE, XFCE_LOCALE_DIR);
   textdomain (PACKAGE);
+  init_xfce_rcfile ();
   gtk_init (argc, argv);
-  init_xfce_rcfile();
-
-  #ifdef HAVE_GDK_IMLIB
+#ifdef HAVE_GDK_IMLIB
   gdk_imlib_init ();
 /* Get gdk to use imlib's visual and colormap */
   gtk_widget_push_visual (gdk_imlib_get_visual ());
   gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+
+  /*
+   * Taken from gnome-libs where it is explained.
+   */
+  gdk_imlib_get_cache_info (&pixmaps, &images);
+  if (!((pixmaps == -1) || (images == -1)))
+  {
+    gdk_imlib_set_cache_info (0, images);
+  }
+#else
+#ifdef HAVE_GDK_PIXBUF
+  gdk_rgb_init ();
+  gtk_widget_set_default_colormap (gdk_rgb_get_cmap ());
+  gtk_widget_set_default_visual (gdk_rgb_get_visual ());
+#endif
 #endif
 }
 
@@ -692,5 +733,5 @@ xfce_end (gpointer data, int status)
   /* We'll be able to add more stuff here, but for the moment,
    * that's all we do here ...
    */
-  exit (status);
+  gdk_exit (status);
 }
