@@ -214,6 +214,191 @@ char *xres[] = { "/.Xdefaults",
   NULL
 };
 
+/* 
+ * The following functions are taken directly from GTK+ source code
+ */
+
+static void
+rgb_to_hls (double *r,
+            double *g,
+            double *b)
+{
+  double min;
+  double max;
+  double red;
+  double green;
+  double blue;
+  double h, l, s;
+  double delta;
+  
+  red = *r;
+  green = *g;
+  blue = *b;
+  
+  if (red > green)
+    {
+      if (red > blue)
+        max = red;
+      else
+        max = blue;
+      
+      if (green < blue)
+        min = green;
+      else
+        min = blue;
+    }
+  else
+    {
+      if (green > blue)
+        max = green;
+      else
+        max = blue;
+      
+      if (red < blue)
+        min = red;
+      else
+        min = blue;
+    }
+  
+  l = (max + min) / 2;
+  s = 0;
+  h = 0;
+  
+  if (max != min)
+    {
+      if (l <= 0.5)
+        s = (max - min) / (max + min);
+      else
+        s = (max - min) / (2 - max - min);
+      
+      delta = max -min;
+      if (red == max)
+        h = (green - blue) / delta;
+      else if (green == max)
+        h = 2 + (blue - red) / delta;
+      else if (blue == max)
+        h = 4 + (red - green) / delta;
+      
+      h *= 60;
+      if (h < 0.0)
+        h += 360;
+    }
+  
+  *r = h;
+  *g = l;
+  *b = s;
+}
+
+static void
+hls_to_rgb (double *h,
+            double *l,
+            double *s)
+{
+  double hue;
+  double lightness;
+  double saturation;
+  double m1, m2;
+  double r, g, b;
+  
+  lightness = *l;
+  saturation = *s;
+  
+  if (lightness <= 0.5)
+    m2 = lightness * (1 + saturation);
+  else
+    m2 = lightness + saturation - lightness * saturation;
+  m1 = 2 * lightness - m2;
+  
+  if (saturation == 0)
+    {
+      *h = lightness;
+      *l = lightness;
+      *s = lightness;
+    }
+  else
+    {
+      hue = *h + 120;
+      while (hue > 360)
+        hue -= 360;
+      while (hue < 0)
+        hue += 360;
+      
+      if (hue < 60)
+        r = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+        r = m2;
+      else if (hue < 240)
+        r = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+        r = m1;
+      
+      hue = *h;
+      while (hue > 360)
+        hue -= 360;
+      while (hue < 0)
+        hue += 360;
+      
+      if (hue < 60)
+        g = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+        g = m2;
+      else if (hue < 240)
+        g = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+        g = m1;
+      
+      hue = *h - 120;
+      while (hue > 360)
+        hue -= 360;
+      while (hue < 0)
+        hue += 360;
+      
+      if (hue < 60)
+        b = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+        b = m2;
+      else if (hue < 240)
+        b = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+        b = m1;
+      
+      *h = r;
+      *l = g;
+      *s = b;
+    }
+}
+
+void color_shade (unsigned short *r, unsigned short *g, unsigned short *b, double   k)
+{
+  double red;
+  double green;
+  double blue;
+  
+  red   = (double) *r / 65535.0;
+  green = (double) *g / 65535.0;
+  blue  = (double) *b / 65535.0;
+  
+  rgb_to_hls (&red, &green, &blue);
+  
+  green *= k;
+  if (green > 1.0)
+    green = 1.0;
+  else if (green < 0.0)
+    green = 0.0;
+  
+  blue *= k;
+  if (blue > 1.0)
+    blue = 1.0;
+  else if (blue < 0.0)
+    blue = 0.0;
+  
+  hls_to_rgb (&red, &green, &blue);
+  
+  *r = red   * 65535.0;
+  *g = green * 65535.0;
+  *b = blue  * 65535.0;
+}
+
 int
 brightness (int r, int g, int b)
 {
@@ -225,7 +410,7 @@ brightness_pal (const XFCE_palette * p, int index)
 {
   if ((p) && (index >= 0) && (index < NB_XFCE_COLORS))
   {
-    return (brightness ((short int) p->r[index], (short int) p->g[index], (short int) p->b[index]));
+    return (brightness ((unsigned short) p->r[index], (unsigned short) p->g[index], (unsigned short) p->b[index]));
   }
   else
   {
@@ -303,7 +488,7 @@ apply_xpalette (XFCE_palette * p, gboolean add_or_remove)
       color++;
     else
     {
-      snprintf (buffer, 255, "%s: #%02X%02X%02X\n", resmapSel[i], ((short int) p->r[color]) ^ 255, ((short int) p->g[color]) ^ 128, ((short int) p->b[color]) ^ 64);
+      snprintf (buffer, 255, "%s: #%02X%02X%02X\n", resmapSel[i], ((unsigned short) p->r[color]) ^ 255, ((unsigned short) p->g[color]) ^ 128, ((unsigned short) p->b[color]) ^ 64);
       write (tube[1], buffer, strlen (buffer));
     }
     i++;
@@ -337,7 +522,7 @@ apply_xpalette (XFCE_palette * p, gboolean add_or_remove)
     {
       int howbright;
 
-      howbright = brightness (((short int) p->r[color]) ^ 255, ((short int) p->g[color]) ^ 128, ((short int) p->b[color]) ^ 64);
+      howbright = brightness (((unsigned short) p->r[color]) ^ 255, ((unsigned short) p->g[color]) ^ 128, ((unsigned short) p->b[color]) ^ 64);
       if (howbright < 50)
         snprintf (buffer, 255, "%s: #FFFFFF\n", resmapSelTxt[i]);
       else
@@ -403,7 +588,7 @@ color_to_hex (char *s, const XFCE_palette * p, int index)
 
   if ((p) && (s) && (index >= 0) && (index < NB_XFCE_COLORS))
   {
-    sprintf (s, "#%02X%02X%02X", (short int) p->r[index], (short int) p->g[index], (short int) p->b[index]);
+    sprintf (s, "#%02X%02X%02X", (unsigned short) p->r[index], (unsigned short) p->g[index], (unsigned short) p->b[index]);
     return (s);
   }
   return (NULL);
@@ -588,12 +773,16 @@ initpal (XFCE_palette * p)
 }
 
 void
-write_style_to_gtkrc_file (FILE * f, XFCE_palette * p, int i, int j, char *template, gboolean textured)
+write_style_to_gtkrc_file (FILE * f, XFCE_palette * p, int normal, int selected, int base, char *template, gboolean textured)
 {
   int c1_howbright, c1_howbrightSel;
   int c2_howbright, c2_howbrightSel;
   char *texture;
   char nobgpixmap[] = "<none>";
+  /* Temporary RGB values */
+  unsigned short red;
+  unsigned short green;
+  unsigned short blue;
 
   /* When running on a display with 256 colors or less, avoid using textures */
   if (DEFAULT_DEPTH > 8)
@@ -602,12 +791,12 @@ write_style_to_gtkrc_file (FILE * f, XFCE_palette * p, int i, int j, char *templ
     texture = nobgpixmap;
 
 
-  c1_howbright = brightness (p->r[i], p->g[i], p->b[i]);
-  c1_howbrightSel = brightness (((short int) p->r[i]) ^ 255, ((short int) p->g[i]) ^ 128, ((short int) p->b[i]) ^ 64);
-  c2_howbright = brightness (p->r[j], p->g[j], p->b[j]);
-  c2_howbrightSel = brightness (((short int) p->r[j]) ^ 255, ((short int) p->g[j]) ^ 128, ((short int) p->b[j]) ^ 64);
+  c1_howbright = brightness (p->r[normal], p->g[normal], p->b[normal]);
+  c1_howbrightSel = brightness (((unsigned short) p->r[normal]) ^ 255, ((unsigned short) p->g[normal]) ^ 128, ((unsigned short) p->b[normal]) ^ 64);
+  c2_howbright = brightness (p->r[selected], p->g[selected], p->b[selected]);
+  c2_howbrightSel = brightness (((unsigned short) p->r[selected]) ^ 255, ((unsigned short) p->g[selected]) ^ 128, ((unsigned short) p->b[selected]) ^ 64);
 
-  fprintf (f, "style \"%s%u\"\n", template, i);
+  fprintf (f, "style \"%s%u\"\n", template, normal);
   fprintf (f, "{\n");
   if ((p->fnt) && strlen (p->fnt))
     fprintf (f, "  font              = \"%s\"\n", p->fnt);
@@ -616,8 +805,8 @@ write_style_to_gtkrc_file (FILE * f, XFCE_palette * p, int i, int j, char *templ
   {
     fprintf (f, "  bg_pixmap[NORMAL] = \"%s\"\n", texture);
     fprintf (f, "  bg_pixmap[ACTIVE] = \"%s\"\n", nobgpixmap);
-    fprintf (f, "  bg_pixmap[INSENSITIVE] = \"%s\"\n", (i == j) ? texture : nobgpixmap);
-    fprintf (f, "  bg_pixmap[PRELIGHT] = \"%s\"\n", (i == j) ? texture : nobgpixmap);
+    fprintf (f, "  bg_pixmap[INSENSITIVE] = \"%s\"\n", (normal == selected) ? texture : nobgpixmap);
+    fprintf (f, "  bg_pixmap[PRELIGHT] = \"%s\"\n", (normal == selected) ? texture : nobgpixmap);
   }
   else
   {
@@ -667,32 +856,55 @@ write_style_to_gtkrc_file (FILE * f, XFCE_palette * p, int i, int j, char *templ
     fprintf (f, "  text[SELECTED]    = \"#000000\"\n");
   }
 
-  fprintf (f, "  bg[NORMAL]        = \"#%02X%02X%02X\"\n", (short int) p->r[i], (short int) p->g[i], (short int) p->b[i]);
+  fprintf (f, "  bg[NORMAL]        = \"#%02X%02X%02X\"\n", (unsigned short) p->r[normal], (unsigned short) p->g[normal], (unsigned short) p->b[normal]);
 
-  fprintf (f, "  base[NORMAL]      = \"#%02X%02X%02X\"\n", (short int) p->r[i], (short int) p->g[i], (short int) p->b[i]);
+  fprintf (f, "  base[NORMAL]      = \"#%02X%02X%02X\"\n", (unsigned short) p->r[base], (unsigned short) p->g[base], (unsigned short) p->b[base]);
+  
+  /* Init temp colors */
+  red   = (unsigned short) p->r[selected];
+  green = (unsigned short) p->g[selected];
+  blue  = (unsigned short) p->b[selected];
 
-  fprintf (f, "  bg[ACTIVE]        = \"#%02X%02X%02X\"\n", (short int) shift (p->r[j], DARK), (short int) shift (p->g[j], DARK), (short int) shift (p->b[j], DARK));
+  /* Compute shadow color */
+  color_shade (&red, &green, &blue, DARK);
 
-  fprintf (f, "  base[ACTIVE]      = \"#%02X%02X%02X\"\n", (short int) shift (p->r[j], DARK), (short int) shift (p->g[j], DARK), (short int) shift (p->b[j], DARK));
+  /* Then set color */
+  fprintf (f, "  bg[ACTIVE]        = \"#%02X%02X%02X\"\n", (unsigned short) red, (unsigned short) green, (unsigned short) blue);
 
-  if (i == j)
+  /* Do the same for normal GC, init temp colors */
+  red   = (unsigned short) p->r[base];
+  green = (unsigned short) p->g[base];
+  blue  = (unsigned short) p->b[base];
+
+  /* Compute shadow color */
+  color_shade (&red, &green, &blue, DARK);
+
+  /* Then set color */
+  fprintf (f, "  base[ACTIVE]      = \"#%02X%02X%02X\"\n", (unsigned short) red, (unsigned short) green, (unsigned short) blue);
+
+#if 0
+  if (normal == selected)
   {
-    fprintf (f, "  bg[PRELIGHT]      = \"#%02X%02X%02X\"\n", (short int) shift (p->r[i], LIGHT), (short int) shift (p->g[i], LIGHT), (short int) shift (p->b[i], LIGHT));
+    fprintf (f, "  bg[PRELIGHT]      = \"#%02X%02X%02X\"\n", (unsigned short) shift (p->r[normal], LIGHT), (unsigned short) shift (p->g[normal], LIGHT), (unsigned short) shift (p->b[normal], LIGHT));
   }
   else
   {
-    fprintf (f, "  bg[PRELIGHT]    = \"#%02X%02X%02X\"\n", (short int) p->r[j], (short int) p->g[j], (short int) p->b[j]);
+    fprintf (f, "  bg[PRELIGHT]    = \"#%02X%02X%02X\"\n", (unsigned short) p->r[selected], (unsigned short) p->g[selected], (unsigned short) p->b[selected]);
   }
+#else
+  fprintf (f, "  bg[PRELIGHT]    = \"#%02X%02X%02X\"\n", (unsigned short) p->r[selected], (unsigned short) p->g[selected], (unsigned short) p->b[selected]);
+#endif
+  fprintf (f, "  base[PRELIGHT]    = \"#%02X%02X%02X\"\n", (unsigned short) p->r[base], (unsigned short) p->g[base], (unsigned short) p->b[base]);
 
-  fprintf (f, "  base[PRELIGHT]    = \"#%02X%02X%02X\"\n", (short int) p->r[j], (short int) p->g[j], (short int) p->b[j]);
+  fprintf (f, "  bg[SELECTED]      = \"#%02X%02X%02X\"\n", ((unsigned short) p->r[selected]) ^ 255, ((unsigned short) p->g[selected]) ^ 128, ((unsigned short) p->b[selected]) ^ 64);
 
-  fprintf (f, "  bg[SELECTED]      = \"#%02X%02X%02X\"\n", ((short int) p->r[j]) ^ 255, ((short int) p->g[j]) ^ 128, ((short int) p->b[j]) ^ 64);
+  fprintf (f, "  bg[INSENSITIVE]   = \"#%02X%02X%02X\"\n", (unsigned short) p->r[normal], (unsigned short) p->g[normal], (unsigned short) p->b[normal]);
 
-  fprintf (f, "  bg[INSENSITIVE]   = \"#%02X%02X%02X\"\n", (short int) p->r[i], (short int) p->g[i], (short int) p->b[i]);
-
-  fprintf (f, "  base[INSENSITIVE] = \"#%02X%02X%02X\"\n", (short int) p->r[i], (short int) p->g[i], (short int) p->b[i]);
+  fprintf (f, "  base[INSENSITIVE] = \"#%02X%02X%02X\"\n", (unsigned short) p->r[normal], (unsigned short) p->g[normal], (unsigned short) p->b[normal]);
+#ifndef WIN32
   if ((p->engine) && (strlen (p->engine)) && my_strncasecmp (p->engine, "gtk", 3))
     fprintf (f, "  engine \"%s\" {}\n", p->engine);
+#endif
   fprintf (f, "}\n");
 }
 
@@ -724,9 +936,9 @@ create_gtkrc_file (XFCE_palette * p, char *name)
       fprintf (f, "%s\n\n", XFCE3GTKRC);
       fprintf (f, "pixmap_path \"%s:.:/\"\n\n", build_path ("/"));
       for (i = 1; i < 8; i++)   /* Color 0 is used for the mouse pointer only */
-        write_style_to_gtkrc_file (f, p, i, i, "xfce_", (i == 7));
+        write_style_to_gtkrc_file (f, p, i, i, 4, "xfce_", (i == 7));
 #ifndef OLD_STYLE
-      write_style_to_gtkrc_file (f, p, 7, 2, "xfcebar_", TRUE);
+      write_style_to_gtkrc_file (f, p, 7, 2, 4, "xfcebar_", TRUE);
 #endif
       fprintf (f, "style \"tooltips-style\" {\n");
       fprintf (f, "  bg[NORMAL] = \"#ffffc0\"\n");
@@ -773,7 +985,7 @@ create_temp_gtkrc_file (XFCE_palette * p)
     fprintf (f, "%s\n\n", XFCE3GTKRC);
     fprintf (f, "pixmap_path \"%s:.:/\"\n\n", build_path ("/"));
     for (i = 0; i < 8; i++)
-      write_style_to_gtkrc_file (f, p, i, i, "temp_xfce_", FALSE);
+      write_style_to_gtkrc_file (f, p, i, i, 4, "temp_xfce_", FALSE);
     fprintf (f, "widget       \"*temp_color0*\"  style \"temp_xfce_0\"\n");
     fprintf (f, "widget       \"*temp_color1*\"  style \"temp_xfce_1\"\n");
     fprintf (f, "widget       \"*temp_color2*\"  style \"temp_xfce_2\"\n");
@@ -798,30 +1010,56 @@ void
 defpal (XFCE_palette * p)
 {
   initpal (p);
+  /*
   p->r[0] = 255;
   p->g[0] = 255;
   p->b[0] = 255;
-  p->r[1] = 205;
-  p->g[1] = 204;
-  p->b[1] = 205;
-  p->r[2] =   0;
-  p->g[2] = 126;
-  p->b[2] = 190;
-  p->r[3] =   0;
-  p->g[3] = 126;
-  p->b[3] = 190;
+  p->r[1] = 183;
+  p->g[1] = 183;
+  p->b[1] = 179;
+  p->r[2] = 183;
+  p->g[2] = 183;
+  p->b[2] = 179;
+  p->r[3] = 183;
+  p->g[3] = 183;
+  p->b[3] = 179;
+  p->r[4] = 229;
+  p->g[4] = 229;
+  p->b[4] = 224;
+  p->r[5] = 229;
+  p->g[5] = 229;
+  p->b[5] = 224;
+  p->r[6] =  10;
+  p->g[6] = 137;
+  p->b[6] =  94;
+  p->r[7] = 204;
+  p->g[7] = 204;
+  p->b[7] = 199;
+   */
+  p->r[0] =   0;
+  p->g[0] =   0;
+  p->b[0] =   0;
+  p->r[1] = 200;
+  p->g[1] = 200;
+  p->b[1] = 200;
+  p->r[2] = 242;
+  p->g[2] = 242;
+  p->b[2] = 242;
+  p->r[3] = 200;
+  p->g[3] = 200;
+  p->b[3] = 200;
   p->r[4] = 255;
   p->g[4] = 255;
   p->b[4] = 255;
-  p->r[5] = 255;
-  p->g[5] = 255;
-  p->b[5] = 255;
-  p->r[6] =  64;
-  p->g[6] = 153;
-  p->b[6] =  65;
-  p->r[7] = 205;
-  p->g[7] = 204;
-  p->b[7] = 205;
+  p->r[5] = 242;
+  p->g[5] = 242;
+  p->b[5] = 242;
+  p->r[6] =  10;
+  p->g[6] =  95;
+  p->b[6] = 137;
+  p->r[7] = 220;
+  p->g[7] = 220;
+  p->b[7] = 220;
   p->texture = g_realloc (p->texture, sizeof (char) * (strlen (DEFAULTTEXTURE) + 1));
   strcpy (p->texture, DEFAULTTEXTURE);
 }
