@@ -18,7 +18,6 @@
 
 #ifndef __ACTION_H__
 #define __ACTION_H__
-#include "xfcolor.h"
 
 GtkWidget *action_icon_optionmenu;
 GtkWidget *action_icon_optionmenu_menu;
@@ -30,10 +29,10 @@ GtkWidget *action_ok_button;
 guint action_signal_id1;
 guint action_signal_id2;
 
-GtkWidget *create_action (XFCE_palette *);
+GtkWidget *create_action (void);
 GtkWidget *action_addto_choice (char *name);
-int action_get_choice_selected (void);
-void action_set_choice_selected (int index);
-void open_action (GtkWidget * action, int nbr);
+gint action_get_choice_selected (void);
+void action_set_choice_selected (gint index);
+void open_action (GtkWidget * action, gint nbr);
 
 #endif
