@@ -1,11 +1,10 @@
 /* XPM */
 static char *iconify[] = {
-  "4 4 3 1",
+  "3 3 3 1",
   ". c none",
   "X c #303030",
-  "o c #ffffff",
-  "XXXo",
-  "X..o",
-  "X..o",
-  "Xooo"
+  "o c #f0f0f0",
+  "XXo",
+  "X.o",
+  "Xoo"
 };
