@@ -42,13 +42,14 @@ void
 info_private_ok_cb (GtkWidget * twidget)
 {
   gtk_widget_hide (info_scr);
+  gdk_window_withdraw ((GTK_WIDGET (info_scr))->window);
 }
 
 gboolean
-info_private_delete_event (GtkWidget * widget,
-			   GdkEvent * event, gpointer data)
+info_private_delete_event (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
   gtk_widget_hide (info_scr);
+  gdk_window_withdraw ((GTK_WIDGET (info_scr))->window);
   return (TRUE);
 }
 
@@ -81,7 +82,11 @@ create_info (void)
   gtk_object_set_data (GTK_OBJECT (info), "info_mainframe", info_mainframe);
   gtk_widget_show (info_mainframe);
   gtk_container_add (GTK_CONTAINER (info), info_mainframe);
+#ifdef OLD_STYLE
+  gtk_frame_set_shadow_type (GTK_FRAME (info_mainframe), GTK_SHADOW_NONE);
+#else
   gtk_frame_set_shadow_type (GTK_FRAME (info_mainframe), GTK_SHADOW_OUT);
+#endif
 
   info_vbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_set_name (info_vbox, "info_vbox");
@@ -101,25 +106,21 @@ create_info (void)
   if (info_logo_pixmap == NULL)
     g_error (_("Couldn't create pixmap"));
   gtk_widget_set_name (info_logo_pixmap, "info_logo_pixmap");
-  gtk_object_set_data (GTK_OBJECT (info), "info_logo_pixmap",
-		       info_logo_pixmap);
+  gtk_object_set_data (GTK_OBJECT (info), "info_logo_pixmap", info_logo_pixmap);
   gtk_widget_show (info_logo_pixmap);
   gtk_container_add (GTK_CONTAINER (info_topframe), info_logo_pixmap);
 
   info_centralframe = gtk_frame_new (NULL);
   gtk_widget_set_name (info_centralframe, "info_centralframe");
-  gtk_object_set_data (GTK_OBJECT (info), "info_centralframe",
-		       info_centralframe);
+  gtk_object_set_data (GTK_OBJECT (info), "info_centralframe", info_centralframe);
   gtk_widget_show (info_centralframe);
   gtk_box_pack_start (GTK_BOX (info_vbox), info_centralframe, TRUE, TRUE, 0);
   gtk_container_border_width (GTK_CONTAINER (info_centralframe), 4);
   gtk_frame_set_shadow_type (GTK_FRAME (info_centralframe), GTK_SHADOW_IN);
 
-  info_copyright_label =
-    gtk_label_new (_("By Olivier Fourdan (c) 1997-2000"));
+  info_copyright_label = gtk_label_new (_("By Olivier Fourdan (c) 1997-2000"));
   gtk_widget_set_name (info_copyright_label, "info_copyright_label");
-  gtk_object_set_data (GTK_OBJECT (info), "info_copyright_label",
-		       info_copyright_label);
+  gtk_object_set_data (GTK_OBJECT (info), "info_copyright_label", info_copyright_label);
   gtk_widget_show (info_copyright_label);
   gtk_container_add (GTK_CONTAINER (info_centralframe), info_copyright_label);
   gtk_widget_set_usize (info_copyright_label, -2, 20);
@@ -127,22 +128,19 @@ create_info (void)
 
   info_bottomframe = gtk_frame_new (NULL);
   gtk_widget_set_name (info_bottomframe, "info_bottomframe");
-  gtk_object_set_data (GTK_OBJECT (info), "info_bottomframe",
-		       info_bottomframe);
+  gtk_object_set_data (GTK_OBJECT (info), "info_bottomframe", info_bottomframe);
   gtk_widget_show (info_bottomframe);
   gtk_box_pack_start (GTK_BOX (info_vbox), info_bottomframe, TRUE, TRUE, 0);
   gtk_container_border_width (GTK_CONTAINER (info_bottomframe), 5);
 
   info_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_container_add (GTK_CONTAINER (info_bottomframe), info_scrolled_window);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (info_scrolled_window),
-				  GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (info_scrolled_window), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
   gtk_widget_show (info_scrolled_window);
 
   info_license_text = gtk_text_new (NULL, NULL);
   gtk_widget_set_name (info_license_text, "info_license_text");
-  gtk_object_set_data (GTK_OBJECT (info), "info_license_text",
-		       info_license_text);
+  gtk_object_set_data (GTK_OBJECT (info), "info_license_text", info_license_text);
   gtk_text_set_editable (GTK_TEXT (info_license_text), FALSE);
   gtk_widget_show (info_license_text);
   gtk_container_add (GTK_CONTAINER (info_scrolled_window), info_license_text);
@@ -153,53 +151,48 @@ create_info (void)
   gtk_text_freeze (GTK_TEXT (info_license_text));
 
   if (infile)
+  {
+    char *buffer;
+    int nbytes_read, nbytes_alloc;
+
+    nbytes_read = 0;
+    nbytes_alloc = 1024;
+    buffer = g_new (char, nbytes_alloc);
+    while (1)
     {
-      char *buffer;
-      int nbytes_read, nbytes_alloc;
-
-      nbytes_read = 0;
-      nbytes_alloc = 1024;
-      buffer = g_new (char, nbytes_alloc);
-      while (1)
-	{
-	  int len;
-	  if (nbytes_alloc < nbytes_read + 1024)
-	    {
-	      nbytes_alloc *= 2;
-	      buffer = g_realloc (buffer, nbytes_alloc);
-	    }
-	  len = fread (buffer + nbytes_read, 1, 1024, infile);
-	  nbytes_read += len;
-	  if (len < 1024)
-	    break;
-	}
-
-      gtk_text_insert (GTK_TEXT (info_license_text), NULL, NULL,
-		       NULL, buffer, nbytes_read);
-      g_free (buffer);
-      fclose (infile);
+      int len;
+      if (nbytes_alloc < nbytes_read + 1024)
+      {
+	nbytes_alloc *= 2;
+	buffer = g_realloc (buffer, nbytes_alloc);
+      }
+      len = fread (buffer + nbytes_read, 1, 1024, infile);
+      nbytes_read += len;
+      if (len < 1024)
+	break;
     }
 
+    gtk_text_insert (GTK_TEXT (info_license_text), NULL, NULL, NULL, buffer, nbytes_read);
+    g_free (buffer);
+    fclose (infile);
+  }
+
   gtk_text_set_word_wrap (GTK_TEXT (info_license_text), TRUE);
   gtk_text_set_line_wrap (GTK_TEXT (info_license_text), TRUE);
   gtk_text_thaw (GTK_TEXT (info_license_text));
 
-  info_agreement_button = gtk_button_new_with_label (_("Agreement"));
+  info_agreement_button = gtk_button_new_with_label (_("Accept"));
   gtk_widget_set_name (info_agreement_button, "info_agreement_button");
-  gtk_object_set_data (GTK_OBJECT (info), "info_agreement_button",
-		       info_agreement_button);
+  gtk_object_set_data (GTK_OBJECT (info), "info_agreement_button", info_agreement_button);
   gtk_widget_show (info_agreement_button);
-  gtk_box_pack_start (GTK_BOX (info_vbox), info_agreement_button, FALSE,
-		      FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (info_vbox), info_agreement_button, FALSE, FALSE, 0);
   gtk_container_border_width (GTK_CONTAINER (info_agreement_button), 5);
   GTK_WIDGET_SET_FLAGS (info_agreement_button, GTK_CAN_DEFAULT);
   gtk_widget_grab_default (info_agreement_button);
 
-  gtk_signal_connect (GTK_OBJECT (info_agreement_button), "clicked",
-		      GTK_SIGNAL_FUNC (info_private_ok_cb), NULL);
+  gtk_signal_connect (GTK_OBJECT (info_agreement_button), "clicked", GTK_SIGNAL_FUNC (info_private_ok_cb), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (info), "delete_event",
-		      GTK_SIGNAL_FUNC (info_private_delete_event), NULL);
+  gtk_signal_connect (GTK_OBJECT (info), "delete_event", GTK_SIGNAL_FUNC (info_private_delete_event), NULL);
 
   return info;
 }
