@@ -1,6 +1,5 @@
 /* XPM */
-static char *minipnt[] =
-{
+static char *minipnt[] = {
   "24 18 9 1",
   "+ c none",
   ". c #bebebe",
@@ -28,4 +27,5 @@ static char *minipnt[] =
   "+++a##...ffff.....##a+++",
   "++++aa###......###aa++++",
   "++++++aa########aa++++++",
-  "++++++++aaaaaaaa++++++++"};
+  "++++++++aaaaaaaa++++++++"
+};
