@@ -19,7 +19,12 @@
 #include <gtk/gtk.h>
 #include <gmodule.h>
 
-#define SCROLLBAR_WIDTH 14
+#define SCROLLBAR_WIDTH 15
+
+static gint range_slider_width;
+static gint range_min_slider_size;
+static gint range_stepper_size;
+static gint range_stepper_slider_spacing;
 
 /* Theme functions to export */
 void theme_init (GtkThemeEngine * engine);
@@ -69,6 +74,14 @@ static void
 theme_rc_style_to_style (GtkStyle * style, GtkRcStyle * rc_style)
 {
   style->klass = &xfce_default_class;
+  gtk_style_set_prop_experimental (style, "GtkButton::default_spacing", 6);
+  gtk_style_set_prop_experimental (style, "GtkCheckButton::indicator_size", 13);
+  gtk_style_set_prop_experimental (style, "GtkPaned::handle_full_size", 1);
+  gtk_style_set_prop_experimental (style, "GtkRange::trough_border", 2);
+  gtk_style_set_prop_experimental (style, "GtkRange::slider_width", SCROLLBAR_WIDTH);
+  gtk_style_set_prop_experimental (style, "GtkRange::stepper_size", SCROLLBAR_WIDTH);
+  gtk_style_set_prop_experimental (style, "GtkRange::stepper_spacing", 0);
+  gtk_style_set_prop_experimental (style, "GtkSpinButton::shadow_type", GTK_SHADOW_ETCHED_IN);
 }
 
 static void
@@ -110,12 +123,6 @@ theme_init (GtkThemeEngine * engine)
   engine->destroy_rc_style = theme_destroy_rc_style;
   engine->destroy_style = theme_destroy_style;
   engine->set_background = NULL;
-
-  /* Make scrollbars wider */
-  rangeclass = (GtkRangeClass *) gtk_type_class (gtk_range_get_type ());
-  rangeclass->slider_width = SCROLLBAR_WIDTH;
-  rangeclass->min_slider_size = SCROLLBAR_WIDTH;
-  rangeclass->stepper_size = SCROLLBAR_WIDTH;
 }
 
 void
