@@ -21,7 +21,6 @@
 
 #include <gdk/gdk.h>
 
-gdouble *
-xfclock_colorselect(gdouble *initial);
+gdouble *xfclock_colorselect (gdouble * initial);
 
 #endif
