@@ -23,6 +23,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
+#include <stdlib.h>
 #include "my_intl.h"
 #include "xfmouse.h"
 #include "xfmouse_cb.h"
@@ -53,8 +54,7 @@ cancel_cb (GtkWidget * widget, gpointer data)
   exit (0);
 }
 
-gboolean
-delete_event (GtkWidget * widget, GdkEvent * event, gpointer data)
+gboolean delete_event (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
   cancel_cb (widget, data);
   return (TRUE);
