@@ -20,7 +20,6 @@
 #define __XFSOUND_H__
 
 #include <gtk/gtk.h>
-#include "xfcolor.h"
 
 #define KNOWN_MESSAGES          13
 #define BUILTIN_STARTUP		KNOWN_MESSAGES
@@ -57,16 +56,15 @@ char *homedir, *tempstr;
 XFSound sndcfg;
 int fd_width;
 int fd[2];
-XFCE_palette *palette;
 
 void allocXFSound (XFSound * s);
 void freeXFSound (XFSound * s);
 void loadcfg (XFSound * s);
 int savecfg (XFSound * s);
-void audio_play (short code);
+void audio_play (short code, short backgnd);
 char *get_all_data (int i);
 void update_all_data (void);
-GtkWidget *create_xfsound (XFCE_palette * pal);
+GtkWidget *create_xfsound (void);
 GtkWidget *list_addto_choice (char *name);
 int list_get_choice_selected (void);
 void list_set_choice_selected (int index);
