@@ -20,18 +20,16 @@
 #define __XFSOUND_CB_H__
 
 #include <gtk/gtk.h>
-void doplay_cb (GtkWidget *widget, gpointer   data );
-void play_com_cb (GtkWidget *widget, gpointer   data );
-void soundfile_cb (GtkWidget *widget, gpointer   data );
-void browsefile_cb (GtkWidget *widget, gpointer   data );
-void internal_cb (GtkWidget *widget, gpointer   data );
-void defaultcmd_cb (GtkWidget *widget, gpointer   data );
-void ok_cb (GtkWidget *widget, gpointer   data );
-void apply_cb (GtkWidget *widget, gpointer   data );
-void cancel_cb (GtkWidget *widget, gpointer   data );
-void testfile_cb (GtkWidget *widget, gpointer   data );
-gboolean delete_event( GtkWidget *widget,
-                   GdkEvent  *event,
-                   gpointer   data );
+void doplay_cb (GtkWidget * widget, gpointer data);
+void play_com_cb (GtkWidget * widget, gpointer data);
+void soundfile_cb (GtkWidget * widget, gpointer data);
+void browsefile_cb (GtkWidget * widget, gpointer data);
+void internal_cb (GtkWidget * widget, gpointer data);
+void defaultcmd_cb (GtkWidget * widget, gpointer data);
+void ok_cb (GtkWidget * widget, gpointer data);
+void apply_cb (GtkWidget * widget, gpointer data);
+void cancel_cb (GtkWidget * widget, gpointer data);
+void testfile_cb (GtkWidget * widget, gpointer data);
+gboolean delete_event (GtkWidget * widget, GdkEvent * event, gpointer data);
 
 #endif
