@@ -50,28 +50,8 @@ typedef struct
 }
 entry;
 
+#include "ft_types.h"
 
-#define FT_DIR			(1<<0)
-#define FT_DIR_UP		(1<<1)
-#define FT_FILE			(1<<2)
-#define FT_CHAR_DEV		(1<<3)
-#define FT_BLOCK_DEV		(1<<4)
-#define FT_FIFO			(1<<5)
-#define FT_SOCKET		(1<<6)
-#define FT_EXE			(1<<7)
-#define FT_HIDDEN		(1<<8)
-#define FT_LINK			(1<<9)
-#define FT_DIR_PD		(1<<10)
-#define FT_STALE_LINK		(1<<11)
-#define FT_UNKNOWN		(1<<12)
-#define FT_DUMMY		(1<<13)
-
-#define FT_TAR			(1<<14)
-#define FT_TARCHILD		(1<<15)
-#define FT_TAR_DUMMY		(1<<16)
-#define FT_GZ			(1<<17)
-#define FT_COMPRESS		(1<<18)
-#define FT_BZ2			(1<<19)
 
 #define EN_IS_TAR(en) (en->type & FT_TAR)
 #define EN_IS_TARCHILD(en) (en->type & FT_TARCHILD)
