@@ -28,6 +28,7 @@
 #  include <config.h>   
 #endif
 
+#include <unistd.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -48,6 +49,8 @@
 #define B_HEIGHT	35
 #define E_WIDTH		260
 
+static gboolean dlgfree=TRUE;
+
 typedef struct
 {
   GtkWidget *top;
@@ -81,14 +84,22 @@ on_cancel (GtkWidget * btn, gpointer * data)
 {
   if ((int) ((long) data) != DLG_RC_DESTROY)
   {
+    dlgfree=TRUE;
     gtk_widget_destroy (dl.top);
   }
   dl.result = DLG_RC_CANCEL;
   /*fprintf(stderr,"dbg: at cancel\n");*/
-   if (dl.return_data) free(dl.return_data); dl.return_data=NULL;
+   if (dl.return_data) g_free(dl.return_data); dl.return_data=NULL;
+}
+
+static void
+on_destroy (GtkWidget * btn, gpointer * data)
+{
+  dlgfree=TRUE;
   gtk_main_quit ();
 }
 
+
 /*
  * called if user presses ok button
  * keep combo+entryedit separate. 
@@ -98,9 +109,9 @@ on_cancel (GtkWidget * btn, gpointer * data)
 static void
 on_ok (GtkWidget * ok, gpointer * data)
 {
+  dlgfree=TRUE;
   gtk_widget_destroy (dl.top);
   dl.result = (int) ((long) data);
-  gtk_main_quit ();
 }
 
 
@@ -109,16 +120,17 @@ static void
 on_ok_combo (GtkWidget * ok, gpointer * data)
 {
   /*fprintf(stderr,"dbg: at ok_combo\n");*/
-  if (dl.return_data) free(dl.return_data);
+  if (dl.return_data) g_free(dl.return_data);
   dl.return_data=NULL; /* return value of false for fails */
   if (!(dl.entry)) return;
-  if (dl.return_data) free(dl.return_data);
   dl.return_data = (void *)malloc(1+strlen(gtk_entry_get_text (GTK_ENTRY (dl.entry) )) ); 
   if (!(dl.return_data)) return;
+  /*fprintf(stderr,"dbg: at ok_combo:%s\n",gtk_entry_get_text (GTK_ENTRY (dl.entry)));*/
   strcpy((char *)dl.return_data,gtk_entry_get_text (GTK_ENTRY (dl.entry)));
+  /*fprintf(stderr,"dbg: at ok_combo->%s\n",(char *)dl.return_data);*/
+  dlgfree=TRUE;
   gtk_widget_destroy (dl.top);
   dl.result = 0; /* value not used */
-  gtk_main_quit ();
 }
 
 
@@ -243,23 +255,27 @@ static GtkWidget *make_button_with_accel(gchar *label, GtkAccelGroup *accelgrp)
  */
 
 
-long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *data, int type)
+long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *data, int type, gboolean def_cancel)
 {
   GtkWidget *ok = NULL, *cancel = NULL, *all = NULL, *skip = NULL, *close = NULL, *icon = NULL, *combo = NULL, *label, *box, *button_box;
-  /*char title[DLG_MAX];*/
   char *longlabel = NULL;
   GdkPixmap *pix = NULL, *pim;
   GtkAccelGroup *accelgrp;
 
   /*fprintf(stderr,"dbg1:labelval..%s\ndbg:defval..%s\n",labelval,defval);*/
   
+  while (!dlgfree){
+  	while (gtk_events_pending()) gtk_main_iteration();
+	usleep(500);
+  }
   dl.result = 0;
   dl.type = type;
   dl.entry = NULL;
   dl.data = defval;
 
   dl.top = gtk_dialog_new ();
-  gtk_window_position (GTK_WINDOW (dl.top), GTK_WIN_POS_CENTER);
+  dlgfree=FALSE;
+  gtk_window_position (GTK_WINDOW (dl.top), GTK_WIN_POS_MOUSE);
   gtk_window_set_modal (GTK_WINDOW (dl.top), TRUE);
   box = gtk_hbox_new (FALSE, FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (box), 5);
@@ -311,9 +327,10 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
       /* SJB ok = gtk_button_new_with_label (_("Continue")); */
       ok = make_button_with_accel(_("_Continue"), accelgrp);
     }
-    GTK_WIDGET_SET_FLAGS (ok, GTK_CAN_DEFAULT);
+    if (!def_cancel) GTK_WIDGET_SET_FLAGS (ok, GTK_CAN_DEFAULT);
     gtk_box_pack_start (GTK_BOX (button_box), ok, TRUE, FALSE, 0);
     gtk_widget_set_usize (ok, B_WIDTH, B_HEIGHT);
+    if (!def_cancel) gtk_widget_grab_default (ok);
     
     if (type &(DLG_ENTRY_EDIT | DLG_COMBO)) {
       	    gtk_signal_connect (GTK_OBJECT (ok), "clicked", GTK_SIGNAL_FUNC (on_ok_combo), 
@@ -326,14 +343,6 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
     gtk_signal_connect (GTK_OBJECT (ok), "key_press_event", GTK_SIGNAL_FUNC (on_key_press), 
 	    (gpointer) cancel);
   }
-  if ((type & DLG_SKIP) && !(type & (DLG_ENTRY_EDIT | DLG_COMBO )))
-  {
-    skip = gtk_button_new_with_label (_("Skip"));
-    GTK_WIDGET_SET_FLAGS (skip, GTK_CAN_DEFAULT);
-    gtk_box_pack_start (GTK_BOX (button_box), skip, TRUE, FALSE, 0);
-    gtk_signal_connect (GTK_OBJECT (skip), "clicked", GTK_SIGNAL_FUNC (on_ok), (gpointer) ((long) DLG_RC_SKIP));
-    gtk_widget_set_usize (skip, B_WIDTH, B_HEIGHT);
-  }
   if (type & (DLG_CANCEL | DLG_NO))
   {
     if (type & DLG_CANCEL)
@@ -346,11 +355,19 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
       /* SJB cancel = gtk_button_new_with_label (_("No")); */
       cancel = make_button_with_accel(_("_No"), accelgrp);
     }
-    GTK_WIDGET_SET_FLAGS (cancel, GTK_CAN_DEFAULT);
+    if (def_cancel) GTK_WIDGET_SET_FLAGS (cancel, GTK_CAN_DEFAULT);
     gtk_box_pack_start (GTK_BOX (button_box), cancel, TRUE, FALSE, 0);
     gtk_signal_connect (GTK_OBJECT (cancel), "clicked", GTK_SIGNAL_FUNC (on_cancel), (gpointer) ((long) DLG_RC_CANCEL));
     gtk_widget_set_usize (cancel, B_WIDTH, B_HEIGHT);
-    gtk_widget_grab_default (cancel);
+    if (def_cancel) gtk_widget_grab_default (cancel);
+  }
+  if ((type & DLG_SKIP) && !(type & (DLG_ENTRY_EDIT | DLG_COMBO )))
+  {
+    skip = gtk_button_new_with_label (_("Skip"));
+    if (!ok && !cancel) GTK_WIDGET_SET_FLAGS (skip, GTK_CAN_DEFAULT);
+    gtk_box_pack_start (GTK_BOX (button_box), skip, TRUE, FALSE, 0);
+    gtk_signal_connect (GTK_OBJECT (skip), "clicked", GTK_SIGNAL_FUNC (on_ok), (gpointer) ((long) DLG_RC_SKIP));
+    gtk_widget_set_usize (skip, B_WIDTH, B_HEIGHT);
   }
   if ((type & DLG_ALL) && !(type & (DLG_ENTRY_EDIT | DLG_COMBO )))
 
@@ -358,7 +375,7 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
     /* SJB all = gtk_button_new_with_label (_("All")); */
     all = make_button_with_accel(_("_All"), accelgrp);
     
-    GTK_WIDGET_SET_FLAGS (all, GTK_CAN_DEFAULT);
+    if (!ok && !cancel) GTK_WIDGET_SET_FLAGS (all, GTK_CAN_DEFAULT);
     gtk_box_pack_start (GTK_BOX (button_box), all, TRUE, FALSE, 0);
     gtk_signal_connect (GTK_OBJECT (all), "clicked", GTK_SIGNAL_FUNC (on_ok), (gpointer) ((long) DLG_RC_ALL));
     gtk_widget_set_usize (all, B_WIDTH, B_HEIGHT);
@@ -368,14 +385,15 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
     /* SJB close = gtk_button_new_with_label (_("Close")); */
     close = make_button_with_accel(_("_Close"), accelgrp);
     
-    GTK_WIDGET_SET_FLAGS (close, GTK_CAN_DEFAULT);
+    if (!ok && !cancel) GTK_WIDGET_SET_FLAGS (close, GTK_CAN_DEFAULT);
     gtk_box_pack_start (GTK_BOX (button_box), close, TRUE, FALSE, 0);
     gtk_signal_connect (GTK_OBJECT (close), "clicked", GTK_SIGNAL_FUNC (on_ok), (gpointer) ((long) DLG_RC_OK));
   }
 
   if (type & DLG_ENTRY_VIEW)
   {
-    dl.entry = gtk_entry_new_with_max_length (DLG_MAX);
+    dl.entry = gtk_entry_new ();
+    gtk_entry_set_max_length ((GtkEntry *)dl.entry,DLG_MAX);
     gtk_widget_set_usize (dl.entry, E_WIDTH, -1);
     gtk_entry_set_editable (GTK_ENTRY (dl.entry), FALSE);
     /* do not uncomment the following line. Some versions
@@ -385,9 +403,10 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
   else if (type & DLG_ENTRY_EDIT)
   {
     /*fprintf(stderr,"dbg2:labelval..%s\ndbg:defval..%s\n",labelval,defval);*/
-    dl.entry = gtk_entry_new_with_max_length (DLG_MAX);
+    dl.entry = gtk_entry_new ();
+    gtk_entry_set_max_length ((GtkEntry *)dl.entry,DLG_MAX);
     gtk_widget_set_usize (dl.entry, E_WIDTH, -1);
-    GTK_WIDGET_SET_FLAGS (dl.entry, GTK_CAN_DEFAULT);
+    if (!ok && !cancel) GTK_WIDGET_SET_FLAGS (dl.entry, GTK_CAN_DEFAULT);
     gtk_drag_dest_set (dl.entry, GTK_DEST_DEFAULT_ALL, target_table, NUM_TARGETS, GDK_ACTION_COPY);
     gtk_signal_connect (GTK_OBJECT (dl.entry), "drag_data_received", GTK_SIGNAL_FUNC (on_drag_data_received), NULL);
     gtk_widget_grab_focus (dl.entry);
@@ -399,7 +418,7 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
     gtk_combo_disable_activate (GTK_COMBO (combo));
     gtk_combo_set_case_sensitive (GTK_COMBO (combo), 1);
     dl.entry = GTK_COMBO (combo)->entry;
-    GTK_WIDGET_SET_FLAGS (dl.entry, GTK_CAN_DEFAULT);
+    if (!ok && !cancel) GTK_WIDGET_SET_FLAGS (dl.entry, GTK_CAN_DEFAULT);
     gtk_drag_dest_set (dl.entry, GTK_DEST_DEFAULT_ALL, target_table, NUM_TARGETS, GDK_ACTION_COPY);
     gtk_signal_connect (GTK_OBJECT (dl.entry), "activate", GTK_SIGNAL_FUNC (on_ok_combo), (gpointer) ((long) DLG_RC_OK));
     gtk_signal_connect (GTK_OBJECT (dl.entry), "drag_data_received", GTK_SIGNAL_FUNC (on_drag_data_received), NULL);
@@ -442,7 +461,7 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
     if (type & DLG_ENTRY_EDIT)
       gtk_entry_select_region (GTK_ENTRY (dl.entry), 0, -1);
   }
-  /*gtk_signal_connect (GTK_OBJECT (dl.top), "destroy", GTK_SIGNAL_FUNC (on_cancel), (gpointer) ((long) DLG_RC_DESTROY));*/
+  gtk_signal_connect (GTK_OBJECT (dl.top), "destroy", GTK_SIGNAL_FUNC (on_destroy), (gpointer) ((long) DLG_RC_DESTROY));
   gtk_signal_connect (GTK_OBJECT (dl.top), "key_press_event", GTK_SIGNAL_FUNC (on_key_press), (gpointer) cancel);
   gtk_widget_show_all (dl.top);
 
@@ -453,9 +472,5 @@ long xf_dlg_new (GtkWidget *parent,const char *labelval, char *defval, void *dat
   return (long)(dl.result);
 }
 
-/* function for deprecated calls: */
-gint dlg_new (char *labelval, char *defval, void *data, int type){
-	return (xf_dlg_new(NULL,labelval,defval,data,type));
-}
 
 
