@@ -7,6 +7,8 @@
  * Olivier Fourdan (fourdan@xfce.org)
  * Heavily modified as part of the Xfce project (http://www.xfce.org)
  *
+ * Edscott Wilson Garcia Copyright 2001-2002
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -25,7 +27,10 @@
 #ifndef __GTK_EXEC_H__
 #define __GTK_EXEC_H__
 
+int xf_dlg_open_with (GtkWidget *ctree,char *xap, char *defval, char *file);
+/* depredated (use xf_dlg_open_with instead): */
 int dlg_open_with (char *xap, char *defval, char *file);
-void free_app_list (void);
-#define dlg_execute(x,d) dlg_open_with(x, d, NULL)
+GList *free_app_list (void);
+/* deprected: #define dlg_execute(x,d) dlg_open_with(x, d, NULL)*/
+#define xf_dlg_execute(p,x,d) xf_dlg_open_with(p,x, d, NULL)
 #endif
