@@ -7,6 +7,8 @@
  * Olivier Fourdan (fourdan@xfce.org)
  * Heavily modified as part of the Xfce project (http://www.xfce.org)
  *
+ * Edscott Wilson Garcia Copyright 2001-2002
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -41,6 +43,8 @@ typedef struct
   off_t size;
 }
 fprop;
+/* dlg_prop is deprecated. use xf_dlg_prop instead */
 
+int xf_dlg_prop (GtkWidget *parent,char *path, fprop * prop, int multi);
 int dlg_prop (char *path, fprop * prop, int multi);
 #endif
