@@ -7,7 +7,7 @@
  * Olivier Fourdan (fourdan@xfce.org)
  * Heavily modified as part of the Xfce project (http://www.xfce.org)
  *
- * Edscott Wilson Garcia Copywrite 2001 for Xfce project.
+ * Edscott Wilson Garcia Copywrite 2001-2002 for Xfce project.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,8 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-
+#include <unistd.h>
+#include <signal.h>
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
@@ -45,6 +46,9 @@
 #  include "dmalloc.h"
 #endif
 
+extern void cleanup_tmpfiles(void);
+extern GtkWidget *io_parent;
+
 extern char **environ;
 
 /*
@@ -126,44 +130,57 @@ io_can_write_to_parent (char *file)
 
 /*
  */
+
+pid_t io_pid;
 int
-io_system (char *cmd)
+io_system (char **argv,GtkWidget *parent)
 {
   int pid, status;
   int nulldev;
 
-  if (cmd == NULL)
-    return (1);
+  if (!argv[0]) return (1);
+  io_pid=getpid();
+  io_parent=parent;
   pid = fork ();
-  if (pid == -1)
-    return (-1);
-  if (pid == 0)
-  {
-    char *argv[4];
-    /* child */
-    argv[0] = "sh";
-    argv[1] = "-c";
-    argv[2] = cmd;
-    argv[3] = NULL;
-
+  if (pid == -1) return (-1);
+  if (pid==0) { /* child process */
+    /*printf("dbg:%s %s %s %s\n",argv[0],argv[1],argv[2],argv[3]);*/
     /* The following is to avoid X locking when executing 
        terminal based application that requires user input */
     if ((nulldev = open ("/dev/null", O_RDWR)))
     {
       close (0);
       dup (nulldev);
+#if 0
+      /* keep stdout and stderr open for diagnostics */
       close (1);
       dup (nulldev);
       close (2);
       dup (nulldev);
-    }
+#endif
+    } else _exit (127);
 
-    if (execve ("/bin/sh", argv, environ) == -1)
-      perror ("/bin/sh");
+    /* second fork instead of using /bin/sh,
+     * this enables error processing 
+     * (sometimes, at least :-0*/
+    if (fork ()==0) { 
+       /*printf("dbg:by direct...\n");*/
+       if (execve (argv[0], argv, environ) == -1) {
+           FILE *mess;
+	   if (errno != ENOEXEC) execvp (argv[0], argv); 
+	   mess=fopen("/tmp/xftree.USR1","w");
+	   if (mess){
+	       fprintf(mess,"%s: %s\n",argv[0],strerror(errno));
+	       fclose(mess);
+	       kill(io_pid,SIGUSR1);
+	   }
+	   usleep(50000);
+	   /*perror (argv[0]);*/
+       }
+    }
     _exit (127);
   }
-  do
-  {
+  while (1){
     if (waitpid (pid, &status, 0) == -1)
     {
       if (errno != EINTR)
@@ -172,7 +189,6 @@ io_system (char *cmd)
     else
       return status;
   }
-  while (1);
 }
 
 /*
@@ -181,6 +197,7 @@ static void
 sig_seg (int signum)
 {
   fprintf (stderr, "segmention fault (pid=%d)\n", (int) getpid ());
+  cleanup_tmpfiles();
   exit (127);
 }
 
