@@ -4,7 +4,7 @@
  *              some of Rasca's ideas remain, and the input/output is
  *              enhanced (ewg).
  * 
- * copywrite 1999-2001 under GNU/GPL
+ * copywrite 1999-2002 under GNU/GPL
  * Edscott Wilson Garcia, 
  * Olivier Fourdan, 
  * Rasca, Berlin
@@ -41,6 +41,7 @@
 #include <dirent.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/wait.h>
 #include <fcntl.h>
 #include <glob.h>
 #include <X11/Xlib.h>
@@ -106,7 +107,7 @@
 
 
 #define CHILD_FILE_LENGTH 64
-#define MAX_LINE_SIZE (sizeof(char)*256)
+#define MAX_LINE_SIZE (sizeof(char)*1024)
 static char child_file[CHILD_FILE_LENGTH];
 static int  child_mode;
 static int total_files=0;
@@ -128,18 +129,87 @@ static gboolean force_override=FALSE;
 static int internal_rw_file(char *target,char *source,off_t size);
 static int rwStderr (int n, void *data);
 static int rwStdout (int n, void *data);
-static void rwForkOver (void);
+static void rwForkOver (pid_t pid);
 static void set_innerloop(gboolean state);
 static int process_error(int code);
 static void cb_cancel (GtkWidget * w, void *data);
 static gboolean all_recursive=FALSE;
 
+char *src_host=NULL;
+
 /* tmo */
 #define XTIME_IT
 #ifdef TIME_IT
 time_t tiempo;
 #endif
 
+
+int rsync(GtkCTree *ctree,char *src,char *tgt){
+      char *cmd,*argv[6],*c;
+      int status;
+      pid_t pid;
+      cfg *win;
+
+      win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+      
+      if (!sane("ssh")) {
+	      xf_dlg_error(win->top,"Not found","ssh");
+	      return FALSE;
+      }
+      
+      if (win->preferences & USE_RSYNC) {
+	      if (!sane("rsync")) {
+		      xf_dlg_error(win->top,"Not found","rsync");
+		      return FALSE;
+	      }
+	      c = "rsync -av --rsh=ssh";
+      } else {
+	      if (!sane("scp")){
+		      xf_dlg_error(win->top,"Not found","scp");
+		      return FALSE;
+	      }
+	      c = "scp -pvr";
+      }
+      
+      cmd=(char *)malloc(strlen("echo \"%%\";")
+		      +2*strlen(src_host)+2*strlen(src)+2*strlen(tgt)
+		       +2*strlen(c)+2*strlen("%% %%:%% %%")+1);
+      if (!cmd) return FALSE;
+      sprintf(cmd,"echo \"%s %s:%s %s\";%s %s:%s %s",
+		      c,src_host,src,tgt,
+		      c,src_host,src,tgt);
+      /*printf("dbg: %s\n",u->url);*/
+      /*printf("dbg: %s\n",cmd);*/
+      argv[0]=TERMINAL;
+      argv[1]="-e";
+      argv[2]="/bin/sh";
+      argv[3]="-c";
+      argv[4]=cmd;
+      argv[5]=0;
+      cursor_wait (GTK_WIDGET (ctree));
+      pid = fork ();
+      if (pid == -1) {
+        g_free(cmd);
+        cursor_reset (GTK_WIDGET (ctree));    
+	return FALSE;
+      }
+      if (pid==0) { /* child process */
+       	execvp (argv[0], argv); 
+        /*perror (argv[0]);*/
+	_exit(123);
+      }
+      g_free(cmd);
+
+      do {
+	while (gtk_events_pending()) gtk_main_iteration();
+      } while (!waitpid(pid,&status,WNOHANG));
+      cursor_reset (GTK_WIDGET (ctree));    
+      update_timer (GTK_CTREE (ctree));
+      return TRUE;
+}
+
+
+
 gboolean on_same_device(void){return same_device;}
 
 /*
@@ -172,6 +242,7 @@ static int process_error(int code){
 	  case RW_ERROR_OPENING_TGT:
 		  txt=fork_target;
 		  message=strerror(errno); 
+		  /*return code; */
 		  break;
 	  case RW_ERROR_TOO_FEW:
 		  txt=fork_target;
@@ -227,7 +298,7 @@ static int process_error(int code){
 		  sprintf(allfile,"%s.all",child_file);
 		  allF=fopen(allfile,"r");
 		  if (allF) {doall=TRUE;fclose(allF);}
-        	  free(allfile);
+        	  g_free(allfile);
 		}
 		if (!doall) {
 		  FILE *hold;
@@ -255,7 +326,7 @@ static int process_error(int code){
 
 char *mktgpath(entry *ten,entry *sen){
   static char *target=NULL;
-  if (target) free(target);
+  if (target) g_free(target);
   target=(char *)malloc((strlen(ten->path)+strlen(sen->label)+2)*sizeof(char));
   if (!target) target="malloc error: mktgpath()\n";
   
@@ -279,28 +350,50 @@ void set_override(gboolean state)
 
 static int nitems;
 
-static char *randomTmpName(void){
+char *randomTmpName(char *ext){
     static char *fname=NULL;
     int fnamelen;
-    if (fname) free(fname);
-    fnamelen=strlen("/tmp/xftree.9999.tmp")+1;
+    if (fname) g_free(fname);
+    if (ext==NULL) fnamelen=strlen("/tmp/xftree.XXXXXX")+1;
+    else fnamelen=strlen("/tmp/xftree.XXXXXX")+strlen(ext)+2;
+    fname = (char *)malloc(sizeof(char)*(fnamelen));
+    if (!fname) return NULL;
+    sprintf(fname,"/tmp/xftree.XXXXXX");
+    close(mkstemp(fname));
+    if (ext) {
+	    unlink(fname);
+	    strcat(fname,"."); strcat(fname,ext);
+    }
+    return fname;
+}
+
+/*char *randomTmpName(char *ext){
+    static char *fname=NULL;
+    int fnamelen;
+    long long id;
+    if (ext==NULL) ext="tmp";
+    if (fname) g_free(fname);
+    id=random()*(9999.0/RAND_MAX);
+    while (id > 9999) id /= 2; 
+    fnamelen=strlen("/tmp/xftree.9999.")+strlen(ext)+1;
     srandom(time(NULL));
     fname = (char *)malloc(sizeof(char)*(fnamelen));
     if (!fname) return NULL;
-    sprintf(fname,"/tmp/xftree.%d.tmp",(int)((9999.0/RAND_MAX)*random()));
+    sprintf(fname,"/tmp/xftree.%lld.%s",id,ext);
     return fname;
-}
+}*/
 
 static char *SimpleTmpList(GtkWidget *parent,char *tgt,char *src){
     static char *fname=NULL;
     FILE *tmpfile;
-    if ((fname=randomTmpName())==NULL) return NULL;
+    if ((fname=randomTmpName(NULL))==NULL) return NULL;
     if ((tmpfile=fopen(fname,"w"))==NULL) return NULL;
-    fprintf(tmpfile,"%d:%s:%s\n",TR_COPY,src,tgt);
+    fprintf(tmpfile,"%d\t%s\t%s\n",TR_COPY,src,tgt);
     fclose(tmpfile);
     return fname;
 }
 
+
 char  *CreateTmpList(GtkWidget *parent,GList *list,entry *t_en){
     char *target;   
     FILE *tmpfile;
@@ -309,7 +402,7 @@ char  *CreateTmpList(GtkWidget *parent,GList *list,entry *t_en){
     entry *s_en;
     
     nitems=0;
-    if ((fname=randomTmpName())==NULL) return NULL;
+    if ((fname=randomTmpName(NULL))==NULL) return NULL;
     if ((tmpfile=fopen(fname,"w"))==NULL) return NULL;
     same_device=TRUE;
     tar_extraction=FALSE;
@@ -338,7 +431,7 @@ char  *CreateTmpList(GtkWidget *parent,GList *list,entry *t_en){
 				t_stat.st_dev=113;
 			}
 		  }
-		  free(route);  
+		  g_free(route);  
 		}
 	}
 
@@ -355,11 +448,12 @@ char  *CreateTmpList(GtkWidget *parent,GList *list,entry *t_en){
 			 unlink (fname);
 			 return NULL;
 		default: 
-			 if ((u->type != URI_LOCAL)||(u->type != URI_FILE)) same_device=FALSE;
-			 else if (s_en->st.st_dev != t_stat.st_dev) same_device=FALSE;
+			 /*if ((u->type != URI_LOCAL)||(u->type != URI_FILE)) same_device=FALSE; else */
+			 if (s_en->st.st_dev != t_stat.st_dev) same_device=FALSE;
+			 
 			 nitems++;
-			 fprintf(tmpfile,"%d:%s:%s\n",u->type,s_en->path,target);
-			 /*fprintf(stderr,"dbg:%d:%s:%s\n",u->type,s_en->path,target);*/
+			 fprintf(tmpfile,"%d\t%s\t%s\n",u->type,s_en->path,target);
+			 /*fprintf(stderr,"dbg:%d\t%s\t%s\n",u->type,s_en->path,target);*/
 			 fflush(NULL);
 			 break;
 	} 
@@ -385,7 +479,7 @@ static int ok_input(GtkWidget *parent,char *target,entry *s_en){
   gboolean target_exists=TRUE;
   
   source=s_en->path;
-  if (stat (target, &t_stat) < 0) {
+  if (lstat (target, &t_stat) < 0) {
 	if (errno != ENOENT) return xf_dlg_error_continue (parent,target, strerror (errno));
 	else target_exists=FALSE;
   }
@@ -416,7 +510,7 @@ static int ok_input(GtkWidget *parent,char *target,entry *s_en){
    if (S_ISCHR(s_en->st.st_mode)||S_ISBLK(s_en->st.st_mode)){
 	return xf_dlg_error_continue (parent,source,_("Can't copy device file") );
    }
-   if (S_ISBLK(s_en->st.st_mode)){
+   if (S_ISSOCK(s_en->st.st_mode)){
 	return xf_dlg_error_continue (parent,source,_("Can't copy socket") );
    }
   }
@@ -425,7 +519,7 @@ static int ok_input(GtkWidget *parent,char *target,entry *s_en){
   /* check for overwrite, both files and directories */
   if ((target_exists) && (!force_override)) {
 	int rc;
-        rc=xf_dlg_new(parent,override_txt(target,s_en->path),NULL,NULL,DLG_CANCEL|DLG_OK|DLG_SKIP|DLG_ALL);
+        rc=xf_dlg_new(parent,override_txt(target,s_en->path),NULL,NULL,DLG_CANCEL|DLG_OK|DLG_SKIP|DLG_ALL,1);
         if (rc == DLG_RC_SKIP) 	 return DLG_RC_SKIP;
         if (rc == DLG_RC_CANCEL) return DLG_RC_CANCEL;
         if (rc == DLG_RC_ALL)	 {
@@ -440,7 +534,8 @@ static int ok_input(GtkWidget *parent,char *target,entry *s_en){
 static gboolean SubChildTransfer(char *target,char *source){
 	struct stat s_stat,t_stat;
 	int i,rc;
-	if (stat(target,&t_stat)<0){  /* follow link stat() */
+	
+	if (stat(target,&t_stat)<0){  /* follow link for target: stat() */
 		char *route,*end;
 		route=(char *)malloc(strlen(target)+1);
 		if (route) {
@@ -450,20 +545,45 @@ static gboolean SubChildTransfer(char *target,char *source){
 		    else end[0]=0;
 		    stat(route,&t_stat);
 		  }
-		  free(route);
+		  g_free(route);
 		}
 	}
-	lstat(source,&s_stat); /* stat() the link itself */
-	
 	/* do the link business before going recursive:
 	 * (link directories, not contents) */
+	/* (historical, TR_LINK should fall to DirectTransfer) */
 	if (child_mode & TR_LINK){ 
+	  printf("xftree:Calling IndirectTransfer for TR_LINK is obsolete (but works)\n");
 	  if (symlink (source, target) < 0) {
 	     return process_error(RW_ERROR_WRITING_TGT);
 	  } else return TRUE;
 	}
-	
-	
+
+	lstat(source,&s_stat); /* stat() the link itself */
+
+/* what if we find a symlink in our path? */       	
+	if (S_ISLNK(s_stat.st_mode)) {
+	  char *src_lnk;
+	  int len;
+	  struct stat st;
+	  lstat(source,&st);
+	  src_lnk=(char *)malloc(st.st_size+1);
+	  if (!src_lnk) return TRUE;
+	  len = readlink (source, src_lnk, st.st_size);
+	  if (len <= 0) {fprintf(stderr,"xftree:%s\n",strerror(errno));return (TRUE); }
+      	  src_lnk[len] = 0;
+	  if (symlink (src_lnk, target) == -1){
+	     g_free(src_lnk);
+	     return process_error(RW_ERROR_WRITING_TGT);
+	  }
+	  g_free(src_lnk);
+      	  if (child_mode & TR_MOVE) {
+		  if (unlink (source) == ERROR) {
+	            return process_error(RW_ERROR_WRITING_SRC);
+		  }
+	  }
+	  return (TRUE);
+	}
+
 	/* recursivity, if src is directory:
 	 * 1- mkdir tgt/src
 	 * 2- glob src
@@ -504,7 +624,7 @@ static gboolean SubChildTransfer(char *target,char *source){
 		  
 		  newtarget=(char *)malloc(strlen(target)+strlen(src)+3);
 		  if (!newtarget) {
-			  free(globstring);
+			  g_free(globstring);
 			  globfree(&dirlist);
 			  return FALSE; /* fatal error */
 		  }
@@ -512,14 +632,14 @@ static gboolean SubChildTransfer(char *target,char *source){
 		  /*fprintf(stderr,"dbg:dirlist: %s\n",dirlist.gl_pathv[i]);*/
 		  if (!SubChildTransfer(newtarget,dirlist.gl_pathv[i])){
 			/*fprintf(stderr,"dbg:dirlisterror: %s\n",dirlist.gl_pathv[i]);*/
-	  		free(globstring);
-		 	free(newtarget);
+	  		g_free(globstring);
+		 	g_free(newtarget);
 			globfree(&dirlist);
 			return FALSE; /* fatal error */
 		  }
-		  free(newtarget);
+		  g_free(newtarget);
 		}
-		free(globstring);
+		g_free(globstring);
 		globfree(&dirlist);
 		
 		/* remove old directory (rmdir should fail if any interior move failed) */
@@ -553,7 +673,8 @@ static gboolean SubChildTransfer(char *target,char *source){
 	 *  in the popup are the same thing for the time being) */	
         if (!rc) return FALSE; /* user intervention */	
 	 
-	if (!(rc & (RW_ERROR_WRITING_TGT|RW_ERROR_OPENING_TGT))) { /* NO ERRORS */
+	if (!(rc & (RW_ERROR_WRITING_TGT|RW_ERROR_OPENING_TGT))) { 
+	   	
 	  if ((child_mode & TR_MOVE) && (unlink(source) < 0)) {
 	   return process_error(RW_ERROR_WRITING_SRC);/* user intervention */
 	  }
@@ -597,16 +718,16 @@ static void ChildTransfer(void){
 	child_path_number=0;
 	while (!feof(tfile)&&fgets(line,MAX_LINE_SIZE-1,tfile)){
 		line[MAX_LINE_SIZE-1]=0;
-		type=atoi(strtok(line,":"));
+		type=atoi(strtok(line,"\t"));
 		source=strtok(NULL,"\n");
-		target=strrchr(source,':')+1;
-		*(strrchr(source,':'))=0;
+		target=strrchr(source,'\t')+1;
+		*(strrchr(source,'\t'))=0;
 		switch (type) {
 		  case URI_LOCAL:
 		  case URI_FILE:
-			/*source=strtok(NULL,":");target=strtok(NULL,"\n");*/
+			/*source=strtok(NULL,"\t");target=strtok(NULL,"\n");*/
 			/*fprintf(stderr,"dbg:(%d)%s->%s\n",type,source,target);*/
-			fprintf(stdout,"child:tgt-src:%s:%s\n",target,source);
+			fprintf(stdout,"child:tgt-src:%s\t%s\n",target,source);
 			fprintf(stdout,"child:item:%d\n",child_path_number++);
 			if (!SubChildTransfer(target,source)) goto cut_out;
 			break;
@@ -625,12 +746,16 @@ static void ChildTransfer(void){
 	}
 cut_out:
 	fclose(tfile);
-	free (line);
+	g_free (line);
 	fflush(NULL);
 	_exit(123);
 }
 
 static GtkWidget *count_label;
+static gboolean count_cancelled;
+static GtkWidget *countW=NULL;
+
+static int countT;
 
 static int SubParentCount(char *source){
 	struct stat s_stat;
@@ -645,34 +770,32 @@ static int SubParentCount(char *source){
 		if (!globstring) return FALSE; /* fatal error */
 		sprintf(globstring,"%s/*",source);
 		/* glob source dir */
+		{
+		 char count_txt[32];
+		 sprintf(count_txt,"%d",countT);
+		 if (!count_cancelled) gtk_label_set_text (GTK_LABEL (count_label),count_txt );
+		 while (gtk_events_pending()) gtk_main_iteration();
+ 			 gdk_flush();
+		}
 		if (glob (globstring, GLOB_ERR | GLOB_TILDE | GLOB_PERIOD, 
 					NULL, &dirlist) != 0) {
 			return 0;
 		}
   		else {
-		 char *count_txt = NULL;
 		 count = 0;
-		 count_txt=(char *)malloc(strlen(source)+strlen(" --> ")+32);
-		 if (count_txt != NULL) {
-			 char *short_txt;
-			 if (strstr(source,"/")==NULL) short_txt=source;
-			 else short_txt=strrchr(source,'/')+1;
-			 if (*short_txt==0) short_txt=source;
-			 sprintf(count_txt,"%s --> %d",short_txt,count);
-			 gtk_label_set_text (GTK_LABEL (count_label),count_txt );
-			 free(count_txt);
-			 while (gtk_events_pending()) gtk_main_iteration();
- 			 gdk_flush();
-		 }
+		 countT += (dirlist.gl_pathc-3);
 		 for (i = 0; i < dirlist.gl_pathc; i++) {
 		  if (strstr(dirlist.gl_pathv[i],"/")) src=strrchr(dirlist.gl_pathv[i],'/')+1;
 		  else src = dirlist.gl_pathv[i];
 		  if ((strcmp(src,".")==0)||(strcmp(src,"..")==0)) continue;
+		  if (count_cancelled) {globfree(&dirlist); return 0; }
 		  count += SubParentCount(dirlist.gl_pathv[i]);
+		  	  
 		  /*fprintf(stdout,"dbg:%s --> %d\n",dirlist.gl_pathv[i],count);*/
 		 }
+		 globfree(&dirlist);
 		}
-		free(globstring);		
+		g_free(globstring);		
 		return count;		
 	}
        	/* not a directory entry, only one file here */
@@ -683,50 +806,74 @@ static gint ParentCount(gpointer data){
 	FILE *tfile;
 	char *line,*source;
 	int type;
-	total_files=0;
+	countT=total_files=0;
 	line=(char *)malloc(MAX_LINE_SIZE);
 	if (!line) goto count_done; 
 	tfile=fopen(child_file,"r");
 	if (!tfile) {
-		free(line);
+		g_free(line);
 		goto count_done; 
 	}
-	while (fgets(line,MAX_LINE_SIZE-1,tfile) && !feof(tfile)){
+	while (fgets(line,MAX_LINE_SIZE-1,tfile) && !feof(tfile) && !count_cancelled){
 		/*fprintf(stderr,"dbg:%s\n",line);*/
-		type=atoi(strtok(line,":"));
-		source=strtok(NULL,":");
-		if ((type == URI_LOCAL)||(type == URI_FILE))
+		type=atoi(strtok(line,"\t"));
+		source=strtok(NULL,"\t");
+		if ((type == URI_LOCAL)||(type == URI_FILE)){
+			if (count_cancelled) goto count_done; 
 			total_files += SubParentCount(source);
+		}
 		else total_files++;
+		
 		/*fprintf(stdout,"dbg:%s --> %d\n",source,total_files);*/
 	}
 	fclose(tfile);
-	free (line);
+	g_free (line);
 count_done:
 	gtk_main_quit();
 	return FALSE;
 }
+
+
+static void cb_count_destroy(GtkWidget *widget,gpointer data){
+	count_cancelled=TRUE; /* for user destruction */
+	countW=NULL;
+}
+static void cb_count_cancel(GtkWidget *widget,gpointer data){
+	count_cancelled=TRUE; /* for user destruction */
+	gtk_widget_destroy(countW);
+	countW=NULL;
+}
+
 static void count_window(GtkWidget *parent){
-  GtkWidget *countW;
+	GtkWidget *cancel;
   countW=gtk_dialog_new ();
   
-  gtk_window_position (GTK_WINDOW (countW), GTK_WIN_POS_CENTER);
+  gtk_window_position (GTK_WINDOW (countW), GTK_WIN_POS_MOUSE);
   gtk_window_set_modal (GTK_WINDOW (countW), TRUE);
   count_label = gtk_label_new ( _("Counting files"));
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (countW)->vbox), count_label, TRUE, TRUE, 3);
   
   count_label = gtk_label_new ( ".........................................");
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (countW)->action_area), count_label, TRUE, TRUE, 3);
-  gtk_widget_show(count_label);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (countW)->vbox), count_label, TRUE, TRUE, 3);
+
+  cancel=gtk_button_new_with_label(_("Cancel"));
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (countW)->action_area), cancel, FALSE, FALSE, 3);
+  gtk_signal_connect (GTK_OBJECT (cancel), "clicked", GTK_SIGNAL_FUNC (cb_count_cancel), NULL);
+  
   gtk_widget_realize (countW);
+  
   if (preferences&SMALL_DIALOGS) gdk_window_set_decorations (countW->window,GDK_DECOR_BORDER);
   if (parent) gtk_window_set_transient_for (GTK_WINDOW (countW), GTK_WINDOW (parent)); 
+  gtk_signal_connect (GTK_OBJECT (countW), "destroy", GTK_SIGNAL_FUNC (cb_count_destroy), NULL);
   gtk_widget_show_all(countW);
   gdk_flush();
   /* add timeout */
   gtk_timeout_add (260, (GtkFunction) ParentCount, NULL);
   gtk_main();
-  gtk_widget_destroy(countW);
+  if (countW) {
+	  gtk_widget_destroy(countW);
+	  count_cancelled=FALSE;
+  }
   return ;
 }
 
@@ -745,7 +892,9 @@ gboolean IndirectTransfer(GtkWidget *ctree,int mode,char *tmpfile) {
 	child_file_number=0;
 	child_mode = mode;
  	/* count total files to transfer */
-	count_window(win->top);
+	count_cancelled=FALSE;
+	if (mode != TR_LINK) count_window(win->top);
+	if (count_cancelled) return TRUE;
 	/*fprintf(stderr,"dbg:Total files=%d\n",total_files);*/
  	if (!cpy_dlg) cpy_dlg=show_cpy(win->top,TRUE,mode);
         /*set_show_cpy_bar(0,nitems);*/
@@ -770,12 +919,13 @@ gboolean IndirectTransfer(GtkWidget *ctree,int mode,char *tmpfile) {
        return TRUE;
 }
 
-/* function for non forked move on same device */
+/* function for non forked move on same device, or symlink too */
 gboolean DirectTransfer(GtkWidget *ctree,int mode,char *tmpfile) {
 	FILE *tfile;
 	char *line,*source,*target;
 	int type,i;
 	cfg *win;
+	struct stat st;
     	/*fprintf(stderr,"dbg: at DirectTransfer\n");*/
         
 	win = gtk_object_get_user_data (GTK_OBJECT (ctree));
@@ -792,10 +942,43 @@ gboolean DirectTransfer(GtkWidget *ctree,int mode,char *tmpfile) {
 	i=0;
 	while (!feof(tfile)&&fgets(line,MAX_LINE_SIZE-1,tfile)){
 		line[MAX_LINE_SIZE-1]=0;
-		type=atoi(strtok(line,":"));
+		type=atoi(strtok(line,"\t"));
 		source=strtok(NULL,"\n");
-		target=strrchr(source,':')+1;
-		*(strrchr(source,':'))=0;
+		target=strrchr(source,'\t')+1;
+		*(strrchr(source,'\t'))=0;
+		lstat(source,&st);
+		if (S_ISLNK(st.st_mode)) {
+	  	  char *src_lnk;
+ 	  	  int len;
+	 	  struct stat st;
+		  lstat(source,&st);
+		  src_lnk=(char *)malloc(st.st_size+1);
+		  if (!src_lnk) continue;
+		  len = readlink (source, src_lnk, st.st_size);
+		  if (len <= 0) {
+			  if (xf_dlg_error_continue(win->top,strerror(errno),source)==DLG_RC_CANCEL)
+			  {
+		            g_free(src_lnk);
+			    continue;
+			  }
+		  }
+	      	  src_lnk[len] = 0;
+		  if (symlink (src_lnk, target) == -1){
+		     if (xf_dlg_error_continue(win->top,strerror(errno),target)==DLG_RC_CANCEL){
+		        g_free(src_lnk);
+ 		        continue;
+		     }
+		  }
+		  g_free(src_lnk);
+	      	  if (mode & TR_MOVE) {
+		   if (unlink (source) == ERROR) {
+	             if (xf_dlg_error_continue(win->top,strerror(errno),source)==DLG_RC_CANCEL)
+ 		        continue;
+		   }
+		  }
+ 		  continue;
+		}
+		
 		if (tar_extraction){
 			char *o_src;
 			o_src=g_strdup(source);
@@ -805,14 +988,22 @@ gboolean DirectTransfer(GtkWidget *ctree,int mode,char *tmpfile) {
 			if (mode==TR_MOVE) tar_delete((GtkCTree *)ctree,o_src);
 			g_free (o_src);
 		} else {/* moveit */
-			if (rename (source, target) < 0){
-			  if (xf_dlg_error_continue(win->top,strerror(errno),target)==DLG_RC_CANCEL)
-	          	  return FALSE;
+			if (mode & TR_MOVE) {
+			  if (rename (source, target) < 0){
+			    if (xf_dlg_error_continue(win->top,strerror(errno),target)==DLG_RC_CANCEL)
+	          	    return FALSE;
+			  }
+			} else if (mode & TR_LINK) {
+	                    if (symlink (source, target) < 0) {
+				if ((xf_dlg_error_continue(win->top,strerror(errno),target)==DLG_RC_CANCEL))
+				    return process_error(RW_ERROR_WRITING_TGT);
+			    }
+			    else return TRUE;
 			}
 		}
 	}
 	fclose(tfile);
-	free (line);
+	g_free (line);
 	return TRUE; 
 }
 
@@ -878,7 +1069,7 @@ static int internal_rw_file(char *target,char *source,off_t size){
 				child_path_number,child_file_number,(long long)total_size);fflush(NULL);
 		usleep(50);	*/
 	}
-	free(buffer);
+	g_free(buffer);
 	if (close(source_file)<0){
 		close(target_file);
 		return (RW_ERROR_CLOSE_SRC);
@@ -890,7 +1081,7 @@ static int internal_rw_file(char *target,char *source,off_t size){
 
 	if ((i<0) || (j<0) || (too_few) || (too_many))
 	{
-		if (unlink(source))return (RW_ERROR_UNLINK_SRC); 
+		if (unlink(target))return (RW_ERROR_UNLINK_SRC); 
 		if (too_few) return (RW_ERROR_TOO_FEW);
 		if (too_many) return (RW_ERROR_TOO_MANY);
 		if (i<0) return (RW_ERROR_READING_SRC);
@@ -949,7 +1140,7 @@ static int rwStdout (int n, void *data){
   	strtok(line,":");
   	strtok(NULL,":");
   	texto=strtok(NULL,"\n");
-	if (texto) gtk_label_set_text (GTK_LABEL (info[2]),texto );
+	if (texto && info[2]) gtk_label_set_text (GTK_LABEL (info[2]),texto );
 	return TRUE;
   }
  /* src-tgt update */
@@ -957,7 +1148,7 @@ static int rwStdout (int n, void *data){
 	char *src,*tgt;
   	strtok(line,":");
   	strtok(NULL,":");
-	tgt=strtok(NULL,":");
+	tgt=strtok(NULL,"\t");
 	src=strtok(NULL,"\n");
         if (tgt && src) set_show_cpy(tgt,src);
 	return TRUE;
@@ -977,7 +1168,7 @@ static int rwStdout (int n, void *data){
   /*fprintf(stderr,"dbg(rwStdout error):%s\n",texto);fflush(NULL);*/
   /*set_dnd_status sets static variable in xtree_dnd to break loop;*/
 /*  rc=xf_dlg_error_continue (cat,texto,NULL);*/
-  rc=xf_dlg_new(cat,texto,NULL,NULL,DLG_CANCEL|DLG_CONTINUE|DLG_ALL);
+  rc=xf_dlg_new(cat,texto,NULL,NULL,DLG_CANCEL|DLG_CONTINUE|DLG_ALL,1);
   /*rc=xf_dlg_error_continue_all (cat,texto,NULL);*/
   if (rc==DLG_RC_ALL){
     FILE *allF;
@@ -986,7 +1177,7 @@ static int rwStdout (int n, void *data){
     if (allfile) { 
 	sprintf(allfile,"%s.all",child_file);
 	allF=fopen(allfile,"w"); if (allF) fclose(allF);	    
-        free(allfile);
+        g_free(allfile);
     }
   }
   
@@ -998,20 +1189,20 @@ static int rwStdout (int n, void *data){
   sprintf(holdfile,"%s.hold",child_file);  
   if (rc==DLG_RC_CANCEL) cb_cancel(NULL,NULL); /* terminates child */
   usleep(500000); /* give child time to close */
-  unlink(holdfile); free(holdfile);
+  unlink(holdfile); g_free(holdfile);
   /*set_innerloop(FALSE);*/
   return TRUE;
 }
 
 /* function called when child is dead */
-static void rwForkOver (void)
+static void rwForkOver (pid_t pid)
 {
   char *allfile;
   allfile=(char *)malloc(strlen(child_file)+1+strlen(".all"));
   if (allfile) { 
     sprintf(allfile,"%s.all",child_file);
     unlink(allfile);
-    free(allfile);
+    g_free(allfile);
   }  
 /*  cursor_reset (GTK_WIDGET (smb_nav));*/
   rw_fork_obj = NULL;
@@ -1032,7 +1223,7 @@ void set_show_cpy(char *target,char *source){
 	gtk_entry_set_text (GTK_ENTRY (info[0]), source);
 	gtk_entry_set_text (GTK_ENTRY (info[1]), target);
 	sprintf (line, _("%d / %d"), 0,total_files);
-	gtk_label_set_text (GTK_LABEL (info[2]),line );
+	if (info[2])gtk_label_set_text (GTK_LABEL (info[2]),line );
 }
 
 /* function to set the state of the progress bar*/
@@ -1097,6 +1288,7 @@ GtkWidget *show_cpy(GtkWidget *parent,gboolean show,int mode)
   
  
   cat = gtk_dialog_new ();
+  gtk_window_position (GTK_WINDOW (cat), GTK_WIN_POS_MOUSE);
   gtk_signal_connect (GTK_OBJECT (cat), "destroy", GTK_SIGNAL_FUNC (cb_cancel), NULL);
  
   box = gtk_vbox_new (FALSE, 4);
@@ -1120,7 +1312,7 @@ GtkWidget *show_cpy(GtkWidget *parent,gboolean show,int mode)
   info[1] = gtk_entry_new ();
   gtk_table_attach (GTK_TABLE (table), info[1], 1, 2, 1, 2, X_OPT, 0, 0, 0);
 
-  info[2] = gtk_label_new (_("file x of x"));
+  info[2] = gtk_label_new (_("beginning copy operation"));
   gtk_box_pack_start (GTK_BOX (box), info[2], TRUE, TRUE, 0);
 
   progress = gtk_progress_bar_new();
@@ -1132,7 +1324,7 @@ GtkWidget *show_cpy(GtkWidget *parent,gboolean show,int mode)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (cat)->action_area), cancel, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (cancel), "clicked", GTK_SIGNAL_FUNC (cb_cancel),NULL);
 
-  gtk_widget_set_usize(cat,300,150);
+  gtk_widget_realize(cat);  
   gtk_widget_show_all (cat);
 
   if (mode == TR_COPY)      tit = _("XFTree: Copy");	  
@@ -1143,12 +1335,10 @@ GtkWidget *show_cpy(GtkWidget *parent,gboolean show,int mode)
   if (title) {
 	sprintf (title, tit);
 	gtk_window_set_title (GTK_WINDOW (cat), title);
-        free(title);
+        g_free(title);
   }
 
   
-  gtk_widget_show (cat);
-  gtk_widget_realize(cat);  
   /*gdk_flush();*/
   gtk_window_set_modal (GTK_WINDOW (cat), TRUE);
   if (parent) gtk_window_set_transient_for (GTK_WINDOW (cat), GTK_WINDOW (parent));
@@ -1222,7 +1412,7 @@ next:;
    /* immediate refresh */
   update_timer (ctree);
   cursor_reset (GTK_WIDGET (ctree));
-  free(nfile);
+  g_free(nfile);
 duplicate_return:
   gtk_clist_thaw (GTK_CLIST (ctree));
   cursor_reset (GTK_WIDGET (ctree));   return;
@@ -1236,27 +1426,27 @@ void cb_symlink (GtkWidget * item, GtkCTree * ctree)
   int num,selected;
   struct stat st;
   cfg *win;
+  char *argv[6];
 
   cursor_wait (GTK_WIDGET (ctree));
   gtk_clist_freeze (GTK_CLIST (ctree));
   win = gtk_object_get_user_data (GTK_OBJECT (ctree));
   selected = count_selection (ctree, &node);
   if (!selected) {
-	  xf_dlg_error(win->top,"No file or directory selected for symlink!",NULL);
+	  xf_dlg_error(win->top,_("No file or directory selected!"),NULL);
 	  goto symlink_return;
   } else if (selected > 1) {
-	  xf_dlg_error(win->top,"Only one file or directory can be selected for symlink!",NULL);
+	  xf_dlg_error(win->top,_("Only one file or directory can be selected!"),NULL);
 	  goto symlink_return;
   }
   
   en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
-  if (en->type & FT_TARCHILD) {
-	xf_dlg_error(win->top,_("This function is not available for the contents of tar files"),NULL);
+  if (en->type & (FT_TARCHILD|FT_RPMCHILD)) {
+	xf_dlg_error(win->top,_("This function is not available for the contents of tar/rpm files"),NULL);
 	goto symlink_return;
   }
 
   if (!io_is_valid (en->label)) goto symlink_return;
-  cursor_wait (GTK_WIDGET (ctree));
   num = 0;
   if ((nfile=(char *) malloc(strlen(en->path)+12))==NULL) goto symlink_return;
 
@@ -1278,10 +1468,10 @@ void cb_symlink (GtkWidget * item, GtkCTree * ctree)
 	  goto symlink_return;
   }	  
   strcpy(ofile,en->path);
-  free(nfile);
+  g_free(nfile);
   nfile = (char *)malloc(strlen(en->path)+strlen(entry_return)+1);
   if (!nfile) {
-	  free(ofile);
+	  g_free(ofile);
 	  goto symlink_return;
   }
   strcpy (nfile,ofile);
@@ -1293,23 +1483,71 @@ void cb_symlink (GtkWidget * item, GtkCTree * ctree)
 
   if (lstat (nfile, &st) != ERROR)  {
       xf_dlg_error (win->top,_("File exists !"), nfile);
-      free(ofile); free(nfile);
+      g_free(ofile); g_free(nfile);
       goto symlink_return;
   }
 
   /*fprintf(stderr,"dbg:ln -s %s %s\n",ofile,nfile);*/
-  if (fork()==0){
-	  execlp("ln","ln","-s",ofile,nfile,(char *)0);
-	  _exit(123);
-  } else usleep(50000);
-	   
+  argv[0]="ln";
+  argv[1]="-s";
+  argv[2]=ofile;
+  argv[3]=nfile;
+  argv[4]=0;
+  
+  io_system(argv,win->top);
+  usleep(50000);
+    
    /* immediate refresh */
   update_timer (ctree);
   cursor_reset (GTK_WIDGET (ctree));
-  free(nfile);
-  free(ofile);
+  g_free(nfile);
+  g_free(ofile);
 symlink_return:
   gtk_clist_thaw (GTK_CLIST (ctree));
   cursor_reset (GTK_WIDGET (ctree));   return;
 }
 
+void cb_touch (GtkWidget * item, GtkCTree * ctree)
+{
+  entry *en;
+  GtkCTreeNode *node;
+  int num;
+  cfg *win;
+  char *argv[4];
+  GList *selection;
+
+  cursor_wait (GTK_WIDGET (ctree));
+  gtk_clist_freeze (GTK_CLIST (ctree));
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  num = count_selection (ctree, &node);
+  if (!num) {
+	  xf_dlg_error(win->top,_("No file or directory selected!"),NULL);
+	  goto touch_return;
+  }    
+  
+  selection = GTK_CLIST (ctree)->selection;
+  node = selection->data;
+  en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree),node);
+
+  if (!io_is_valid (en->label)) goto touch_return;
+
+  argv[0]="touch";
+  argv[2]=0;
+  for (;selection != NULL;selection=selection->next) {
+     node = selection->data;
+     en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree),node);
+     if (en->type & (FT_TARCHILD|FT_RPMCHILD)) continue;
+     argv[1]=en->path;
+     io_system(argv,win->top);
+     usleep(50000);
+  }
+   
+   /* immediate refresh */
+  update_timer (ctree);
+  cursor_reset (GTK_WIDGET (ctree));
+touch_return:
+  gtk_clist_thaw (GTK_CLIST (ctree));
+  cursor_reset (GTK_WIDGET (ctree));   
+  return;
+}
+
