@@ -31,6 +31,7 @@
 
 #include <stdio.h>
 #include <unistd.h>
+#include <netdb.h>
 #include <stdarg.h>
 #include <utime.h>
 #include <stdlib.h>
@@ -47,6 +48,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkenums.h>
+#include <X11/Xatom.h>
 #include "constant.h"
 #include "my_intl.h"
 #include "my_string.h"
@@ -70,6 +72,7 @@
 #include "xtree_go.h"
 #include "xtree_cb.h"
 #include "xtree_tar.h"
+#include "xtree_rpm.h"
 #include "xtree_toolbar.h"
 #include "xtree_functions.h"
 #include "xtree_icons.h"
@@ -97,6 +100,60 @@
 
 static void update_status(GtkCTreeNode * node,GtkCTree * ctree);
 static int update_tree (GtkCTree * ctree, GtkCTreeNode * node);
+
+char *our_host_name(GtkWidget *ctree)
+{
+  static char *name = NULL;
+  GdkAtom atomo;
+  if (name) return name;
+  atomo=gdk_atom_intern("WM_CLIENT_MACHINE",FALSE);
+ 
+  if (atomo  == GDK_NONE) name=g_strdup("localhost");
+  else {
+      unsigned char *property_data;
+      unsigned long items,remaining;
+      int actual_format;
+      Atom actual_atom;
+      if (XGetWindowProperty(GDK_DISPLAY(),
+		      ((GdkWindowPrivate*) gtk_widget_get_toplevel (GTK_WIDGET (ctree))->window)->xwindow,
+		      /*((GdkWindowPrivate*) context->source_window)->xwindow,*/
+		      atomo,0,255,FALSE,
+		      XA_STRING,&actual_atom,
+		      &actual_format,&items,
+		      &remaining,&property_data)==Success){
+	      /*printf("dbg: property_data=%s\n",property_data);*/
+	      name=g_strdup(property_data);
+	      XFree(property_data);
+      } else  name=g_strdup("localhost");
+  }
+ return name;
+}
+
+gboolean check_hostname(char *host){
+	char buffer[256],*testv;
+	int i;
+	if (host[0]==':') return TRUE;	
+	testv="localhost";	
+	if (strncmp(host,testv,strlen(testv))==0) return TRUE;
+	testv="localhost.localdomain";	
+	if (strncmp(host,testv,strlen(testv))==0) return TRUE;
+	if (gethostname(buffer, 256) == 0)
+	{
+	  struct hostent *ent;
+	  buffer[256] = '\0';
+	  testv=buffer;
+	  /*printf("dbg:%s==%s\n",host,testv);*/
+	  if (strncmp(host,testv,strlen(testv))==0) return TRUE;
+	  ent = gethostbyname(buffer);
+	  for (i=0; ent->h_aliases[i] != NULL ; i++){
+		  testv=ent->h_aliases[i];
+		  /*printf("dbg:%s==%s\n",host,testv);*/
+	          if (strncmp(host,testv,strlen(testv))==0) return TRUE;
+	  }
+	}
+	return FALSE;
+}
+
 /*
  * check if a node is a directory and is visible and expanded
  * will be called for every node
@@ -137,6 +194,7 @@ get_visible_or_parent (GtkCTree * ctree, GtkCTreeNode * node, gpointer data)
 /*
  * timer function to update the view
  */
+
 gint update_timer (GtkCTree * ctree)
 {
   GList *list = NULL, *tmp;
@@ -144,7 +202,6 @@ gint update_timer (GtkCTree * ctree)
   gboolean manage_timeout;
   cfg *win;
 
-  //return (TRUE);
   win = gtk_object_get_user_data (GTK_OBJECT (ctree));
   status_node=win->status_node;
 
@@ -153,7 +210,7 @@ gint update_timer (GtkCTree * ctree)
     entry *en;
     glob_t dirlist;
     GtkCTreeNode *root;
-    root = GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list);
+    root = find_root((GtkCTree *)ctree);
     en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree),root); 
     if (glob (en->path, GLOB_ERR, NULL, &dirlist) != 0){
 	    fprintf(stderr,"xftree: xftree root has vanished. Now going home.\n");
@@ -176,8 +233,7 @@ gint update_timer (GtkCTree * ctree)
 
   /* get a list of directories we have to check
    */
-  gtk_ctree_post_recursive (ctree, 
-		  GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list), 
+  gtk_ctree_post_recursive (ctree,find_root(ctree), 
 		  get_visible_or_parent, &list);
 
   gtk_clist_freeze (GTK_CLIST (ctree));
@@ -193,7 +249,7 @@ gint update_timer (GtkCTree * ctree)
   {
     win->timer = gtk_timeout_add (TIMERVAL, (GtkFunction) update_timer, ctree);
   }
-  update_status(status_node,ctree);
+  /*update_status(status_node,ctree);*/
   gtk_clist_thaw (GTK_CLIST (ctree));
   
   return (TRUE);
@@ -211,8 +267,8 @@ count_selection (GtkCTree * ctree, GtkCTreeNode ** first)
   int num = 0;
   GList *list;
 
-  *first = GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list);
-
+  *first = find_root(ctree);
+  
   list = GTK_CLIST (ctree)->selection;
   num = g_list_length (list);
   if (num <= 0)
@@ -246,7 +302,7 @@ selection_type (GtkCTree * ctree, GtkCTreeNode ** first)
 
   list = GTK_CLIST (ctree)->selection;
 
-  *first = GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list);
+  *first = find_root((GtkCTree *)ctree);
   if (g_list_length (list) <= 0)
     return (0);
 
@@ -330,32 +386,14 @@ add_node (GtkCTree * ctree, GtkCTreeNode * parent, GtkCTreeNode * sibling, char
 	   /* fprintf(stderr,"dbg:can't do %s\n",path);*/
       return 0;
     }
-    en->flags = flags;
-    if (strstr(en->label,".")){
-	  char *w;
-	  w=strrchr(en->label,'.');
-	  if (strcmp(w,".tar")==0) en->type |= (FT_TAR|FT_TAR_DUMMY);
-	  if (strcmp(w,".tgz")==0) en->type |= (FT_TAR|FT_TAR_DUMMY|FT_GZ);
-	  if (strcmp(w,".gz")==0) {
-		  en->type |= (FT_GZ);
-		  if (strstr(en->label,".tar.gz")) en->type |= (FT_TAR|FT_TAR_DUMMY);
-	  } 
-	  if (strcmp(w,".Z")==0) {
-		  en->type |= (FT_COMPRESS);
-		  if (strstr(en->label,".tar.Z")) en->type |= (FT_TAR|FT_TAR_DUMMY);
-	  }
-	  if (strcmp(w,".bz2")==0) {
-		  en->type |= (FT_BZ2);
-		  if (strstr(en->label,".tar.bz2")) en->type |= (FT_TAR|FT_TAR_DUMMY);
-	  }
-    }
+    en->flags = (flags & INHERIT_FLAG_MASK);
     {
       char *tag="  ";
       unsigned long long tama;
       tama =  en->st.st_size;
-      if (tama >= (long long)1024*1024*1024*10) {tama /= (long long)1024*1024*1024; tag=" Gb";}
-      else if (tama >= 1024*1024*10) {tama /= 1024*1024; tag=" Mb";}
-      else if (tama >= 1024*10) {tama /= 1024; tag=" Kb";}
+      if (tama >= (long long)1024*1024*1024*10) {tama /= (long long)1024*1024*1024; tag=" GB";}
+      else if (tama >= 1024*1024*10) {tama /= 1024*1024; tag=" MB";}
+      else if (tama >= 1024*10) {tama /= 1024; tag=" KB";}
       sprintf (size, " %llu%s", tama,tag);
     }
   }
@@ -370,8 +408,8 @@ add_node (GtkCTree * ctree, GtkCTreeNode * parent, GtkCTreeNode * sibling, char
   gr=getgrgid (en->st.st_gid); 
   text[COL_GID] = (gr)? gr->gr_name : _("unknown");
 
-  isleaf=set_icon_pix(&pix,en->type,en->label);
-  if (en->type & FT_TAR) isleaf=FALSE;
+  isleaf=set_icon_pix(&pix,en->type,en->label,en->flags);
+  if (en->type & (FT_TAR|FT_RPM)) isleaf=FALSE;
   
   /*fprintf(stderr,"dbg:%s en_is_tar=%d\n",en->label,en->type & FT_TAR);*/
 /**************************/
@@ -380,31 +418,52 @@ add_node (GtkCTree * ctree, GtkCTreeNode * parent, GtkCTreeNode * sibling, char
 		  pix.pixmap,pix.pixmask, pix.open,pix.openmask, isleaf, FALSE);
   if (item){
     gtk_ctree_node_set_row_data_full (ctree, item, en, node_destroy);
-    if (en->type & FT_TAR) {
-	    add_tar_dummy(ctree, item,en);
-    }
-/*    if (en->type & FT_TAR) add_tar_tree(ctree, item,en);*/
+    if (en->type & (FT_TAR|FT_RPM)) add_tar_dummy(ctree, item,en);
+   /* if (en->type & FT_TAR) add_tar_dummy(ctree, item,en);
+    if (en->type & FT_RPM) add_rpm_dummy(ctree, item,en);*/
   }
   *type = en->type;
   return (item);
 }
 
-void
-update_node (GtkCTree * ctree, GtkCTreeNode * node, int type, char *label)
+static void
+update_node (GtkCTree * ctree, GtkCTreeNode * child, entry *child_en)
 {
-  icon_pix pix;  
-  gboolean isleaf;
-  entry *en;
-  
-  if (!ctree || !node || !label)
+  gchar size[32];
+  gchar date[32];
+     /* update the labels */
+  struct passwd *pw;
+  struct group *gr;
+     /*fprintf(stderr,"dbg: doing update for %s\n",en->label);*/
   {
-    return;
+       char *tag="  ";
+       unsigned long long tama;
+       tama =  child_en->st.st_size;
+       if (tama >= (long long)1024*1024*1024*10) {tama /= (long long)1024*1024*1024; tag=" GB";}
+       else if (tama >= 1024*1024*10) {tama /= 1024*1024; tag=" MB";}
+       else if (tama >= 1024*10) {tama /= 1024; tag=" KB";}
+       sprintf (size, " %llu%s", tama,tag);
   }
-  en = gtk_ctree_node_get_row_data (ctree, node); 
-  isleaf=set_icon_pix(&pix,en->type,en->label);
-  gtk_ctree_set_node_info (ctree, node, label, SPACING, 
+     
+  sprintf (date, "%02d-%02d-%02d  %02d:%02d", 
+		      child_en->date.year, child_en->date.month, 
+		      child_en->date.day, child_en->date.hour, child_en->date.min);
+  gtk_ctree_node_set_text (ctree, child, COL_DATE, date);
+  gtk_ctree_node_set_text (ctree, child, COL_SIZE, size);
+  gtk_ctree_node_set_text (ctree, child, COL_MODE, mode_txt(child_en->st.st_mode));
+  pw=getpwuid(child_en->st.st_uid); 
+  gtk_ctree_node_set_text (ctree, child, COL_UID,(pw)? pw->pw_name : _("unknown") );
+  gr=getgrgid (child_en->st.st_gid); 
+  gtk_ctree_node_set_text (ctree, child, COL_GID,(gr)? gr->gr_name : _("unknown") );      
+
+  {
+    icon_pix pix;  
+    gboolean isleaf; 
+    isleaf=set_icon_pix(&pix,child_en->type,child_en->label,child_en->flags);
+  /*printf("dbg: updating %s, (%d)\n",en->label,FT_TAR|FT_RPM);*/
+    gtk_ctree_set_node_info (ctree,child, child_en->label, SPACING, 
 		  pix.pixmap,pix.pixmask, pix.open, pix.openmask, isleaf, FALSE);
-  
+  } 
 }
 
 static void update_status(GtkCTreeNode * node,GtkCTree * ctree){
@@ -418,7 +477,7 @@ static void update_status(GtkCTreeNode * node,GtkCTree * ctree){
    status_inf.howmany=0;
    status_inf.howmuch=0;
    /* is the status node still there? */
-   root = GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list);
+   root = find_root(ctree);
    if (!root) printf("dbg: root is null!!!\n");
    if (!gtk_ctree_find (ctree,root,node)){
 	   /*fprintf(stderr,"dbg:status node gone away.\n");*/
@@ -458,7 +517,11 @@ static void update_status(GtkCTreeNode * node,GtkCTree * ctree){
 		   (long long)status_inf.howmany,
 		   _("files"),tama,tag);
   }
+#ifdef STATUS_LABEL   
    gtk_label_set_text ((GtkLabel *)win->status,texto);
+#else
+   gtk_entry_set_text ((GtkEntry *)win->status,texto);
+#endif  
 
    /*fprintf(stderr,"dbg:%s\n",texto);*/
    free(texto);
@@ -466,6 +529,25 @@ static void update_status(GtkCTreeNode * node,GtkCTree * ctree){
 	
 }
 
+void reset_icon(GtkCTree * ctree, GtkCTreeNode * node){
+  entry *en;
+  int i; 
+  icon_pix pix; 
+  gboolean isleaf;
+  gboolean isexpanded;
+  cfg * win;
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  en = gtk_ctree_node_get_row_data (ctree, node);
+
+  for (i = 0; i < COLUMNS; i++)  gtk_clist_set_column_width ((GtkCList *)ctree,
+		  i,gtk_clist_optimal_column_width ((GtkCList *)ctree,i));
+  isleaf=set_icon_pix(&pix,en->type,en->label,en->flags);
+    /*printf("dbg: updating %s\n",en->label);*/
+  isexpanded=GTK_CTREE_ROW(node)->expanded;
+  gtk_ctree_set_node_info (ctree,node,(win->preferences&ABREVIATE_PATHS)?abreviate(en->label):en->label, 
+		 SPACING, pix.pixmap,pix.pixmask, pix.open, pix.openmask, isleaf, isexpanded);
+} 
+	
 
 void add_subtree (GtkCTree * ctree, GtkCTreeNode * root, char *path, int depth, int flags)
 {
@@ -478,6 +560,10 @@ void add_subtree (GtkCTree * ctree, GtkCTreeNode * root, char *path, int depth,
   char *label;
   int add_slash = no, len, d_len;
   int type = 0;
+  entry *p_en;
+  
+  p_en = gtk_ctree_node_get_row_data (ctree, root);
+  p_en->flags &= (0xffffffff ^ HIDDEN_PRESENT);
   win = gtk_object_get_user_data (GTK_OBJECT (ctree));
 
   if (depth == 0) return ;
@@ -493,6 +579,7 @@ void add_subtree (GtkCTree * ctree, GtkCTreeNode * root, char *path, int depth,
   base = g_malloc (len + 1);
   if (!base){
     xf_dlg_error(win->top,_("internal malloc error:"),strerror(errno));
+    cleanup_tmpfiles();
     exit(1);
   }
   strcpy (base, path);
@@ -500,13 +587,14 @@ void add_subtree (GtkCTree * ctree, GtkCTreeNode * root, char *path, int depth,
     strcat (base, "/");
 
       /* fprintf(stderr,"dbg:base=%s\n",base);*/
-  if (depth == 1)
+  if ((depth == 1) && !(GTK_CTREE_ROW(root)->expanded))
   {
     /* create dummy entry */
     if ((complete=(char *)malloc(strlen(base)+2))==NULL) return;
     sprintf (complete, "%s.", base);
     type = FT_DUMMY;
     add_node (GTK_CTREE (ctree), root, NULL, ".", complete, &type, flags);
+    p_en->type |= FT_HAS_DUMMY;
     g_free (base);
     free(complete);
     return ;
@@ -514,7 +602,7 @@ void add_subtree (GtkCTree * ctree, GtkCTreeNode * root, char *path, int depth,
   {
    char *name;
    /* ../ is usually not filtered in, so add it */
-   if ((win->preferences&FILTER_OPTION)&&
+   if (!(win->preferences&HIDE_DD) && (win->preferences&FILTER_OPTION) &&
         ((win->filterOpts & FILTER_DIRS) || (win->filterOpts & FILTER_FILES))){ /* filtering */
      type=FT_DIR_UP;
      if ((complete=(char *)malloc(strlen(base)+3))==NULL) return;
@@ -533,26 +621,32 @@ void add_subtree (GtkCTree * ctree, GtkCTreeNode * root, char *path, int depth,
     item = NULL;
     d_len = strlen (name);
 	/*fprintf(stderr,"dbg:%s\n",name);*/
-    if (io_is_dirup (name)) type |= FT_DIR_UP | FT_DIR;
-    else if ((d_len >= 1) && io_is_hidden (name) && ((flags & IGNORE_HIDDEN)))
+    if (io_is_dirup (name)) {
+	    type |= FT_DIR_UP | FT_DIR;
+	    if (win->preferences & HIDE_DD) continue; 
+    } else if ((d_len >= 1) && io_is_hidden (name) && ((flags & IGNORE_HIDDEN))){
+      if (d_len > 1) p_en->flags |= HIDDEN_PRESENT;	    
+      /*fprintf(stderr,"dbg:hidden, %s\n",name);*/
       continue;
+    }
     if ((complete=(char *)malloc(strlen(base)+strlen(name)+1))==NULL) continue;
     sprintf (complete, "%s%s", base, name);
     if ((label=(char *)malloc(strlen(name)+1))==NULL) continue;
     strcpy (label, name);
     if ((!io_is_current (name))){
-      entry *en;
       item = add_node (GTK_CTREE (ctree), root, first, label, complete, &type, flags);
-      en = gtk_ctree_node_get_row_data (ctree, item); 
     }
+    
     if ((++count % 512)==0){
         gtk_clist_thaw (GTK_CLIST (ctree));
         while (gtk_events_pending()) gtk_main_iteration();	     
         gtk_clist_freeze (GTK_CLIST (ctree));
     }
+    
     if ((type & FT_DIR) && (!(type & FT_DIR_UP)) && (!(type & FT_DIR_PD)) && (io_is_valid (name)) && item){
 	    /* this is just to get the necesary expanders on startup */
       add_subtree (ctree, item, complete, depth - 1, flags);
+      /* dont use reset_icon(ctree, item); here */
     }
     else {if (!first) {first = item;}}
     free(complete);
@@ -562,8 +656,10 @@ void add_subtree (GtkCTree * ctree, GtkCTreeNode * root, char *path, int depth,
    update_status(root,ctree);
   } 
   g_free (base);
-  /* do not autosort directories with more than 1024 entries */
-  if (count <= 1024)gtk_ctree_sort_node (ctree, root);
+  
+   /* do not autosort directories with more than 1024 entries */
+  if (count <= 1024) gtk_ctree_sort_node (ctree, root);
+  
   return ;
 }
 
@@ -574,8 +670,10 @@ on_dotfiles (GtkWidget * item, GtkCTree * ctree)
 {
   GtkCTreeNode *node, *child;
   entry *en;
+  cfg *win;
 
   gtk_clist_freeze (GTK_CLIST (ctree));
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
 
   /* use first selection if available
    */
@@ -601,7 +699,10 @@ on_dotfiles (GtkWidget * item, GtkCTree * ctree)
   }
   en->flags ^= IGNORE_HIDDEN;
   add_subtree (ctree, node, en->path, 2, en->flags);
-  gtk_ctree_expand (ctree, node);
+  reset_icon(ctree, node);
+  /* select affected node to enable easy toggle on/off */
+  gtk_ctree_expand (ctree,node);
+  gtk_ctree_select (ctree,node);
   gtk_clist_thaw (GTK_CLIST (ctree));
 }
 
@@ -614,10 +715,19 @@ on_expand (GtkCTree * ctree, GtkCTreeNode * node, char *path)
   GtkCTreeNode *child;
   cfg *win;
   entry *en;
-
+  
   en = gtk_ctree_node_get_row_data (ctree, node);
-  if (en->type & (FT_TAR|FT_TARCHILD)) {
-      if  (en->type & FT_TAR_DUMMY){
+
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  if (win->source_set_sem) {
+	  gtk_drag_source_unset ((GtkWidget *)ctree);
+	  win->source_set_sem=FALSE;
+  }
+
+
+  
+  if (en->type & (FT_TAR|FT_TARCHILD|FT_RPM|FT_RPMCHILD)) {	 
+      if  (en->type & (FT_HAS_DUMMY)){
 	      /*printf("doingit\n");*/
 	      /* cursor wait */
               ctree_freeze (ctree);
@@ -627,9 +737,10 @@ on_expand (GtkCTree * ctree, GtkCTreeNode * node, char *path)
                 gtk_ctree_remove_node (ctree, child);
                 child = GTK_CTREE_ROW (node)->children;
               }
-	      en->type ^= FT_TAR_DUMMY;
+	      if (en->type & FT_HAS_DUMMY) en->type ^= FT_HAS_DUMMY;
 	      /* add tar tree */
-              add_tar_tree(ctree,node,en);
+              if (en->type & (FT_RPM|FT_RPMCHILD)) add_rpm_tree(ctree,node,en);
+              if (en->type & (FT_TAR|FT_TARCHILD)) add_tar_tree(ctree,node,en);
 	      /* cursor_reset */
               ctree_thaw (ctree);
       } 
@@ -637,9 +748,15 @@ on_expand (GtkCTree * ctree, GtkCTreeNode * node, char *path)
       return;
   }
 
+  if (!(en->type & FT_HAS_DUMMY)) {
+       if (win->preferences & STATUS_FOLLOWS_EXPAND)
+            set_title_ctree((GtkWidget *)ctree,en->path);
+       update_status(node,ctree);
+       update_timer(ctree);
+       return;
+  }
+  en->type ^= FT_HAS_DUMMY;
   
-  
-  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
   ctree_freeze (ctree);
   child = GTK_CTREE_ROW (node)->children;
   while (child)
@@ -649,10 +766,10 @@ on_expand (GtkCTree * ctree, GtkCTreeNode * node, char *path)
   }
   en = gtk_ctree_node_get_row_data (ctree, node);
   add_subtree (ctree, node, en->path, 2, en->flags);
+  
+  reset_icon(ctree, node);
   ctree_thaw (ctree);
   if (win->preferences & STATUS_FOLLOWS_EXPAND){
-   cfg *win;
-   win = gtk_object_get_user_data (GTK_OBJECT (ctree));
    set_title_ctree((GtkWidget *)ctree,en->path);
   }
 }
@@ -666,11 +783,17 @@ on_collapse (GtkCTree * ctree, GtkCTreeNode * node, char *path)
   cfg *win;
   entry *en;
   GtkCTreeNode *child,*parent;
+
   
   /* unselect all children */
   win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  if (win->source_set_sem) {
+	  gtk_drag_source_unset ((GtkWidget *)ctree);
+	  win->source_set_sem=FALSE;
+  }
+  
   child = GTK_CTREE_NODE (GTK_CTREE_ROW (node)->children);
-  if (node==GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list)) parent=node;
+  if (node==find_root(ctree)) parent=node;
   else parent = GTK_CTREE_NODE (GTK_CTREE_ROW (node)->parent);
   while (child)  {
     gtk_ctree_unselect (ctree, child);
@@ -679,43 +802,87 @@ on_collapse (GtkCTree * ctree, GtkCTreeNode * node, char *path)
   
   en = gtk_ctree_node_get_row_data (ctree, parent);
   if (en->type & (FT_TAR|FT_TARCHILD)) return;
+  if (en->type & (FT_RPM|FT_RPMCHILD)) return;
   if (win->preferences & STATUS_FOLLOWS_EXPAND){
    set_title_ctree((GtkWidget *)ctree,en->path);
   }
   update_status(parent,ctree);
 }
 
-
-void
-set_title (GtkWidget * w, const char *path)
-{
-  char *title;
-  title = (char *)malloc((strlen("XFTree: ")+strlen(path)+1)*sizeof(char));
-  if (!title) return; 
-  sprintf (title, "XFTree: %s", path);
-  gtk_window_set_title (GTK_WINDOW (gtk_widget_get_toplevel (w)), title);
-  free(title);
-
-}
 void
 set_title_ctree (GtkWidget * ctree, const char *path)
 {
-  char *title;
+  char *title,*hostname;
   cfg *win;
+  GdkAtom atomo;
+  entry *en;
+  GtkCTreeNode *root;
+  
+  hostname=our_host_name(ctree);
   win = gtk_object_get_user_data (GTK_OBJECT (ctree));
-  title = (char *)malloc((strlen("XFTree: ")+strlen(path)+1)*sizeof(char));
-  if (!title) return; 
+  title = (char *)malloc((strlen("XFTree: ")+strlen(hostname)+strlen(path)+1)*sizeof(char));
+  if (win->iconname) g_free(win->iconname);
+  win->iconname = (char *)malloc((strlen("XFTree: ")+strlen(hostname)+strlen(path)+1)*sizeof(char));
+  if (!title || !win->iconname) return; 
+  
+  
   if (win->preferences&SHORT_TITLES) {
 	  char *word;
 	  word = strrchr (path,'/');
+          if (strncmp(path,getenv ("HOME"),strlen(getenv ("HOME")))==0){	  
+            sprintf(win->iconname,"~%s",path+strlen(getenv ("HOME")));
+          } else sprintf (win->iconname, "%s", path);
 	  if (word) sprintf(title,"%s",(word[1]==0)?word:word+1);
 	  else  sprintf(title,"XFTree");	  
   }
-  else sprintf (title, "%s", path);
+  else {
+	sprintf (title, "//%s%s",hostname,path); 
+        strcpy (win->iconname,title);
+  }
   gtk_window_set_title (GTK_WINDOW (gtk_widget_get_toplevel (win->top)), title);
-  free(title);
+  gdk_window_set_icon_name (gtk_widget_get_toplevel (GTK_WIDGET (ctree))->window, 
+		  win->iconname);
+  sprintf(title,"xftree %s",path);
+  root=find_root((GtkCTree *) ctree);
+  en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), root);
+  g_free(title);
+  
+  atomo=gdk_atom_intern("WM_COMMAND",TRUE);
+  gdk_property_change (gtk_widget_get_toplevel (GTK_WIDGET (ctree))->window,
+		  atomo,
+                  XA_STRING, /* GdkAtom type,*/
+                  8, /* bit per data element: gint format*/
+ 	      	  GDK_PROP_MODE_REPLACE,
+                  (guchar *)"xftree",  
+		  strlen("xftree")+1); 
 
-}
+  { /* remote connections */
+    /*printf("display=%s differs from hostname\n",getenv("DISPLAY"));*/
+    gdk_property_change (gtk_widget_get_toplevel (GTK_WIDGET (ctree))->window,
+		  atomo,
+                  XA_STRING, /* GdkAtom type,*/
+                  8, /* bit per data element: gint format*/
+ 	      	  GDK_PROP_MODE_APPEND,
+                  (guchar *)"-h",  
+		  3); 
+    gdk_property_change (gtk_widget_get_toplevel (GTK_WIDGET (ctree))->window,
+		  atomo,
+                  XA_STRING, /* GdkAtom type,*/
+                  8, /* bit per data element: gint format*/
+ 	      	  GDK_PROP_MODE_APPEND,
+                  (guchar *)hostname,  
+		  strlen(hostname)+1); 
+  }
+  
+  gdk_property_change (gtk_widget_get_toplevel (GTK_WIDGET (ctree))->window,
+		  atomo,
+                  XA_STRING, /* GdkAtom type,*/
+                  8, /* bit per data element: gint format*/
+ 	      	  GDK_PROP_MODE_APPEND,
+                  (guchar *)en->path,  
+		  strlen(en->path)+1);
+  
+ }
 
 
 /*
@@ -757,8 +924,7 @@ update_tree (GtkCTree * ctree, GtkCTreeNode * node)
   entry *en, *child_en;
   char compl[PATH_MAX + 1];
   int type, p_len, changed, tree_updated, root_changed;
-  gchar size[32];
-  gchar date[32];
+  /*gchar size[32];  gchar date[32];*/
   cfg *win;
   gboolean manage_timeout;
   deletenode_t *head_delete=NULL,*p_del=NULL,*l_del=NULL;
@@ -793,7 +959,7 @@ update_tree (GtkCTree * ctree, GtkCTreeNode * node)
   }
   
   
-  if (!(en->type&(FT_TAR|FT_TARCHILD)))
+  if (!(en->type&(FT_TAR|FT_TARCHILD|FT_RPM|FT_RPMCHILD)) )
 	  for (child=GTK_CTREE_ROW (node)->children;child != NULL;child = GTK_CTREE_ROW (child)->sibling)
   {
 	  
@@ -818,38 +984,15 @@ update_tree (GtkCTree * ctree, GtkCTreeNode * node)
     }
     else if (changed == TRUE)
     {
-      /* update the labels */
-     struct passwd *pw;
-     struct group *gr;
-     /*fprintf(stderr,"dbg: doing update for %s\n",en->label);*/
-      {
-       char *tag="  ";
-       unsigned long long tama;
-       tama =  child_en->st.st_size;
-       if (tama >= (long long)1024*1024*1024*10) {tama /= (long long)1024*1024*1024; tag=" Gb";}
-       else if (tama >= 1024*1024*10) {tama /= 1024*1024; tag=" Mb";}
-       else if (tama >= 1024*10) {tama /= 1024; tag=" Kb";}
-       sprintf (size, " %llu%s", tama,tag);
-      }
-     
-      sprintf (date, "%02d-%02d-%02d  %02d:%02d", 
-		      child_en->date.year, child_en->date.month, 
-		      child_en->date.day, child_en->date.hour, child_en->date.min);
-      gtk_ctree_node_set_text (ctree, child, COL_DATE, date);
-      gtk_ctree_node_set_text (ctree, child, COL_SIZE, size);
-      gtk_ctree_node_set_text (ctree, child, COL_MODE, mode_txt(en->st.st_mode));
-      pw=getpwuid(en->st.st_uid); 
-      gtk_ctree_node_set_text (ctree, child, COL_UID,(pw)? pw->pw_name : _("unknown") );
-      gr=getgrgid (en->st.st_gid); 
-      gtk_ctree_node_set_text (ctree, child, COL_GID,(gr)? gr->gr_name : _("unknown") );      
-      update_node (ctree, child, child_en->type, child_en->label); /* icon changes */
+      update_node (ctree, child, child_en); /* icon changes */
       /* skip sort if no files added tree_updated = TRUE;*/
     }
     /* this may be a dummy subtree, and need not be updated when node is collapsed
      * when node is expanded, each subnode will be updated individually by
      * the recursive tree function, methinks */
-    if (!(GTK_CTREE_ROW (child)->children) && (io_is_valid (child_en->label)) && !(child_en->type & FT_DIR_UP) && !(child_en->type & FT_DIR_PD) && (child_en->type & FT_DIR)){
+    if (!(GTK_CTREE_ROW (child)->children) && (io_is_valid (child_en->label)) && !(child_en->type & (FT_DIR_UP|FT_DIR_PD)) && (child_en->type & FT_DIR)){
       add_subtree (GTK_CTREE (ctree), child, child_en->path, 1, child_en->flags);
+      reset_icon(GTK_CTREE (ctree),child);      
     }
   } /* end for child */
   
@@ -861,11 +1004,17 @@ update_tree (GtkCTree * ctree, GtkCTreeNode * node)
 		  free(p_del);
 	  }
   }
-  
-
+#if 10
+  if ((GTK_CTREE_ROW (node)->children == NULL)&&(win->preferences&HIDE_DD)) {
+	  /* everything is gone, so add DD as dummy */
+     int type;
+     type=FT_DIR_UP;
+     add_node (GTK_CTREE (ctree), node, NULL, "..",en->path,&type, 0);
+  }
+#endif
     /*fprintf(stderr,"dbg:(%s)rc=%d,tu=%d, isdir=%d\n",en->path,root_changed,tree_updated,en->type & FT_DIR);fflush(NULL);*/
   /*if ((root_changed || tree_updated) && (en->type & FT_DIR))*/
-  if (root_changed && (en->type & FT_DIR) && !(en->type & (FT_TARCHILD|FT_TAR))) {
+  if (root_changed && (en->type & FT_DIR) && !(en->type & (FT_TARCHILD|FT_TAR|FT_RPMCHILD|FT_RPM))){
     /* root changed == maybe new entries */
     /*fprintf(stderr,"dbg:rc=%d,tu=%d\n",root_changed,tree_updated);fflush(NULL);*/
     if (GTK_CTREE_ROW (node)->expanded)
@@ -874,6 +1023,8 @@ update_tree (GtkCTree * ctree, GtkCTreeNode * node)
       xf_dirent *diren;
       /* may be there are new files */
        /*fprintf(stderr,"dbg:update_tree()...\n");fflush(NULL);*/
+	
+       en->flags &= (0xffffffff ^ HIDDEN_PRESENT); /* hidden files may have dissappeared */
        
        diren = xf_opendir (en->path,(GtkWidget *)ctree);
        if (!diren) {
@@ -884,7 +1035,13 @@ update_tree (GtkCTree * ctree, GtkCTreeNode * node)
        }
        p_len = strlen (en->path);
        while ((name = xf_readdir (diren,(GtkWidget *)ctree)) != NULL) {
-	if (io_is_hidden (name) && (en->flags & IGNORE_HIDDEN))  continue;
+	if (io_is_hidden (name)){
+	  if ((strcmp(name,".")!=0)&&(strcmp(name,"..")!=0)) {
+		/*printf("flagging hidden because of %s\n",name);*/
+		en->flags |= HIDDEN_PRESENT; /* hidden files may have appeared */
+	  }
+	  if (en->flags & IGNORE_HIDDEN)  continue;
+	}
 	if (io_is_current (name))  continue;
 	if (!node_has_child (ctree, node, name))
 	{
@@ -898,16 +1055,19 @@ update_tree (GtkCTree * ctree, GtkCTreeNode * node)
 	  new_child = add_node (ctree, node, NULL, name, compl, &type, en->flags);
 	  if ((type & FT_DIR) && (io_is_valid (name)) && !(type & FT_DIR_UP) && !(type & FT_DIR_PD) && new_child)
 	    add_subtree (ctree, new_child, compl, 1, en->flags);
-	  if (entry_update (en) > 0) update_node (ctree, node, en->type, en->label);
+            reset_icon(ctree, new_child);
+	  if (entry_update (en) > 0) update_node (ctree, node, en);
+/*	  if (entry_update (en) > 0) update_node (ctree, node, en->type, en->label);*/
 	  /* root is changed: tree_updated = TRUE;*/
 	}
 	/*else {fprintf(stderr,"dbg:update_tree()...node has child\n");fflush(NULL);}*/
        } /* end while */
        diren = xf_closedir (diren);  
     }
-    else if ((GTK_CTREE_ROW (node)->children) && (io_is_valid (en->label)) && !(en->type & FT_DIR_UP) && !(en->type & FT_DIR_PD))
+    else if ((GTK_CTREE_ROW (node)->children) && (io_is_valid (en->label)) && !(en->type & (FT_DIR_UP|FT_DIR_PD)))
     {
       add_subtree (GTK_CTREE (ctree), node, en->path, 1, en->flags);
+      reset_icon(GTK_CTREE (ctree), node);
       /* icon changes after adding the node? not going to happen: */
       /*if (entry_update (en) > 0) update_node (ctree, node, en->type, en->label); */
     }
@@ -915,6 +1075,8 @@ update_tree (GtkCTree * ctree, GtkCTreeNode * node)
   /*if (tree_updated || root_changed) {*/
   if (root_changed) {
       /*fprintf(stderr,"dbg:doing sort\n");fflush(NULL);*/
+      reset_icon(GTK_CTREE (ctree), node);
+      update_status(win->status_node,GTK_CTREE (ctree));
       gtk_ctree_sort_node (GTK_CTREE (ctree), node);
   }
  
@@ -947,6 +1109,7 @@ XErrorHandler ErrorHandler (Display * dpy, XErrorEvent * event)
   fprintf (stderr, "xftree: Fatal XLib internal error\n");
   fprintf (stderr, "%s\n", buf);
   fprintf (stderr, "Request %d, Error %d\n", event->request_code, event->error_code);
+  cleanup_tmpfiles();
   exit (1);
   return (0);
 }
