@@ -48,6 +48,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkenums.h>
+#include <X11/Xatom.h>
 #include "constant.h"
 #include "my_intl.h"
 #include "my_string.h"
@@ -74,6 +75,7 @@
 #include "xtree_toolbar.h"
 #include "xtree_cpy.h"
 #include "xtree_icons.h"
+#include "xtree_tar.h"
 #include "icons/xftree_icon.xpm"
 
 
@@ -110,16 +112,21 @@ menu_entry;
 static GtkAccelGroup *accel;
 
 /* autotype entries will appear in file-menu when no
- * application is registered for that filetype */
+ * application is registered for that filetype 
+ * leave a blank at end if using options (to be safe) */
 
 autotype_t autotype[]= {
-	{".gz","gunzip"},
-	{".tar","tar -xf"},
-	{".tgz","tar -xzf"},
-	{".bz2","bunzip2"},
-	{".Z","uncompress"},
-	{".zip","unzip"},
-	{".ZIP","unzip"},
+	{".tar.gz","tar -xzf ",N_("Extract files from"),N_("Extract into")},
+	{".gz","gunzip",N_("Uncompress"),NULL},
+	{".tar","tar -xf ",N_("Extract files from"),N_("Extract into")},
+	{".tgz","tar -xzf ",N_("Extract files from"),N_("Extract into")},
+	{".tar.bz2","tar --use-compress-program bunzip2 -xf",N_("Extract files from"),N_("Extract into")},
+	{".bz2","bunzip2",N_("Uncompress"),NULL},
+	{".Z","uncompress",N_("Uncompress"),NULL},
+	{".ZIP","unzip",N_("Uncompress"),NULL},
+	{".zip","unzip",N_("Uncompress"),NULL},
+	{".rpm","rpm -U --percent ",N_("Install/update"),NULL},
+	{".deb","dpkg -i ",N_("Install/update"),NULL},
 	{NULL,NULL}
 };
 
@@ -140,29 +147,33 @@ autotype_t autotype[]= {
     
 #define AUTOTAR_MENU \
     {"", (gpointer) cb_autotar, 0,}
- 
+    
+#define MAINF_ICON_VIEW \
+    {N_("Open icon view"), (gpointer) cb_rox, 0, GDK_y,GDK_CONTROL_MASK}
+    
 #define MAINF_DIRECTORY_MENU \
-    {N_("Open in new"), (gpointer) cb_new_window, 0, GDK_w,GDK_CONTROL_MASK},\
-    {N_("Open in terminal"), (gpointer) cb_term, 0, GDK_t,GDK_CONTROL_MASK}, \
+    {N_("Open tree view"), (gpointer) cb_new_window, 0, GDK_w,GDK_CONTROL_MASK},\
+    {N_("Open terminal view"), (gpointer) cb_term, 0, GDK_t,GDK_CONTROL_MASK}, \
     {NULL, NULL, 0}, \
     {N_("New Folder"), (gpointer) cb_new_subdir, 0, GDK_n,GDK_MOD1_MASK},\
     {N_("New file"), (gpointer) cb_new_file, 0,GDK_n,GDK_CONTROL_MASK}
 
 #define MAINF_MENU \
     {NULL, NULL, 0}, \
+    {N_("Touch ..."), (gpointer) cb_touch, 0, GDK_a,GDK_MOD1_MASK}, \
     {N_("Symlink ..."), (gpointer) cb_symlink, 0, GDK_l,GDK_MOD1_MASK}, \
     {N_("Delete ..."), (gpointer) cb_delete, 0}
     
 #define INSERT_MENU \
-    {N_("Insert from pasteboard"), (gpointer) cb_paste, 0, GDK_i,GDK_CONTROL_MASK}
+    {N_("Paste"), (gpointer) cb_paste, 0, GDK_i,GDK_CONTROL_MASK}
     
 #define DIRECTORY_MENU \
     {N_("Find ..."), (gpointer) cb_find, 0, GDK_f,GDK_CONTROL_MASK},\
     {N_("Show disk usage ..."), (gpointer) cb_du, 0, GDK_v,GDK_CONTROL_MASK}
      
 #define DIR_FILE_MENU \
-    {N_("Cut to pasteboard"), (gpointer) cb_cut, 0, GDK_k,GDK_CONTROL_MASK},\
-    {N_("Copy to pasteboard"), (gpointer) cb_copy, 0, GDK_c,GDK_CONTROL_MASK}
+    {N_("Cut"), (gpointer) cb_cut, 0, GDK_k,GDK_CONTROL_MASK},\
+    {N_("Copy"), (gpointer) cb_copy, 0, GDK_c,GDK_CONTROL_MASK}
     
 #define MAIN_EDIT_MENU \
     {N_("List pasteboard contents"), (gpointer) cb_paste_show, 0, GDK_l,GDK_CONTROL_MASK},\
@@ -183,10 +194,15 @@ autotype_t autotype[]= {
     {NULL, NULL, 0} 
      
 #define COMMON_MENU_GOTO \
-    {N_("Go to ..."), (gpointer) cb_go_to, 0, GDK_g,GDK_MOD1_MASK}    
+    {N_("Go to ..."), (gpointer) cb_go_to, 0, GDK_g,GDK_MOD1_MASK} 
+    
+#define TAR_MENU \
+     {N_("Open with ..."), (gpointer) cb_tar_open_with, 0}
    
 #define FILE_MENU \
-     {N_("Open with ..."), (gpointer) cb_open_with, 0, GDK_o,GDK_MOD1_MASK},\
+     {N_("Open with ..."), (gpointer) cb_open_with, 0, GDK_o,GDK_MOD1_MASK}
+
+#define REGISTER_MENU \
      {N_("Register ..."), (gpointer) cb_register, 0, GDK_r,GDK_MOD1_MASK}
      
 #define SIMPLE_GOTO_MENU \
@@ -228,7 +244,8 @@ autotype_t autotype[]= {
     {N_("Hide dates"),cb_hide_date, HIDE_DATE, GDK_d,GDK_MOD1_MASK}, \
     {N_("Hide owner"),cb_hide_uid, HIDE_UID, GDK_o,GDK_MOD1_MASK}, \
     {N_("Hide group"),cb_hide_gid, HIDE_GID, GDK_y,GDK_MOD1_MASK}, \
-    {N_("Hide mode"),cb_hide_mode, HIDE_MODE, GDK_e,GDK_MOD1_MASK}
+    {N_("Hide mode"),cb_hide_mode, HIDE_MODE, GDK_e,GDK_MOD1_MASK}, \
+    {N_("Hide ../ "),cb_hide_dd, HIDE_DD, GDK_f,GDK_MOD1_MASK }
  
 #define HELP_MENU \
     {N_("Sort by file name"), NULL, SORT_NAME, GDK_n, GDK_CONTROL_MASK | GDK_MOD1_MASK}, \
@@ -240,7 +257,7 @@ autotype_t autotype[]= {
 char *mode_txt(mode_t mode){
 	static char modeT[11];
 	modeT[10]=0;
-	if (mode&040000) modeT[0]='d'; else modeT[0]='-';
+	if (S_ISDIR(mode)) modeT[0]='d'; else modeT[0]='-';
 	if (mode&0400) modeT[1]='r'; else modeT[1]='-';
 	if (mode&0200) modeT[2]='w'; else modeT[2]='-';
 	if ((mode&04000)&&(mode&0100)) modeT[3]='s'; 
@@ -261,26 +278,150 @@ char *mode_txt(mode_t mode){
 	else modeT[9]='-';
 	return modeT;
 }
+
+static gint startit(GtkWidget * ctree,entry *en,int mod_mask,GtkCTreeNode *node){
+  cfg *win;
+  reg_t *prg;
+  char *argv[24];
+  char *a=NULL;
+  int j=0;
+    entry *up;
+   /* disable openwith on FT_TARCHILD */
+    win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+    if (en->type & FT_RPMCHILD) return TRUE;
+    if (en->type & FT_TARCHILD) {
+	    cb_tar_open_with(NULL,GTK_CTREE (ctree));
+	    return TRUE;
+    }
+
+    if (en->type & (FT_TAR|FT_RPM)){
+      if (!GTK_CTREE_ROW (node)->expanded) {
+	      on_expand(GTK_CTREE (ctree),node,NULL);
+	      gtk_ctree_expand (GTK_CTREE (ctree), node); 
+      } else {
+	      on_collapse(GTK_CTREE (ctree),node,NULL);
+	      gtk_ctree_collapse (GTK_CTREE (ctree), node);
+      }
+      return (TRUE);
+    }
+    if (en->type & FT_DIR_UP)
+    {
+      cb_go_up(NULL,GTK_CTREE (ctree)); 	    
+      return (TRUE);
+    }
+    if (!(en->type & FT_FILE)) return (FALSE);
+    up = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), GTK_CTREE_ROW (node)->parent);
+    cursor_wait (GTK_WIDGET (ctree));
+    chdir (up->path);
+    if (en->type & FT_EXE) { /*io_can_exec (en->path)) */
+      /* here let's do a check if its a script file 
+       * and if it is, then runit in a terminal window.*/
+      char *cmd;
+      FILE *pipe;
+      gboolean doterminal=FALSE;
+      cmd=(char *)malloc(strlen("file \"xx\"")+strlen(en->path)+1);
+      if (cmd) {	
+         sprintf (cmd, "file \"%s\"",en->path);
+         pipe = popen (cmd, "r");
+       	 if (pipe)
+  	 {
+  	  char *p,line[LINE_MAX+1];
+  	  fgets (line, LINE_MAX, pipe);
+  	  line[LINE_MAX] = 0;
+   	  pclose (pipe);
+  	  if ((p = strstr (line, ": ")) != NULL){
+   	   p += 2;
+	   if (strstr(p,"script")) doterminal=TRUE;
+   	  }
+ 	 }
+	 g_free(cmd);
+      }
+	    
+      if (doterminal || (mod_mask & GDK_MOD1_MASK)){
+	argv[j++]=TERMINAL;
+	argv[j++]="-e";
+	argv[j++]=en->path;
+	argv[j]=0;
+      } else {
+	argv[j++]=en->path;
+	argv[j]=0;
+      }
+      io_system (argv,win->top); /* open directly */ 
+    }
+    else
+    {
+      /* call open with dialog */
+      prg = reg_prog_by_file (win->reg, en->path);
+      if (prg)
+      {
+	argv[j++]=prg->app;
+	if (prg->arg){
+	  if (strstr(prg->arg," ")){
+		a=g_strdup(prg->arg);
+		argv[j++]=strtok(a," ");
+		do {
+		      argv[j]=strtok(NULL," ");
+		      if (!argv[j]) break;
+		      j++;
+		      if (j>=24) { argv[24]=0; break; }
+
+	        } while (1);
+	  } else  argv[j++]=prg->arg;
+	  argv[j++]=en->path;
+	  argv[j]=0;
+	} else {
+	  argv[j++]=en->path;
+	  argv[j]=0;
+	}
+	io_system (argv,win->top); /* open direct */
+	if (a) g_free(a);
+      }
+      else
+      {
+	xf_dlg_open_with (ctree,win->xap, DEF_APP, en->path);
+      }
+    }
+    cursor_reset (GTK_WIDGET (ctree));
+    return (TRUE);
+}
     
 /*
- * start the marked program on double click
- */
+ * set drag set for ctree
+ *  */
+gboolean was_double_click=FALSE;
+static gint
+on_button_release (GtkWidget * ctree, GdkEventButton * event, void *menu){
+  cfg *win;
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  if (was_double_click) return 1;
+  if ( (event->button == 1)){
+     if (!win->source_set_sem) {
+        win->source_set_sem=TRUE;
+        gtk_drag_source_set (ctree, GDK_BUTTON1_MASK | GDK_BUTTON2_MASK, 
+		  target_table, NUM_TARGETS, 
+		  GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);
+     }
+  }
+  return 1;
+}
+
+/* 
+ * start the marked program on double click 
+ * */
 static gint
 on_double_click (GtkWidget * ctree, GdkEventButton * event, void *menu)
 {
   GtkCTreeNode *node;
-  entry *en, *up;
-  char cmd[(PATH_MAX + 3) * 2];
-  char *wd;
+  entry *en;
   cfg *win;
-  reg_t *prg;
   gint row, col;
   win = gtk_object_get_user_data (GTK_OBJECT (ctree));
     /*fprintf(stderr,"dbg:  click detected\n"); */
+
   if ((event->type == GDK_2BUTTON_PRESS) && (event->button == 1))
   {
     /*fprintf(stderr,"dbg: double click detected\n"); */
-	  
+    was_double_click=TRUE;	  
     /* check if the double click was over a directory */
     row = -1;
     gtk_clist_get_selection_info (GTK_CLIST (ctree), event->x, event->y, &row, &col);
@@ -291,9 +432,9 @@ on_double_click (GtkWidget * ctree, GdkEventButton * event, void *menu)
       if (EN_IS_DIR (en) && ((event->state & (GDK_MOD1_MASK | GDK_CONTROL_MASK)) || (win->preferences & DOUBLE_CLICK_GOTO)))
       {
         /* disable goto on FT_TARCHILD */
-        if (en->type & FT_TARCHILD) return TRUE;
+        if (en->type & (FT_RPMCHILD|FT_TARCHILD)) return TRUE;
         /* Alt or Ctrl button is pressed, it's the same as _go_to().. */
-	go_to (GTK_CTREE (ctree), GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list), en->path, en->flags);
+	go_to (GTK_CTREE (ctree), find_root((GtkCTree *)ctree), en->path, en->flags);
 	return (TRUE);
       }
     }
@@ -306,53 +447,8 @@ on_double_click (GtkWidget * ctree, GdkEventButton * event, void *menu)
       return (TRUE);
     }
     en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
-    /* disable openwith on FT_TARCHILD */
-    if (en->type & FT_TARCHILD) return TRUE;
-
-    if (en->type & FT_DIR_UP)
-    {
-      cb_go_up(NULL,GTK_CTREE (ctree)); 	    
-   /*   node = GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list);
-      go_to (GTK_CTREE (ctree), node, uri_clear_path (en->path), en->flags);*/
-      return (TRUE);
-    }
-    if (!(en->type & FT_FILE))
-      return (FALSE);
-    up = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), GTK_CTREE_ROW (node)->parent);
-    cursor_wait (GTK_WIDGET (ctree));
-
-    wd = getcwd (NULL, PATH_MAX);
-    chdir (up->path);
-    if (en->type & FT_EXE)
-    {				/*io_can_exec (en->path)) */
-      if (event->state & GDK_MOD1_MASK)
-	sprintf (cmd, "%s -e \"%s\" &", TERMINAL, en->path);
-      else
-	sprintf (cmd, "\"%s\" &", en->path);
-      io_system (cmd);
-    }
-    else
-    {
-      /* call open with dialog */
-      prg = reg_prog_by_file (win->reg, en->path);
-      if (prg)
-      {
-	if (prg->arg)
-	  sprintf (cmd, "\"%s\" %s \"%s\" &", prg->app, prg->arg, en->path);
-	else
-	  sprintf (cmd, "\"%s\" \"%s\" &", prg->app, en->path);
-	io_system (cmd);
-      }
-      else
-      {
-	xf_dlg_open_with (ctree,win->xap, "", en->path);
-      }
-    }
-    chdir (wd);
-    free (wd);
-    cursor_reset (GTK_WIDGET (ctree));
-    return (TRUE);
-  }
+    return startit(ctree,en,event->state, node);
+  } else was_double_click=FALSE;
   return (FALSE);
 }
 
@@ -422,42 +518,58 @@ on_button_press (GtkWidget * widget, GdkEventButton * event, void *data)
 	if (GTK_CLIST (ctree)->selection) num = selection_type (ctree, &node);
       }
     }
+    gtk_widget_hide(win->autotype_D);
     gtk_widget_hide(win->autotype_C);
-    if (node== GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list))
+    if (node==find_root((GtkCTree *)ctree))
 	    gtk_widget_hide(win->autotar_C);
     else gtk_widget_show(win->autotar_C);
     en = gtk_ctree_node_get_row_data (ctree, node); 
-    if (!(en->type & FT_TARCHILD)&&(num==MN_FILE)){
+    if (!(en->type & FT_TARCHILD)&&((num==MN_FILE)||(num==MN_DIR))){
       int i;
+      static char *text=NULL;
       GtkLabel *label;
       prg = reg_prog_by_file (win->reg, en->path);
       if (prg) {/* look in registered programs first */
         char cmd[(PATH_MAX + 3) * 2];
-        label=(GtkLabel *)(((GtkBin *)(win->autotype_C))->child);
+	GtkWidget *at;
+	if (num==MN_DIR) at=win->autotype_D;
+	else at=win->autotype_C;
+        label=(GtkLabel *)(((GtkBin *)(at))->child);
 	if (prg->arg) sprintf (cmd, "%s %s %s", prg->app, prg->arg, en->path);
 	else sprintf (cmd, "%s %s", prg->app, en->path);
 	gtk_label_set_text(label,cmd);
-	gtk_widget_show(win->autotype_C);
-      } else {/* use default autotypes */	       
+	gtk_widget_show(at);
+      } else if (num==MN_FILE) {/* use default autotypes */	      
        char *loc;
-       loc=strrchr(en->path,'.');
-       if (loc) for (i=0;1;i++){
+       /*loc=strrchr(en->path,'.'); if (loc) */
+       for (i=0;1;i++){
 	       if (autotype[i].extension==NULL) break;
-	       if (strcmp(loc,autotype[i].extension)==0){
+	       loc=strstr(en->path,autotype[i].extension);
+	       if ((loc)&&(strcmp(loc,autotype[i].extension)==0)){
 		       GtkLabel *label;
-	               static char *text=NULL;
 	               if (text) free(text);
 		       label=(GtkLabel *)(((GtkBin *)(win->autotype_C))->child);
-	               text=(char *)malloc(strlen(autotype[i].command)+strlen(en->label)+2);
+	               text=(char *)malloc(strlen(_(autotype[i].label))+strlen(en->label)+2);
 		       if (!text) break;
-	               sprintf(text,"%s %s",autotype[i].command,en->label);
+	               sprintf(text,"%s %s",_(autotype[i].label),en->label);
 		       gtk_label_set_text(label,text);
 		       gtk_widget_show(win->autotype_C);
 		       break;
 	       }
        }
+      } else if (num==MN_DIR) {/* use static directory entry default */
+		GtkLabel *label;
+	        if (text) free(text);
+		label=(GtkLabel *)(((GtkBin *)(win->autotype_D))->child);
+	        text=(char *)malloc(strlen(_("Open icon view"))+1);
+		if (text){
+		  sprintf(text,"%s",_("Open icon view"));
+  		  gtk_label_set_text(label,text);
+  		  gtk_widget_show(win->autotype_D);
+		}
       }
-    } else if   (!(en->type & FT_TARCHILD)&&(num==MN_DIR)){ 
+    } 
+    if (!(en->type & FT_TARCHILD)&&(num==MN_DIR)){ 
         GtkLabel *label;
         static char *text=NULL;
 	label=(GtkLabel *)(((GtkBin *)(win->autotar_C))->child);
@@ -483,10 +595,16 @@ on_button_press (GtkWidget * widget, GdkEventButton * event, void *data)
 static gint
 on_key_press (GtkWidget * ctree, GdkEventKey * event, void *menu)
 {
-  int num, i;
+  int num,i;
   entry *en;
   GtkCTreeNode *node;
-  GdkEventButton evbtn;
+  /*GdkEventButton evbtn;*/
+  GList *selection;
+  
+  selection = GTK_CLIST (ctree)->selection;
+  if ((num = g_list_length (GTK_CLIST (ctree)->selection))==0)return (TRUE);
+  node=selection->data;
+  en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree),node);
 
   switch (event->keyval)
   {
@@ -495,42 +613,24 @@ on_key_press (GtkWidget * ctree, GdkEventKey * event, void *menu)
     return (TRUE);
     break;
   case GDK_Return:
-    num = g_list_length (GTK_CLIST (ctree)->row_list);
-    for (i = 0; i < num; i++)
-    {
-      if (GTK_CLIST (ctree)->focus_row == i)
-      {
-	node = gtk_ctree_node_nth (GTK_CTREE (ctree), i);
-	en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
-	if (EN_IS_DIR (en) && !(en->type & FT_DIR_UP))
-	{
+    if (!en->path) return (TRUE); 
+    if ((en->type & FT_DIR) && !(en->type & FT_DIR_UP)){
 	  if (event->state & (GDK_MOD1_MASK | GDK_CONTROL_MASK))
 	  {
 	    /* Alt or Ctrl button is pressed, it's the same as _go_to().. */
-	    go_to (GTK_CTREE (ctree), GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list), en->path, en->flags);
+	    go_to (GTK_CTREE (ctree), find_root((GtkCTree *)ctree), en->path, en->flags);
 	    return (TRUE);
-	    break;
 	  }
-	  if (!GTK_CTREE_ROW (node)->expanded)
-	    gtk_ctree_expand (GTK_CTREE (ctree), node);
-	  else
-	    gtk_ctree_collapse (GTK_CTREE (ctree), node);
+	  if (!GTK_CTREE_ROW (node)->expanded) gtk_ctree_expand (GTK_CTREE (ctree), node);
+	  else gtk_ctree_collapse (GTK_CTREE (ctree), node);
 	  return (TRUE);
-	  break;
-	}
-      }
     }
-
-    evbtn.type = GDK_2BUTTON_PRESS;
-    evbtn.button = 1;
-    evbtn.state = event->state;
-    on_double_click (ctree, &evbtn, menu);
-    return (TRUE);
-    break;
-  default:
+    return startit(ctree,en,event->state, node);
+  default: /*FIXME: */
     if ((event->keyval >= GDK_A) && (event->keyval <= GDK_z) && (event->state <= GDK_SHIFT_MASK))
     {
       num = g_list_length (GTK_CLIST (ctree)->row_list);
+      /*(GTK_CLIST (ctree)->row_list);*/
       for (i = 0; i < num; i++)
       {
 	node = gtk_ctree_node_nth (GTK_CTREE (ctree), i);
@@ -564,6 +664,7 @@ my_compare (GtkCList * clist, gconstpointer ptr1, gconstpointer ptr2)
   entry *en1, *en2;
   char *loc1=NULL,*loc2=NULL;
   int type1, type2;
+  gboolean omit_subsort=FALSE;
     cfg *win;
     win = gtk_object_get_user_data (GTK_OBJECT (clist));
 
@@ -578,6 +679,7 @@ my_compare (GtkCList * clist, gconstpointer ptr1, gconstpointer ptr2)
     return (type1 < type2 ? -1 : 1);
   }
 
+  if ((en1->type & FT_DIR)||(en2->type & FT_DIR)) omit_subsort=TRUE;
   
 /* subsort by filetype */
   if (win->preferences&SUBSORT_BY_FILETYPE) {
@@ -591,7 +693,7 @@ my_compare (GtkCList * clist, gconstpointer ptr1, gconstpointer ptr2)
     /* please don't compare numbers as strings! */
     GtkCListCompareFunc compare;
     compare = (GtkCListCompareFunc) win->compare;
-    if (win->preferences&SUBSORT_BY_FILETYPE) {
+    if ((win->preferences&SUBSORT_BY_FILETYPE)&&(!omit_subsort)) {
 	  if ((!loc1)&&(!loc2)) { /* subsorted */
 	     if (clist->sort_column == COL_DATE){
 	       return en1->st.st_mtime - en2->st.st_mtime;
@@ -619,7 +721,7 @@ my_compare (GtkCList * clist, gconstpointer ptr1, gconstpointer ptr2)
   }
   
   /* special case, sorting by column name */
-  if (win->preferences&SUBSORT_BY_FILETYPE) {
+  if ((win->preferences&SUBSORT_BY_FILETYPE)&&(!omit_subsort)) {
     if ((!loc1)&&(!loc2)) return strcmp (en1->label, en2->label);
     if ((!loc1)&&(loc2)) return strcmp (".",loc2);
     if ((loc1)&&(!loc2)) return strcmp (loc1,".");
@@ -652,7 +754,9 @@ create_menu (GtkWidget * top, GtkWidget * ctree, cfg * win,GtkWidget *hlpmenu)
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
   {
     menu_entry mlist[] = {
+      MAINF_ICON_VIEW,
       MAINF_DIRECTORY_MENU,
+      REGISTER_MENU,
       MAINF_MENU,
       DIR_OR_FILE_MENU,
       NONE_MENU
@@ -817,6 +921,13 @@ create_menu (GtkWidget * top, GtkWidget * ctree, cfg * win,GtkWidget *hlpmenu)
   gtk_menu_append (GTK_MENU (menu), menuitem);  gtk_widget_show (menuitem);
   gtk_signal_connect (GTK_OBJECT (menuitem), "activate", 
 		    GTK_SIGNAL_FUNC (cb_drag_copy), (gpointer) ctree);
+  
+  menuitem = gtk_check_menu_item_new_with_label (_("Use rsync instead of scp"));
+  GTK_CHECK_MENU_ITEM (menuitem)->active = (USE_RSYNC & preferences)?1:0;
+  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menuitem), 1);
+  gtk_menu_append (GTK_MENU (menu), menuitem);  gtk_widget_show (menuitem);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate", 
+		    GTK_SIGNAL_FUNC (cb_use_rsync), (gpointer) ctree);
 
 #if 0
   shortcut_menu (menu, _("Save geometry on exit"), (gpointer) cb_toggle_preferences, 
@@ -856,10 +967,21 @@ create_menu (GtkWidget * top, GtkWidget * ctree, cfg * win,GtkWidget *hlpmenu)
   menu = gtk_menu_new ();
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
   
+  menuitem = gtk_menu_item_new_with_label (_("Icon view"));
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate", GTK_SIGNAL_FUNC (cb_help_iv), ctree);
+  gtk_menu_append (GTK_MENU (menu), menuitem);
+  gtk_widget_show (menuitem);
+
   menuitem = gtk_menu_item_new_with_label (_("Drag and drop"));
   gtk_signal_connect (GTK_OBJECT (menuitem), "activate", GTK_SIGNAL_FUNC (cb_dnd_help), ctree);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
+  
+  menuitem = gtk_menu_item_new_with_label (_("Rsync and scp"));
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate", GTK_SIGNAL_FUNC (cb_rsync), ctree);
+  gtk_menu_append (GTK_MENU (menu), menuitem);
+  gtk_widget_show (menuitem);
+
 
 
   menuitem = gtk_menu_item_new_with_label (_("Unlisted shortcut keys"));
@@ -915,16 +1037,20 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
   GtkCTreeNode *root;
   gchar *label[COLUMNS];
   gchar *titles[COLUMNS];
-  char *icon_name;
   entry *en;
   cfg *win;
   GtkAccelGroup *inner_accel;
   int i;
   struct passwd *pw;
   struct group *gr;
+  GdkAtom atomo;
 
+	  
   menu_entry dir_mlist[] = {
+    AUTOTYPE_MENU,
     MAINF_DIRECTORY_MENU,
+    FILE_MENU,
+    REGISTER_MENU,
     AUTOTAR_MENU,
     DIRECTORY_MENU,
     MAINF_MENU,
@@ -938,6 +1064,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
 
 
   menu_entry tarchild_mlist[] = {
+     TAR_MENU,
      DIR_FILE_MENU,
      MAINF_MENU,
      NONE_MENU
@@ -949,6 +1076,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
   menu_entry file_mlist[] = {
      AUTOTYPE_MENU,
      FILE_MENU,
+     REGISTER_MENU,
      DIR_FILE_MENU,
      MAINF_MENU,
      DIR_OR_FILE_MENU,
@@ -989,6 +1117,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
   XSetErrorHandler ((XErrorHandler) ErrorHandler);
 
   win = g_malloc (sizeof (cfg));
+  win->source_set_sem=FALSE;
   win->dnd_row = -1;
   win->dnd_data = NULL;
   win->gogo =NULL;
@@ -1006,14 +1135,38 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
   win->top = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_policy ((GtkWindow *)win->top,FALSE,TRUE,FALSE);
   gtk_widget_realize (win->top);
-    
+
   win->gogo = pushgo(path,win->gogo);
                                               
   top_register (win->top);
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (win->top), vbox);
   gtk_widget_show (vbox);
-
+  
+  atomo=gdk_atom_intern("WM_COMMAND",FALSE);
+  gdk_property_change (gtk_widget_get_parent_window(vbox),
+		  atomo,
+                  XA_STRING, /* GdkAtom type,*/
+                  8, /* bit per data element: gint format*/
+ 	      	  GDK_PROP_MODE_REPLACE,
+                  (guchar *)"xftree",  
+		  strlen("xftree")+1);  
+  
+#if 0
+  atomo=gdk_atom_intern("WM_CLIENT_MACHINE",FALSE);
+  gdk_property_change (gtk_widget_get_parent_window(vbox),
+		  atomo,
+                  XA_STRING, /* GdkAtom type,*/
+                  8, /* bit per data element: gint format*/
+ 	      	  GDK_PROP_MODE_REPLACE,
+                  (guchar *)our_host_name(),  
+		  strlen(our_host_name())+1);  
+#endif 
+  atomo=gdk_atom_intern("WM_CLIENT_LEADER",TRUE);
+  if (atomo != GDK_NONE) {
+	  gdk_property_delete (gtk_widget_get_parent_window(vbox),atomo);
+  }
+  
   for (i=0;i<4;i++) {
 	  handlebox[i] = gtk_handle_box_new ();
 	  gtk_container_border_width (GTK_CONTAINER (handlebox[i]), 2);
@@ -1029,8 +1182,15 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
   gtk_box_pack_start (GTK_BOX (vbox),widget, FALSE, FALSE, 0);
   gtk_widget_show (widget);
   
+#ifdef STATUS_LABEL
   win->status = gtk_label_new("");
   gtk_box_pack_start (GTK_BOX (widget), win->status, FALSE, FALSE, 0);
+#else
+  win->status = gtk_entry_new();
+  gtk_entry_set_editable((GtkEntry *)win->status,FALSE);
+  gtk_entry_set_max_length ((GtkEntry *)win->status,256);
+  gtk_box_pack_start (GTK_BOX (widget), win->status, TRUE, TRUE, 0);
+#endif  
   gtk_widget_show (win->status); 
   
   ctree = gtk_ctree_new_with_titles (COLUMNS, 0, titles);
@@ -1149,6 +1309,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
       menu_item = gtk_menu_item_new_with_label (_(dir_mlist[i].label));
     else
       menu_item = gtk_menu_item_new ();
+    if (!i) win->autotype_D=menu_item;	    
     if (dir_mlist[i].func)
     {
       if (dir_mlist[i].func==cb_autotar) win->autotar_C=menu_item;
@@ -1292,15 +1453,19 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
 /* first pixmap appearance */
   
   
-  en = entry_new_by_path_and_label (path, path);
+  en = entry_new_by_path_and_label (path, (preferences&ABREVIATE_PATHS)?abreviate(path):path);
   if (!en)
   {
+    cleanup_tmpfiles();
     exit (1);
   }
   en->flags = flags;
+  en->type |= FT_ISROOT;
 
-  if (preferences&ABREVIATE_PATHS) label[COL_NAME] = abreviate(path);
-  else label[COL_NAME] = path; 
+  if (preferences & ABREVIATE_PATHS) {
+	  label[COL_NAME] = abreviate(path);
+  } else label[COL_NAME] = path; 
+  
   label[COL_SIZE] = "";
   label[COL_DATE] = "";
   
@@ -1309,24 +1474,19 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
   label[COL_UID] = (pw)? pw->pw_name : _("unknown");
   gr=getgrgid (en->st.st_gid); 
   label[COL_GID] = (gr)? gr->gr_name : _("unknown");
-  {
-    icon_pix pix;
-    set_icon_pix(&pix,en->type,en->label);   
-    root = gtk_ctree_insert_node (GTK_CTREE (ctree), NULL, NULL, label, 8, 
-		  pix.pixmap,pix.pixmask,
-		  pix.open,pix.openmask,
+  root = gtk_ctree_insert_node (GTK_CTREE (ctree), NULL, NULL, label, 8, 
+		  NULL, NULL,NULL, NULL,
 		  FALSE, TRUE);  
-  } 
   gtk_ctree_node_set_row_data_full (GTK_CTREE (ctree), root, en, node_destroy);
   add_subtree (GTK_CTREE (ctree), root, path, 2, flags);
-  for (i = 0; i < COLUMNS; i++)  gtk_clist_set_column_width ((GtkCList *)ctree,
-		  i,gtk_clist_optimal_column_width ((GtkCList *)ctree,i));
+  reset_icon(GTK_CTREE (ctree), root); 
+  gtk_ctree_select (GTK_CTREE (ctree), root);
 
-
-  gtk_signal_connect (GTK_OBJECT (ctree), "tree_expand", GTK_SIGNAL_FUNC (on_expand), path);
-  gtk_signal_connect (GTK_OBJECT (ctree), "tree_collapse", GTK_SIGNAL_FUNC (on_collapse), path);
+  gtk_signal_connect (GTK_OBJECT (ctree), "tree_expand", GTK_SIGNAL_FUNC (on_expand), NULL);
+  gtk_signal_connect (GTK_OBJECT (ctree), "tree_collapse", GTK_SIGNAL_FUNC (on_collapse), NULL);
   gtk_signal_connect (GTK_OBJECT (ctree), "click_column", GTK_SIGNAL_FUNC (on_click_column), en);
   gtk_signal_connect_after (GTK_OBJECT (ctree), "button_press_event", GTK_SIGNAL_FUNC (on_double_click), root);
+  gtk_signal_connect_after (GTK_OBJECT (ctree), "button_release_event", GTK_SIGNAL_FUNC (on_button_release), root);
   gtk_signal_connect (GTK_OBJECT (ctree), "button_press_event", GTK_SIGNAL_FUNC (on_button_press), menu);
   gtk_signal_connect (GTK_OBJECT (ctree), "key_press_event", GTK_SIGNAL_FUNC (on_key_press), menu);
   gtk_signal_connect (GTK_OBJECT (ctree), "drag_data_received", GTK_SIGNAL_FUNC (on_drag_data), win);
@@ -1337,27 +1497,45 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
                               
 
 
-  set_title_ctree (ctree, en->path);
   if (win->width > 0 && win->height > 0)
   {
     gtk_window_set_default_size (GTK_WINDOW (win->top), width, height);
   }
 
   win->timer = gtk_timeout_add (TIMERVAL, (GtkFunction) update_timer, ctree);
-  gtk_drag_source_set (ctree, GDK_BUTTON1_MASK | GDK_BUTTON2_MASK, target_table, NUM_TARGETS, GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);
-  gtk_drag_dest_set (ctree, GTK_DEST_DEFAULT_DROP|GTK_DEST_DEFAULT_HIGHLIGHT, target_table, NUM_TARGETS, GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);
+  
+  /*
+   * DO NOT put gtk_drag_source_set here. It is very buggy if you do.
+   * Instead set at first mouse click and unset on expand+contract
+   * (inherent GtkCTree bug workaround)
+   * gtk_drag_source_set (ctree, GDK_BUTTON1_MASK | GDK_BUTTON2_MASK, 
+		  target_table, NUM_TARGETS, 
+		  GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);*/
+  
+  gtk_drag_dest_set (ctree, GTK_DEST_DEFAULT_DROP|GTK_DEST_DEFAULT_HIGHLIGHT, 
+		  target_table, NUM_TARGETS, 
+		  GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);
+		  
 	  
   menutop = create_menu (win->top, ctree, win, menu[MN_HLP]);
   gtk_container_add (GTK_CONTAINER (handlebox[0]), menutop);
   gtk_widget_show (menutop);
   win->menu = menutop;
 
-  
   toolbar = create_toolbar (win->top, ctree, win,FALSE);
   gtk_container_add (GTK_CONTAINER (handlebox[1]), toolbar);
   gtk_widget_show (toolbar);
   win->toolbar=toolbar;
   
+  {
+    GtkStyle *Ostyle,*style;
+    Ostyle=gtk_widget_get_style (toolbar);
+    style = gtk_style_copy (Ostyle);
+    gtk_widget_set_style (win->status,style);
+    gtk_widget_ensure_style (win->status);
+   
+  }
+  
   toolbar = create_toolbar (win->top, ctree, win,TRUE);
   gtk_container_add (GTK_CONTAINER (handlebox[2]), toolbar);
   gtk_widget_show (toolbar);
@@ -1393,11 +1571,22 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width, int height,
       gtk_clist_column_titles_hide((GtkCList *)ctree);
   }
   
-  icon_name = strrchr (path, '/');
-  if ((icon_name) && (!(*(++icon_name))))
-    icon_name = NULL;
+/*  win->iconname = (char *)malloc((strlen("XFTree: ")+strlen(path)+1)*sizeof(char));
+  if (win->iconname) {
+   if (strncmp(path,getenv ("HOME"),strlen(getenv ("HOME")))==0){	  
+     sprintf(win->iconname,"~%s",path+strlen(getenv ("HOME")));
+   } else sprintf (win->iconname, "%s", (path)?path:"/");
+   gdk_window_set_icon_name (gtk_widget_get_toplevel (GTK_WIDGET (ctree))->window, 
+		  win->iconname);
+  } */
+  win->iconname = NULL;
+  set_icon (win->top,win->iconname, xftree_icon_xpm);
+  set_title_ctree (ctree, en->path);
+  
 
-  set_icon (win->top, (icon_name ? icon_name : "/"), xftree_icon_xpm);
+ /* icon_name = strrchr (path, '/');
+  if ((icon_name) && (!(*(++icon_name)))) icon_name = NULL;
+  set_icon (win->top, (icon_name ? icon_name : "/"), xftree_icon_xpm);*/
 
   gtk_clist_set_column_visibility ((GtkCList *)ctree,COL_DATE,!(preferences & HIDE_DATE));
   gtk_clist_set_column_visibility ((GtkCList *)ctree,COL_SIZE,!(preferences & HIDE_SIZE));
@@ -1421,6 +1610,9 @@ gui_main (char *path, char *xap_path, char *trash, char *reg_file, wgeo_t * geo,
   init_pixmaps();  
 
   reg = reg_build_list (reg_file);
+  /* clean up stale entries should be cleaned with reg_build */
+  /* now save clean register */
+  reg_save(reg);
   if (SAVE_GEOMETRY & preferences){
 	  geo->width=geometryX;
 	  geo->height=geometryY;
@@ -1438,5 +1630,6 @@ gui_main (char *path, char *xap_path, char *trash, char *reg_file, wgeo_t * geo,
 
   gtk_main ();
   save_defaults(NULL);
+  cleanup_tmpfiles();
   exit (0);
 }
