@@ -27,9 +27,9 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "icons.h"
-#include "xtree_icons.h"
-#include "entry.h"
+#include "../xftree/icons.h"
+#include "../xftree/xtree_icons.h"
+#include "../xftree/ft_types.h"
 #include "xpmext.h"
 
 #ifdef HAVE_GDK_PIXBUF
@@ -60,6 +60,10 @@ enum
   PIX_DIR_OPEN=0, 
   PIX_DIR_CLOSE,PIX_DIR_UP,
   PIX_DIR_PD,
+  PIX_DIR_RO,
+  PIX_DIR_RO_OPEN,PIX_DIR_RO_OPEN_DOT,PIX_DIR_OPEN_DOT,
+  PIX_DIR_OPEN_HIDDEN,PIX_DIR_RO_OPEN_HIDDEN,
+  PIX_PD,
   PIX_PAGE,PIX_PAGE_C,PIX_PAGE_F,PIX_PAGE_O,
   	PIX_PAGE_H,PIX_PAGE_LNK,PIX_CORE,PIX_TAR,
 	PIX_COMPRESSED,PIX_IMAGE,PIX_TEXT,PIX_MAIL,
@@ -79,6 +83,9 @@ enum
   PIX_STALE_LNK,
   PIX_EXE,PIX_EXE_SCRIPT,PIX_EXE_LINK,
   PIX_EXE_FILE,
+  PIX_COMP1,PIX_COMP2,
+  PIX_WG1,PIX_WG2,
+  PIX_PRINT,
   LAST_PIX
 };
 /* don't repeat masks that already exist */
@@ -90,6 +97,7 @@ enum
   PIM_LINKFLAG, 
   PIM_EXEFLAG, 
   PIM_DIR_PD,
+  PIM_PD,
   PIM_PAGE,
   PIM_PAGE_HTML, 
   PIM_CHAR_DEV,
@@ -100,6 +108,9 @@ enum
   PIM_CORE,
   PIM_EXE_FILE,
   PIM_STALE_LNK,
+  PIM_COMP,
+  PIM_WG,
+  PIM_PRINT,
   LAST_PIM
 };
 
@@ -125,6 +136,13 @@ static pixmap_list pixmaps[]={
 	{gPIX+PIX_PO,		NULL,			page_po_xpm},
 	{gPIX+PIX_BAK,		NULL,			page_backup_xpm},
 	{gPIX+PIX_DIR_PD,	NULL,			dir_pd_xpm},
+	{gPIX+PIX_PD,		gPIM+PIM_PD,		pd_xpm},
+	{gPIX+PIX_DIR_RO,	NULL,			dir_ro_xpm},
+	{gPIX+PIX_DIR_RO_OPEN,	NULL,			dir_ro_open_xpm},
+  {gPIX+PIX_DIR_RO_OPEN_DOT,	NULL,			dir_ro_open_dot_xpm},
+	{gPIX+PIX_DIR_OPEN_DOT,	NULL,			dir_open_dot_xpm},
+  {gPIX+PIX_DIR_RO_OPEN_HIDDEN,	NULL,			dir_ro_open_hidden_xpm},
+  {gPIX+PIX_DIR_OPEN_HIDDEN,	NULL,			dir_open_hidden_xpm},
 	{gPIX+PIX_DIR_OPEN,	gPIM+PIM_DIR_OPEN,	dir_open_xpm},
 	{gPIX+PIX_DIR_CLOSE,	gPIM+PIM_DIR_CLOSE,	dir_close_xpm},
 	{gPIX+PIX_DIR_UP,	NULL,			dir_up_xpm},
@@ -136,6 +154,11 @@ static pixmap_list pixmaps[]={
 	{gPIX+PIX_PAGE_HTML,	gPIM+PIM_PAGE_HTML,	page_html_xpm},
 	{gPIX+PIX_STALE_LNK,	gPIM+PIM_STALE_LNK,	stale_lnk_xpm},
 	{gPIX+PIX_EXE_FILE,	gPIM+PIM_EXE_FILE,	exe_file_xpm},
+	{gPIX+PIX_COMP1,	gPIM+PIM_COMP,		comp1_xpm},
+	{gPIX+PIX_COMP2,	NULL,			comp2_xpm},
+	{gPIX+PIX_WG1,		gPIM+PIM_WG,		wg1_xpm},
+	{gPIX+PIX_WG2,		NULL,			wg2_xpm},
+	{gPIX+PIX_PRINT,	gPIM+PIM_PRINT,		print_xpm},
 	{NULL,NULL,NULL}
 };
 
@@ -265,7 +288,9 @@ static gboolean ps_type(char *loc){
 }
 static gboolean packed_type(char *loc){
   char *Type[]={
-	  ".deb",".rpm",".cpio",
+	  ".rpm",
+	  ".deb",
+	  /* ".cpio",*/
 	  NULL
   };
   return checkif_type(Type,loc);			    
@@ -355,7 +380,7 @@ static void create_higher_bitmap(int PIMid){
 
 
 
-gboolean set_icon_pix(icon_pix *pix,int type,char *label) {
+gboolean set_icon_pix(icon_pix *pix,int type,char *label,int flags) {
   char *loc,*loc2;
   gboolean isleaf=TRUE;
   int PIXid[4];
@@ -363,9 +388,31 @@ gboolean set_icon_pix(icon_pix *pix,int type,char *label) {
   /*defaults :*/
   PIXid[0]=PIXid[2]=PIX_PAGE;
   PIXid[1]=PIXid[3]=PIM_PAGE;
+  /* error defaults */
+  if (type&FT_PD){
+   PIXid[0]=PIXid[2]=PIX_PD;
+   PIXid[1]=PIXid[3]=PIM_PD;
+  }
 
+ /* smb type icons */
+  if (type&FT_SMB){
+      if (type&FT_PRINT){PIXid[0]=PIX_PRINT,PIXid[1]=PIM_PRINT;}
+      if (type&FT_COMP1){PIXid[0]=PIX_COMP1,PIXid[1]=PIM_COMP;}
+      if (type&FT_COMP2){PIXid[0]=PIX_COMP2,PIXid[1]=PIM_COMP;}
+      if (type&FT_WG1){PIXid[0]=PIX_WG1,PIXid[1]=PIM_WG;}
+      if (type&FT_WG2){PIXid[0]=PIX_WG2,PIXid[1]=PIM_WG;}
+      /*if (type&FT_HIDDEN){PIXid[0]=PIX_HIDDEN,PIXid[1]=PIM_HIDDEN;}
+      if (type&FT_READONLY){PIXid[0]=PIX_READONLY,PIXid[1]=PIM_READONLY;}*/
+      goto icon_identified;	  
+  }
+  
   /* directories: no icon flag applied */
-  if (type & FT_DIR){
+ if (type & FT_DIR_UP){
+      PIXid[0]=PIX_DIR_UP;
+      PIXid[1]=PIM_DIR_CLOSE;
+      goto icon_identified;
+ } 
+ if (type & FT_DIR){
      PIXid[1]=PIM_DIR_CLOSE;
      PIXid[3]=PIM_DIR_OPEN;
      isleaf=FALSE;   
@@ -379,25 +426,27 @@ gboolean set_icon_pix(icon_pix *pix,int type,char *label) {
 	}	
       } else {
  	PIXid[0]=PIX_DIR_CLOSE;
-        PIXid[2]=PIX_DIR_OPEN;
+        if (flags & IGNORE_HIDDEN) {
+		if (flags & HIDDEN_PRESENT) PIXid[2]=PIX_DIR_OPEN_HIDDEN;
+		else PIXid[2]=PIX_DIR_OPEN;
+	} else PIXid[2]=PIX_DIR_OPEN_DOT; 
         PIXid[1]=PIM_DIR_CLOSE;
         PIXid[3]=PIM_DIR_OPEN;
       }
+      if (type & FT_DIR_PD) {
+       PIXid[0]=PIX_DIR_PD;
+       PIXid[2]=PIX_DIR_OPEN;
+      }
+      if (type & FT_DIR_RO) {
+       PIXid[0]=PIX_DIR_RO;
+       if (flags & IGNORE_HIDDEN) {
+	       if (flags & HIDDEN_PRESENT) PIXid[2]=PIX_DIR_RO_OPEN_HIDDEN;
+	       else PIXid[2]=PIX_DIR_RO_OPEN;
+       }
+       else PIXid[2]=PIX_DIR_RO_OPEN_DOT;
+      }
       goto icon_identified;
-  } else if (type & FT_DIR_UP){
-      PIXid[0]=PIX_DIR_UP;
-      PIXid[1]=PIM_DIR_CLOSE;
-      goto icon_identified;
-  } else if (type & FT_DIR_PD) {
-      isleaf=FALSE;
-      PIXid[0]=PIX_DIR_PD;
-      PIXid[1]=PIM_DIR_CLOSE;
-      PIXid[2]=PIX_DIR_OPEN;
-      PIXid[3]=PIM_DIR_OPEN;
-      goto icon_identified;
-  }
-
-  /* whatever it is, it's not a directory */
+  }   /* whatever it is, it's not a directory */
 
   /* special files : */
   if (type & FT_CHAR_DEV){ PIXid[0]=PIX_CHAR_DEV,PIXid[1]=PIM_CHAR_DEV; }
@@ -410,6 +459,7 @@ gboolean set_icon_pix(icon_pix *pix,int type,char *label) {
 
   /* assignment by filetype */
   /* case one: whole file label */
+  if (!label) goto icon_identified;
 
    if (strcmp(label,"core")==0) {
        PIXid[0]=PIX_CORE;
@@ -426,13 +476,18 @@ gboolean set_icon_pix(icon_pix *pix,int type,char *label) {
    else if (text_type(loc))PIXid[0]= PIX_TEXT;
    else if (ps_type(loc))PIXid[0]=PIX_PS;
    else if (adobe_type(loc))PIXid[0]=PIX_ADOBE;
-   else if (packed_type(loc)){PIXid[0]=PIX_PACKAGE,PIXid[1]=PIM_PACKAGE;}
+   else if (packed_type(loc)){
+	   PIXid[0]=PIX_PACKAGE,PIXid[1]=PIM_PACKAGE;
+	   PIXid[2]=PIX_PACKAGE,PIXid[3]=PIM_PACKAGE;
+   }
    else if (compressed_type(loc)) {PIXid[0]=PIX_COMPRESSED,PIXid[2]=PIX_COMPRESSED,PIXid[3]=PIM_PAGE;}
    else if (www_type(loc)) {PIXid[0]=PIX_PAGE_HTML,PIXid[1]=PIM_PAGE_HTML;}
    else if (audio_type(loc))PIXid[0]= PIX_PAGE_AUDIO;
    else if (movie_type(loc))PIXid[0]= PIX_PAGE_AUDIO;
+   else if (strcmp(loc,".obj")==0) PIXid[0]=PIX_PAGE_O;
    else if (strcmp(loc,".po")==0) PIXid[0]=PIX_PO;
    else if (strcmp(loc,".tar")==0){PIXid[0]=PIX_TAR;PIXid[2]=PIX_TAR;PIXid[3]=PIM_PAGE;}
+   else if ((strcmp(loc,".exe")==0)||(strcmp(loc,".EXE")==0)){PIXid[0]=PIX_EXE_FILE;PIXid[1]=PIM_EXE_FILE;}
    else if (strlen(loc)==2) switch (loc[1]){
       case 'c': PIXid[0]=PIX_PAGE_C; break;
       case 'h': PIXid[0]=PIX_PAGE_H; break;
@@ -442,6 +497,7 @@ gboolean set_icon_pix(icon_pix *pix,int type,char *label) {
    }
 
 icon_identified:
+   if (type & (FT_TAR|FT_RPM)) isleaf=FALSE;   
    {
     int offsetB=0,offsetP=0; 
     if ((type & FT_EXE) && (PIXid[0]==PIX_PAGE)) {
