@@ -84,6 +84,18 @@
 static GdkFont *the_font; 
 static char *custom_font=NULL;
 
+GtkCTreeNode *find_root(GtkCTree * ctree){
+	GtkCTreeNode *node=NULL;
+	entry *en;
+	node=gtk_ctree_node_nth (ctree,0);
+	while (node){
+		en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
+		if (en->type & FT_ISROOT) return node;
+		node = GTK_CTREE_ROW (node)->sibling;
+	}
+	return node;
+}
+
 int set_fontT(GtkWidget * ctree){
 	GtkStyle  *Ostyle,*style;
 	Ostyle=gtk_widget_get_style (ctree);
@@ -276,6 +288,17 @@ void cb_filter_files(GtkWidget * widget, GtkWidget *ctree)
   return;
 
 }
+void
+cb_hide_dd (GtkWidget * widget, GtkWidget *ctree)
+{
+  cfg *win;
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  win->preferences ^= HIDE_DD;
+  preferences = win->preferences;
+  cb_reload(widget, (gpointer) ctree);
+  save_defaults(NULL);
+  return;
+}
 
 void
 cb_hide_mode (GtkWidget * widget, GtkWidget *ctree)
@@ -634,7 +657,7 @@ void cb_status_follows_expand(GtkWidget * widget, GtkWidget *ctree)
   cfg *win;
   entry *en;
   GtkCTreeNode *root;
-  root = GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list);
+  root = find_root((GtkCTree *)ctree);
 
   en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), root);
 
@@ -657,7 +680,7 @@ void cb_show_status(GtkWidget * widget, GtkWidget *ctree)
   entry *en;
   GtkCTreeNode *root;
 
-  root = GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list);
+  root = find_root((GtkCTree *)ctree);
   en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), root);
   win = gtk_object_get_user_data (GTK_OBJECT (ctree));
   
@@ -684,8 +707,7 @@ void cb_short_titles(GtkWidget * widget, GtkWidget *ctree)
   cfg *win;
   entry *en;
   GtkCTreeNode *root;
-  root = GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list);
-
+  root = find_root((GtkCTree *)ctree);
   win = gtk_object_get_user_data (GTK_OBJECT (ctree)); 
   win->preferences ^= SHORT_TITLES;
   preferences = win->preferences;
@@ -731,6 +753,16 @@ cb_save_geo (GtkWidget * widget, gpointer ctree)
   save_defaults (NULL);
 }
 
+void
+cb_use_rsync (GtkWidget * widget, gpointer ctree)
+{
+  cfg *win;
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  win->preferences ^= USE_RSYNC;
+  preferences = win->preferences;
+  save_defaults (NULL);
+}
+
 void
 cb_doubleC_goto (GtkWidget * widget, gpointer ctree)
 {
@@ -759,6 +791,31 @@ void cb_custom_SCK(GtkWidget * item, GtkWidget * ctree)
 	    );
 }
 
+void cb_help_iv(GtkWidget * item, GtkWidget * ctree)
+{
+  cfg *win;
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  xf_dlg_info (win->top, _("The Xftree icon view is the ROX-filer. At the moment this has to be installed\n" 
+"separately from XFCE. A ROX-filer specific for XFCE will soon be available.")
+	    );
+}
+
+void cb_rsync(GtkWidget * item, GtkWidget * ctree)
+{
+  cfg *win;
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  xf_dlg_info (win->top, _("Xftree allows you to drag and drop to/from\n"
+			  "xftree windows running on different hosts.\n"
+			  "You may use either scp or rsync for the copying.\n"
+			  "User authentication is done by ssh.\n"
+			  "See \"man ssh\" if you desire host based\n"
+			  "instead of password based authentication.\n\n"
+			  "Xftree will also accept drops from other\n"
+			  "filemanagers running on different hosts.\n"
+			  )
+	    );
+}
+
 void cb_registered(GtkWidget * item, GtkWidget * ctree)
 {
   cfg *win;
@@ -778,8 +835,11 @@ void cb_dnd_help(GtkWidget * item, GtkWidget * ctree)
 "SHIFT-CTRL drag+drop --> link\n"
 "The default drag+drop action is move,\n" 
 "but can be changed in the preferences menu.\n"
-"To drag multiple files, use the middle button.\n")
-	    );
+"To drag multiple files, use the middle button.\n"
+"Also:\n"
+"Multiple selection by button 1 click-and-drag\n"
+"is available on the first click after a GOTO or REGEN.\n")
+	);
 }
 
 void cb_default_SCK(GtkWidget * item,  GtkWidget * ctree)
@@ -820,8 +880,9 @@ show_cat (char *message)
   if (cat != NULL)
   {
     gtk_text_insert (GTK_TEXT (text), NULL, NULL, NULL, message, strlen (message));
-    if (!GTK_WIDGET_VISIBLE (cat))
-      gtk_widget_show (cat);
+    if (!GTK_WIDGET_VISIBLE (cat)) gtk_widget_show (cat);
+    gdk_window_raise (cat->window);
+    
     return;
   }
 
@@ -829,7 +890,7 @@ show_cat (char *message)
   gtk_container_border_width (GTK_CONTAINER (cat), 5);
   gtk_widget_set_usize(cat,350,200);
 
-  gtk_window_position (GTK_WINDOW (cat), GTK_WIN_POS_CENTER);
+  gtk_window_position (GTK_WINDOW (cat), GTK_WIN_POS_MOUSE);
   gtk_window_set_title (GTK_WINDOW (cat),_("Xftree results"));
   gtk_widget_realize (cat);
   if (preferences & SMALL_DIALOGS) gdk_window_set_decorations (cat->window,GDK_DECOR_BORDER);
@@ -934,28 +995,54 @@ xf_dirent *xf_opendir(char *path,GtkWidget *ctree){
 #define GLOB_APPEND 0
        win->filterOpts = (FILTER_DIRS|FILTER_FILES);
 #endif  
-       
+#ifndef GLOB_NOSPACE
+#define GLOB_NOSPACE 34554
+#endif         
        if (win->filterOpts == (FILTER_DIRS|FILTER_FILES)) {
           /*fprintf(stderr,"dbg:dirandfiles....(%d)**********\n",win->filterOpts);*/
 	       /* both files and dirs are filtered */
-	       glob (diren->globstring, GLOB_ERR | GLOB_PERIOD, NULL, &(diren->dirlist));
+	       if (glob (diren->globstring, GLOB_ERR | GLOB_PERIOD, NULL, &(diren->dirlist))
+			       ==GLOB_NOSPACE){
+		       fprintf(stderr,"xftree:insufficient resources for filtering %s\n",diren->globstring);
+		       free(diren->globstring);
+      	       	       globfree(&(diren->dirlist));
+                       free (diren);
+                       diren=NULL;
+	       }
        } else if (win->filterOpts == FILTER_FILES){
           /*fprintf(stderr,"dbg:only files....**********\n");*/
 	       /* only files are filtered. duplicate directories zapped at xf_readdir() */
-	       glob (diren->globstar, GLOB_ERR | GLOB_PERIOD | GLOB_ONLYDIR, 
-		      NULL, &(diren->dirlist));
-	       glob (diren->globstring,
+	       if ((glob (diren->globstar, GLOB_ERR | GLOB_PERIOD | GLOB_ONLYDIR, 
+		      NULL, &(diren->dirlist))
+			       ==GLOB_NOSPACE)
+		|| (glob (diren->globstring,
 		      GLOB_ERR | GLOB_PERIOD | GLOB_APPEND | GLOB_MARK, 
-		      NULL, &(diren->dirlist));	       	       
+		      NULL, &(diren->dirlist))
+			       ==GLOB_NOSPACE)){
+		       fprintf(stderr,"xftree:insuficient resources for filtering %s\n",diren->globstring);
+		       free(diren->globstring);
+      	       	       globfree(&(diren->dirlist));
+                       free (diren);
+                       diren=NULL;
+	       }
+	 			
        } 
        else { 
 	       /* only directories are filtered */
           /*fprintf(stderr,"dbg:dirs....**********\n");*/
- 	       glob (diren->globstring, GLOB_ERR | GLOB_PERIOD | GLOB_ONLYDIR , 
-		      NULL, &(diren->dirlist));
-	       glob (diren->globstar,
+ 	       if ((glob (diren->globstring, GLOB_ERR | GLOB_PERIOD | GLOB_ONLYDIR , 
+		      NULL, &(diren->dirlist))
+			       ==GLOB_NOSPACE)
+		|| (glob (diren->globstar,
 		      GLOB_ERR | GLOB_PERIOD | GLOB_APPEND |  GLOB_MARK, 
-		      NULL, &(diren->dirlist));
+		      NULL, &(diren->dirlist))
+			       ==GLOB_NOSPACE)){
+		       fprintf(stderr,"xftree:insuficient resources for filtering %s\n",diren->globstring);
+		       free(diren->globstring);
+      	       	       globfree(&(diren->dirlist));
+                       free (diren);
+                       diren=NULL;
+	       }
       }
      } /* end if filtered by glob */
      return diren;	      
@@ -1067,3 +1154,64 @@ void cb_custom_home(GtkWidget *widget,gpointer ctree){
   save_defaults(win->top);
   return;
 }
+
+void cleanup_tmpfiles(void){
+   glob_t dirlist;
+   int i;
+   if (glob ("/tmp/xftree*", GLOB_ERR ,NULL, &dirlist) != 0) {
+		  /*fprintf (stderr, "dbg:%s: no match\n", globstring);*/
+	return;
+   } else for (i = 0; i < dirlist.gl_pathc; i++) {
+	   unlink(dirlist.gl_pathv[i]);
+   }
+}
+
+gboolean
+sane (char *bin)
+{
+  char *spath, *path, *globstring;
+  glob_t dirlist;
+
+  /* printf("getenv=%s\n",getenv("PATH")); */
+  if (getenv ("PATH"))
+  {
+    path = (char *) malloc (strlen (getenv ("PATH")) + 2);
+    strcpy (path, getenv ("PATH"));
+    strcat (path, ":");
+  }
+  else
+  {
+    path = (char *) malloc (4);
+    strcpy (path, "./:");
+  }
+
+  globstring = (char *) malloc (strlen (path) + strlen (bin) + 1);
+
+/* printf("path=%s\n",path);*/
+
+  if (strstr (path, ":"))
+    spath = strtok (path, ":");
+  else
+    spath = path;
+
+  while (spath)
+  {
+    sprintf (globstring, "%s/%s", spath, bin);
+/*	 printf("checking for %s...\n",globstring);*/
+    if (glob (globstring, GLOB_ERR, NULL, &dirlist) == 0)
+    {
+      /*       printf("found at %s\n",globstring); */
+      free (globstring);
+      globfree (&dirlist);
+      free (path);
+      return TRUE;
+    }
+    globfree (&dirlist);
+    spath = strtok (NULL, ":");
+  }
+  free (globstring);
+  free(path);
+  return FALSE;
+}
+
+
