@@ -72,6 +72,7 @@
 #include "xtree_toolbar.h"
 #include "xtree_functions.h"
 #include "xtree_icons.h"
+#include "xtree_cpy.h"
 #include "tubo.h"
 
 #ifdef HAVE_GDK_PIXBUF
@@ -160,7 +161,7 @@ GtkCTreeNode *add_tar_dummy(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en)
    en->label=g_strdup(".");
    en->path=g_strdup("tar:.");
    memcpy((void *)(&(en->st)),(void *)(&(p_en->st)),sizeof(struct stat));
-   set_icon_pix(&pix,en->type,en->label);   
+   set_icon_pix(&pix,en->type,en->label,en->flags);   
    item=gtk_ctree_insert_node (ctree,parent, NULL, text, SPACING, 
 		  pix.pixmap,pix.pixmask,
 		  pix.open,pix.openmask,
@@ -168,7 +169,77 @@ GtkCTreeNode *add_tar_dummy(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en)
    gtk_ctree_node_set_row_data_full (ctree,item,en,node_destroy);
    return (item);   
 }
+#if 10
+/* preliminary bug fix for non gnu generated tar file expansion */
+static  GtkCTreeNode *parent_node(GtkCTree * ctree,char *path,GtkCTreeNode *top_level,int type,char *tarfile){
+	GtkCTreeNode *Tnode,*s_item;
+	char *c,*d,*N_path;
+	entry *d_en;
+	gchar *text[COLUMNS];
+        icon_pix pix;  
+	
+	/*fprintf(stderr,"dbg: looking for %s\n",path);*/
+	if (!strchr(path,'/') && !strchr(path,'\\')) return NULL;
+	text[COL_DATE]=text[COL_SIZE]=text[COL_MODE]=text[COL_UID]=text[COL_GID]="";
+	Tnode=find_tar_dir(path);
+	if (!Tnode) {
+ 	  /*fprintf(stderr,"dbg: %s not found\n",path);*/
+	  if ((d_en = entry_new ())==NULL){
+		fprintf(stderr,"xftree: cannot continue xtree_tar.c\n");
+                cleanup_tmpfiles();
+		exit(1);
+	  }
+	  d_en->type =  FT_TARCHILD|FT_DIR;
+	  d_en->path=(char *)malloc(strlen(path)+strlen(tarfile)+strlen("tar:")+3);
+	  if (!d_en->path) {
+		  fprintf(stderr,"xftree:error 3342\n");
+		  return NULL;
+	  }
+	  sprintf(d_en->path,"tar:%s:%s",tarfile,path);
+	  /* buggy: d_en->path=g_strdup(path);*/
+	  c=g_strdup(path);
+	  
+	  
+	  if (strstr(c,"/")) {d=strrchr(c,'/');*d=0;}
+	  else if (strstr(c,"\\")) {d=strrchr(c,'\\');*d=0;}
+	  
+	  if (strstr(c,"/")) d=strrchr(c,'/')+1;
+	  else if (strstr(c,"\\")) d=strrchr(c,'\\')+1;
+	  else d=NULL;
+	  if (d) d_en->label=g_strdup(d);
+	  else d_en->label=g_strdup(path); 
+	  g_free(c);
+	  text[COL_NAME] = d_en->label;
+	  set_icon_pix(&pix,FT_TARCHILD|FT_DIR|type,path,IGNORE_HIDDEN);
+  
+	  N_path=g_strdup(path);
+	  if (strstr(N_path,"/")) c=strrchr(N_path,'/');else c=strrchr(N_path,'\\');
+	  if (c) *c=0;
+  	  if ((strlen(N_path))&&(strstr(N_path,"/")||strstr(N_path,"\\"))){  
+		if (strstr(N_path,"/")) c=strrchr(N_path,'/');
+		else c=strrchr(N_path,'\\');
+		c[1]=0;
 
+		if (!Tnode) Tnode=parent_node(ctree,N_path,top_level,type,tarfile);
+	  } else Tnode=top_level;
+ 	  
+	  /*fprintf(stderr,"dbg:inserting %s \n",path);*/
+	  s_item=gtk_ctree_insert_node (ctree,Tnode, NULL, text, SPACING, 
+		pix.pixmap,pix.pixmask,pix.open,pix.openmask,
+		FALSE,FALSE);
+	  if (s_item) {
+	        headTar=push_tar_dir(s_item,path);
+	        gtk_ctree_node_set_row_data_full (ctree, s_item, d_en, node_destroy);
+	        /*fprintf(stderr,"subitem inserted\n");*/
+		return s_item;
+	  }
+	  
+          g_free(N_path);
+	} 
+	/*else fprintf(stderr,"dbg: %s present!\n",path);*/
+	return Tnode;
+}
+#endif
 GtkCTreeNode *add_tar_tree(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en){
       GtkCTreeNode *s_item=NULL,*p_node;
       entry *d_en;
@@ -176,6 +247,7 @@ GtkCTreeNode *add_tar_tree(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en){
       char *cmd;
       gchar *text[COLUMNS],date[32],size[32],mode[12],uid[32],gid[32];
       cfg *win;
+      gboolean nopipe=TRUE;
 
       win = gtk_object_get_user_data (GTK_OBJECT (ctree));
       text[COL_DATE]=date;
@@ -186,12 +258,13 @@ GtkCTreeNode *add_tar_tree(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en){
 
       cmd=(char *)malloc(strlen("tar -vtzZf --use-compress-program bunzip2 ")+strlen(p_en->path)+1);
       if (!cmd) return NULL;
-      if (p_en->type & FT_GZ) sprintf (cmd, "tar -vtzf %s", p_en->path);
-      else if (p_en->type & FT_COMPRESS ) sprintf (cmd, "tar -vtZf %s", p_en->path);
-      else if (p_en->type & FT_BZ2 ) sprintf (cmd, "tar --use-compress-program bunzip2 -vtf %s", p_en->path);
-      else sprintf (cmd, "tar -vtf %s", p_en->path);
+      if (p_en->type & FT_GZ) sprintf (cmd, "tar -vtzf \"%s\"", p_en->path);
+      else if (p_en->type & FT_COMPRESS ) sprintf (cmd, "tar -vtZf \"%s\"", p_en->path);
+      else if (p_en->type & FT_BZ2 ) sprintf (cmd, "tar --use-compress-program bunzip2 -vtf \"%s\"", p_en->path);
+      else sprintf (cmd, "tar -vtf \"%s\"", p_en->path);
       /*printf("dbg:%s\n",cmd);*/
       pipe = popen (cmd, "r");
+      g_free(cmd);
       if (pipe) {
               icon_pix pix;  
 	      char *p,*d,*u;
@@ -201,6 +274,7 @@ GtkCTreeNode *add_tar_tree(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en){
 			      pclose (pipe);
 			      return NULL;
 		      }
+		      nopipe=FALSE;
 		      d_en->type =  FT_TARCHILD;
 		      /*fprintf(stderr,"dbg:%s",line);*/
 		      /* mode */
@@ -232,7 +306,17 @@ GtkCTreeNode *add_tar_tree(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en){
 		      /* uid/gid */
 		      u=strtok(NULL," ");
 		      /* size */
-		      strcpy(text[COL_SIZE],strtok(NULL," "));
+ 		      {
+			char *tag="  ";
+			unsigned long long tama;
+			tama =  atol(strtok(NULL," "));
+			if (tama >= (long long)1024*1024*1024*10){
+				tama /= (long long)1024*1024*1024; tag=" GB";
+			}
+		  	else if (tama >= 1024*1024*10) {tama /= 1024*1024; tag=" MB";}
+		  	else if (tama >= 1024*10) {tama /= 1024; tag=" KB";}
+		  	sprintf (text[COL_SIZE], " %llu%s", tama,tag);
+		      }
 		      /* date */
 		      strcpy(text[COL_DATE],strtok(NULL," "));
 		      strcat(text[COL_DATE]," ");
@@ -246,16 +330,16 @@ GtkCTreeNode *add_tar_tree(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en){
 			      pclose (pipe);
 			      return NULL;
 		      }
-		      sprintf(d_en->path,"tar:%s:%s",p_en->path,p);
+		      /*sprintf(d_en->path,"tar:%s:%s",p_en->path,p); //double colon format */
+		      sprintf(d_en->path,"tar:%s/%s",p_en->path,p);
 		      /* use either / or \ */
-		      d=strrchr(d_en->path,':')+1;
+		      /*d=strrchr(d_en->path,':')+1;*/
+		      d=p;
 		      if ((!(d_en->type &  FT_DIR))&&(strstr(d,"/")||strstr(d,"\\"))){
 			      if (strstr(d,"/")) d=strrchr(d_en->path,'/')+1;
 			      else if (strstr(d,"\\")) d=strrchr(d_en->path,'\\')+1;
 		      } 				   
 		      d_en->label=g_strdup (d);
-		      if ((d_en->type &  FT_DIR)&&(strlen(d_en->label)>1)) 
-			      d_en->label[strlen(d_en->label)-1]=0;
 		      
 		      if (win->preferences&ABREVIATE_PATHS) 
 			      text[COL_NAME] = (d_en->type &  FT_DIR)?
@@ -269,39 +353,52 @@ GtkCTreeNode *add_tar_tree(GtkCTree * ctree, GtkCTreeNode * parent,entry *p_en){
 		      {
 			      char *P_path,*d=NULL;
 			      P_path=g_strdup (p);
-			      if (d_en->type &  FT_DIR) {
-			         if (P_path[strlen(P_path)-1]=='/') P_path[strlen(P_path)-1]=0;
-				 else if (P_path[strlen(P_path)-1]=='\\') P_path[strlen(P_path)-1]=0;
-			      }
 			      if (strstr(P_path,"/")) d=strrchr(P_path,'/');
 			      else if (strstr(P_path,"\\")) d=strrchr(P_path,'\\');
 			      if (d) d[1]=0;
-			      if (d_en->type &  FT_DIR){
-			      }
-			      p_node=find_tar_dir(P_path);
-			      if (!p_node) p_node=parent;
+			      /* non gnu tar generated view fix, preliminary */
+			      p_node=parent_node(ctree,P_path,parent,
+					      p_en->type&(FT_COMPRESS|FT_BZ2|FT_GZ),p_en->path);
+			      if (!p_node) p_node=parent; /* error fallback */
 			      g_free(P_path);
 			      
 		      }
-	      	      set_icon_pix(&pix,d_en->type,d_en->label);
-		      s_item=gtk_ctree_insert_node (ctree,p_node, NULL, text, SPACING, 
+		      if (!(d_en->type &  FT_DIR)) {
+	      	        set_icon_pix(&pix,d_en->type,d_en->label,d_en->flags);
+		        s_item=gtk_ctree_insert_node (ctree,p_node, NULL, text, SPACING, 
 		  		pix.pixmap,pix.pixmask,pix.open,pix.openmask,
 				(d_en->type &  FT_DIR)?FALSE:TRUE,FALSE);
-		      if (s_item) {
+		        if (s_item) {
 		          if (d_en->type &  FT_DIR) headTar=push_tar_dir(s_item,p);
 		          gtk_ctree_node_set_row_data_full (ctree, s_item, d_en, node_destroy);
 			  /*fprintf(stderr,"subitem inserted\n");*/
+		        }
 		      }
 	      }
 	      pclose (pipe);
       }
+      if (nopipe) {
+         icon_pix pix;  
+	 set_icon_pix(&pix,FT_PD," ",IGNORE_HIDDEN);
+	 if ((d_en = entry_new ())==NULL) return NULL;
+	 d_en->type =  FT_RPM|FT_RPMCHILD;
+	 d_en->path=d_en->label=NULL;
+	 text[COL_DATE]=text[COL_SIZE]=text[COL_MODE]=text[COL_UID]=text[COL_GID]="";
+	 text[COL_NAME] = _("tar: execution error");
+	 /* use open pixmaps for error situation */
+	 s_item=gtk_ctree_insert_node (ctree,parent, NULL, text, SPACING, 
+	  		pix.open,pix.openmask,NULL,NULL,TRUE,FALSE);
+	 if (s_item) {
+		 gtk_ctree_node_set_row_data_full (ctree, s_item, d_en, node_destroy);
+	 }
+      }
       /*fprintf(stderr,"dbg:done inserting tar stuff\n");*/
-      free(cmd);
       headTar=clean_tar_dir();
       gtk_ctree_sort_node (ctree, parent);
       return s_item;
 }
 
+
 #define TAR_CMD_LEN 1024
 static char tar_cmd[TAR_CMD_LEN];
 static char tar_tgt[TAR_CMD_LEN];
@@ -377,7 +474,7 @@ static int rwStdout (int n, void *data){
 }
 
 /* function called when child is dead */
-static void rwForkOver (void)
+static void rwForkOver (pid_t pid)
 {
   if (tar_cmd_error) {
     /*fprintf(stderr,"dbg fork is over with error\n");*/
@@ -394,6 +491,17 @@ static void rwForkOver (void)
 	  tar_output=0;
   }
   tar_fork_obj=NULL;
+  update_timer (tar_ctree);
+}
+/* function called when child is dead */
+static void rwForkOverE (pid_t pid)
+{
+  if (tar_output) {
+	  close(tar_output);
+	  tar_output=0;
+  }
+  tar_fork_obj=NULL;
+  update_timer (tar_ctree);
 }
 
 
@@ -415,13 +523,75 @@ static int inner_tar_delete(GtkCTree *ctree,char *path){
 	win = gtk_object_get_user_data (GTK_OBJECT (ctree));
 	check.path=g_strdup(path);
 	tar_node=gtk_ctree_find_by_row_data_custom (ctree, 
-			GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list), 
+			find_root((GtkCTree *)ctree), 
 			&check, compare_node_path);
 
 	if (strncmp(check.path,"tar:",strlen("tar:"))!=0) {errno=EFAULT;return -1;}
+	if (strchr(strchr(check.path,':')+1,':')) {
+	 /* double colon format, not standard */
 	strtok(check.path,":");
 	tar_file=strtok(NULL,":"); if (!tar_file){errno=EFAULT;return -1;}
 	tar_entry=strtok(NULL,"\n"); if (!tar_entry){errno=EFAULT;return -1;}
+	} else {
+	  char *p,*g;
+	  struct stat s;
+	  p=g_strdup(strchr(check.path,':')+1);
+	  while (stat(p,&s)<0){
+		  g=strrchr(p,'/');
+		  if (!g){
+			  fprintf(stderr,"xftree: error 989-2\n");/* should not happen */
+			  errno=EFAULT;
+			  return -1;
+		  }
+		  *g=0;
+	  }
+	  tar_file=strchr(check.path,':')+1;
+	  tar_file[strlen(p)]=0;
+	  tar_entry=tar_file+strlen(p)+1;
+	  g_free(p);
+	}
+
+	
+	if (strchr(strchr(check.path,':')+1,':')) {
+	 /* double colon format, not standard */
+	 tar_entry=strrchr(check.path,':');
+	 if (!tar_entry) return FALSE;
+	 *tar_entry='+';	
+	 tar_file=strrchr(check.path,':');
+	 if (!tar_file) return FALSE;
+	 tar_file++;
+	 *tar_entry=0;
+	 tar_entry++;
+	} else {
+	  char *p,*g;
+	  struct stat s;
+	  p=g_strdup(strchr(check.path,':')+1);
+	  while (stat(p,&s)<0){
+		  g=strrchr(p,'/');
+		  if (!g){
+			  fprintf(stderr,"xftree: error 989-1\n");/* should not happen */
+			  return FALSE;
+		  }
+		  *g=0;
+	  }
+	  tar_file=strchr(check.path,':')+1;
+	  tar_file[strlen(p)]=0;
+	  tar_entry=tar_file+strlen(p)+1;
+	  g_free(p);
+	}
+	/* avoid directories with spaces */
+	{
+	  char *ddir;
+	  ddir=tar_file;
+	  tar_file=strrchr(tar_file,'/')+1;
+	  *(strrchr(ddir,'/'))=0;
+	  chdir(ddir);
+	}
+	
+	
+/*	strtok(check.path,":");
+	tar_file=strtok(NULL,":"); if (!tar_file){errno=EFAULT;return -1;}
+	tar_entry=strtok(NULL,"\n"); if (!tar_entry){errno=EFAULT;return -1;}*/
 	if (strlen("tar -zZ --use-compress-program bunzip2 --delete  -f ")+strlen(tar_file)+1+strlen(tar_entry)+1 >TAR_CMD_LEN){
 		errno=EIO;return -1;
 	}
@@ -462,13 +632,18 @@ int tar_delete(GtkCTree *ctree,char *path){
 	return 0;
 }
 
-int tar_extract(GtkCTree *ctree,char *tgt,char *src){
+int tar_extract(GtkCTree *ctree,char *tgt,char *o_src){
 	char *tar_file,*tar_entry,*loc;
+	static char *src=NULL;
 	entry *en;
 	cfg *win;
 	entry check;
 	mode_t mode=S_IRUSR|S_IWUSR|S_IRGRP;
 
+	if (src) g_free(src);
+	src=g_strdup(o_src);
+	if (!src) return FALSE;
+	
 	tar_ctree=ctree;
 	
 	while (tar_fork_obj){
@@ -477,30 +652,57 @@ int tar_extract(GtkCTree *ctree,char *tgt,char *src){
 	}
 	if (src[strlen(src)-1]=='\n') src[strlen(src)-1]=0;
 	if (src[strlen(src)-1]=='\r') src[strlen(src)-1]=0;
-	/*fprintf(stderr,"tgt=%s\n",tgt);*/
-	/*fprintf(stderr,"src=%s\n",src);*/
+	/*fprintf(stderr,"tgt=%s\n",tgt);
+	fprintf(stderr,"src=%s\n",src);*/
 
 	win = gtk_object_get_user_data (GTK_OBJECT (ctree));
 /* FIXME: mode setting dont always work because the search might be done in the wrong xftree window. 
- *        this is not the case with a "delete" command, from where the code was taken */
+ *        this is not the case with a "delete" command */
 	check.path=g_strdup(src);
 	tar_node=gtk_ctree_find_by_row_data_custom (ctree, 
-			GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list), 
+			find_root((GtkCTree *)ctree), 
 			&check, compare_node_path);
         en = gtk_ctree_node_get_row_data (GTK_CTREE (tar_ctree), tar_node);
-	if (en) mode= en->st.st_mode;
-	/*
-	if (!en) fprintf(stderr,"dbg:entry not found\n");
+	if (en && (en->st.st_mode)) mode= en->st.st_mode;
+	
+	/*if (!en) fprintf(stderr,"dbg:entry not found\n");
 	else fprintf(stderr,"dbg:mode=0%o\n",en->st.st_mode);*/
 
-	tar_entry=strrchr(src,':');
-	if (!tar_entry) return FALSE;
-	*tar_entry='+';	
-	tar_file=strrchr(src,':');
-	if (!tar_file) return FALSE;
-	tar_file++;
-	*tar_entry=0;
-	tar_entry++;
+	if (strchr(strchr(src,':')+1,':')) {
+	 /* double colon format, not standard */
+	 tar_entry=strrchr(src,':');
+	 if (!tar_entry) return FALSE;
+	 *tar_entry='+';	
+	 tar_file=strrchr(src,':');
+	 if (!tar_file) return FALSE;
+	 tar_file++;
+	 *tar_entry=0;
+	 tar_entry++;
+	} else {
+	  char *p,*g;
+	  struct stat s;
+	  p=g_strdup(strchr(src,':')+1);
+	  while (stat(p,&s)<0){
+		  g=strrchr(p,'/');
+		  if (!g){
+			  fprintf(stderr,"xftree: error 989-1\n");/* should not happen */
+			  return FALSE;
+		  }
+		  *g=0;
+	  }
+	  tar_file=strchr(src,':')+1;
+	  tar_file[strlen(p)]=0;
+	  tar_entry=tar_file+strlen(p)+1;
+	  g_free(p);
+	}
+	/* avoid directories with spaces */
+	{
+	  char *ddir;
+	  ddir=tar_file;
+	  tar_file=strrchr(tar_file,'/')+1;
+	  *(strrchr(ddir,'/'))=0;
+	  chdir(ddir);
+	}
 	
 	if (strlen("tar --use-compress-program bunzip2 -OZ -f %% -x %%")+strlen(tar_file)+1+strlen(tar_entry)+1 >TAR_CMD_LEN){
 		errno=EIO;return 0;
@@ -526,10 +728,40 @@ int tar_extract(GtkCTree *ctree,char *tgt,char *src){
 		  return FALSE;
 	}	  
 	strcpy(tar_tgt,tgt);	  
-	tar_fork_obj=Tubo (tubo_cmdE, rwForkOver, 0, rwStdout, rwStderr);
+	tar_fork_obj=Tubo (tubo_cmdE, rwForkOverE, 0, rwStdout, rwStderr);
 	usleep(50000);
         return TRUE;
 }
 
+static char *tar_open_with(GtkCTree *ctree,char *src,char *loc){
+   char *tgt;
+   tgt=randomTmpName(loc);
+   if (!tar_extract(ctree,tgt,src)) return NULL;
+   return tgt;  
+}
+
+void cb_tar_open_with (GtkWidget * item, GtkCTree * ctree)
+{
+  entry *en;
+  cfg *win;
+  GtkCTreeNode *node;
+  char *prg,*tgt;
+
+  win = gtk_object_get_user_data (GTK_OBJECT (ctree));
+  if (!count_selection (ctree, &node))
+  {
+    xf_dlg_warning (win->top,_("No files marked !"));
+    return;
+  }
+  en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
+  prg = reg_app_by_file (win->reg, en->path);
+  
+  tgt=tar_open_with(ctree,en->path,en->label);
+  if (!tgt) fprintf(stderr,"Could not extract %s\n",en->path);
+  else xf_dlg_open_with ((GtkWidget *)ctree,win->xap, prg ? prg : DEF_APP, tgt);
+}
+
+
+
 
 
