@@ -96,7 +96,7 @@ Animate (int o_x, int o_y, int o_w, int o_h, int f_x, int f_y, int f_w, int f_h)
 
   if (Scr.Options & AnimateWin)
   {
-    gcv.line_width = 3;
+    gcv.line_width = 2;
 
     XChangeGC (dpy, Scr.DrawGC, GCLineWidth, &gcv);
 
@@ -1633,6 +1633,7 @@ SetMenuFont (XEvent * eventp, Window w, XfwmWindow * tmp_win, unsigned long cont
     free (font);
     return;
   }
+  
   if (Scr.StdFont.fontset)
   {				/* Temporarily, set FontStruct for calculating. */
     XFontStruct **fs_list = NULL;
@@ -1739,7 +1740,7 @@ LoadIconFont (XEvent * eventp, Window w, XfwmWindow * tmp_win, unsigned long con
     fprintf (stderr, "[LoadIconFont]: Error -- Couldn't load NULL font\n");
     return;
   }
-  if (Scr.StdFont.font)
+  if (Scr.IconFont.font)
   {
     XFreeFont (dpy, Scr.IconFont.font);
     Scr.IconFont.font = NULL;
@@ -1768,6 +1769,7 @@ LoadIconFont (XEvent * eventp, Window w, XfwmWindow * tmp_win, unsigned long con
     free (font);
     return;
   }
+  
   if (Scr.IconFont.fontset)
   {				/* Temporarily, set FontStruct for calculating. */
     XFontStruct **fs_list = NULL;
@@ -1779,7 +1781,6 @@ LoadIconFont (XEvent * eventp, Window w, XfwmWindow * tmp_win, unsigned long con
       if (Scr.IconFont.font->ascent < fs_list[i]->ascent)
 	Scr.IconFont.font->ascent = fs_list[i]->ascent;
   }
-
 #ifdef HAVE_X11_XFT_XFT_H
   else if ((enable_xft) && (Scr.IconFont.xftfont))
   {
@@ -1854,7 +1855,6 @@ LoadWindowFont (XEvent * eventp, Window win, XfwmWindow * tmp_win, unsigned long
     return;
   }
 
-
   if (fl->WindowFont.fontset)
   {				/* Temporarily, set FontStruct for calculating. */
     XFontStruct **fs_list = NULL;
@@ -1944,7 +1944,7 @@ FreeButtonFace (Display * dpy, ButtonFace * bf)
       bf->u.ReliefGC = (GC) NULL;
     }
     break;
-  case VectorButton:
+  case PixButton:
     if (bf->bitmap != None)
     {
       XFreePixmap (dpy, bf->bitmap);
