@@ -61,6 +61,187 @@ char *black = "black";
 extern char *Hiback;
 extern char *Hifore;
 
+static void
+rgb_to_hls (double *r,
+            double *g,
+            double *b)
+{
+  double min;
+  double max;
+  double red;
+  double green;
+  double blue;
+  double h, l, s;
+  double delta;
+  
+  red = *r;
+  green = *g;
+  blue = *b;
+  
+  if (red > green)
+    {
+      if (red > blue)
+        max = red;
+      else
+        max = blue;
+      
+      if (green < blue)
+        min = green;
+      else
+        min = blue;
+    }
+  else
+    {
+      if (green > blue)
+        max = green;
+      else
+        max = blue;
+      
+      if (red < blue)
+        min = red;
+      else
+        min = blue;
+    }
+  
+  l = (max + min) / 2;
+  s = 0;
+  h = 0;
+  
+  if (max != min)
+    {
+      if (l <= 0.5)
+        s = (max - min) / (max + min);
+      else
+        s = (max - min) / (2 - max - min);
+      
+      delta = max -min;
+      if (red == max)
+        h = (green - blue) / delta;
+      else if (green == max)
+        h = 2 + (blue - red) / delta;
+      else if (blue == max)
+        h = 4 + (red - green) / delta;
+      
+      h *= 60;
+      if (h < 0.0)
+        h += 360;
+    }
+  
+  *r = h;
+  *g = l;
+  *b = s;
+}
+
+static void
+hls_to_rgb (double *h,
+            double *l,
+            double *s)
+{
+  double hue;
+  double lightness;
+  double saturation;
+  double m1, m2;
+  double r, g, b;
+  
+  lightness = *l;
+  saturation = *s;
+  
+  if (lightness <= 0.5)
+    m2 = lightness * (1 + saturation);
+  else
+    m2 = lightness + saturation - lightness * saturation;
+  m1 = 2 * lightness - m2;
+  
+  if (saturation == 0)
+    {
+      *h = lightness;
+      *l = lightness;
+      *s = lightness;
+    }
+  else
+    {
+      hue = *h + 120;
+      while (hue > 360)
+        hue -= 360;
+      while (hue < 0)
+        hue += 360;
+      
+      if (hue < 60)
+        r = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+        r = m2;
+      else if (hue < 240)
+        r = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+        r = m1;
+      
+      hue = *h;
+      while (hue > 360)
+        hue -= 360;
+      while (hue < 0)
+        hue += 360;
+      
+      if (hue < 60)
+        g = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+        g = m2;
+      else if (hue < 240)
+        g = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+        g = m1;
+      
+      hue = *h - 120;
+      while (hue > 360)
+        hue -= 360;
+      while (hue < 0)
+        hue += 360;
+      
+      if (hue < 60)
+        b = m1 + (m2 - m1) * hue / 60;
+      else if (hue < 180)
+        b = m2;
+      else if (hue < 240)
+        b = m1 + (m2 - m1) * (240 - hue) / 60;
+      else
+        b = m1;
+      
+      *h = r;
+      *l = g;
+      *s = b;
+    }
+}
+
+void color_shade (unsigned short *r, unsigned short *g, unsigned short *b, double   k)
+{
+  double red;
+  double green;
+  double blue;
+  
+  red   = (double) *r / 65535.0;
+  green = (double) *g / 65535.0;
+  blue  = (double) *b / 65535.0;
+  
+  rgb_to_hls (&red, &green, &blue);
+  
+  green *= k;
+  if (green > 1.0)
+    green = 1.0;
+  else if (green < 0.0)
+    green = 0.0;
+  
+  blue *= k;
+  if (blue > 1.0)
+    blue = 1.0;
+  else if (blue < 0.0)
+    blue = 0.0;
+  
+  hls_to_rgb (&red, &green, &blue);
+  
+  *r = red   * 65535.0;
+  *g = green * 65535.0;
+  *b = blue  * 65535.0;
+}
+
 /****************************************************************************
  *
  * This routine computes the shadow color from the background color
@@ -76,10 +257,8 @@ Pixel GetShadow (Pixel background)
   bg_color.pixel = background;
   XQueryColor (dpy, attributes.colormap, &bg_color);
 
-  bg_color.red = shift16 (bg_color.red, LO_MULT);
-  bg_color.green = shift16 (bg_color.green, LO_MULT);
-  bg_color.blue = shift16 (bg_color.blue, LO_MULT);
-
+  color_shade (&(bg_color.red), &(bg_color.green), &(bg_color.blue), LO_MULT );
+  
   if (!XAllocColor (dpy, attributes.colormap, &bg_color))
   {
     nocolor ("alloc shadow", "");
@@ -104,9 +283,7 @@ Pixel GetHilite (Pixel background)
   bg_color.pixel = background;
   XQueryColor (dpy, attributes.colormap, &bg_color);
 
-  bg_color.red = shift16 (bg_color.red, HI_MULT);
-  bg_color.green = shift16 (bg_color.green, HI_MULT);
-  bg_color.blue = shift16 (bg_color.blue, HI_MULT);
+  color_shade (&(bg_color.red), &(bg_color.green), &(bg_color.blue), HI_MULT );
 
   if (!XAllocColor (dpy, attributes.colormap, &bg_color))
   {
