@@ -1,7 +1,22 @@
-
+/*  gxfce
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+*/
 
 /****************************************************************************
- * This module is all original code 
+ * This module is from original code 
  * by Rob Nation 
  * Copyright 1993, Robert Nation
  *     You may use this code for any purpose, as long as the original
@@ -16,11 +31,17 @@
 
 #include "configure.h"
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdio.h>
 #include <signal.h>
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
 
 #include "xfwm.h"
 #include "menus.h"
@@ -52,7 +73,6 @@ static struct functions func_config[] = {
   {"AutoRaise", SetAutoRaise, F_AUTORAISE, FUNC_NO_WINDOW},
   {"AutoRaiseDelay", SetAutoRaiseDelay, F_AUTORAISEDELAY, FUNC_NO_WINDOW},
   {"Beep", Bell, F_BEEP, FUNC_NO_WINDOW},
-  {"BitmapButtons", use_bitmap_buttons, F_BITMAPBUTTONS, FUNC_NO_WINDOW},
   {"ClickRaise", SetClickRaise, F_SETCLICKRAISE, FUNC_NO_WINDOW},
   {"ClickTime", SetClick, F_CLICK, FUNC_NO_WINDOW},
   {"Close", close_function, F_CLOSE, FUNC_NEEDS_WINDOW},
@@ -67,6 +87,7 @@ static struct functions func_config[] = {
   {"DestroyMenu", destroy_menu, F_DESTROY_MENU, FUNC_NO_WINDOW},
   {"DestroyModuleConfig", DestroyModConfig, F_DESTROY_MOD, FUNC_NO_WINDOW},
   {"Echo", echo_func, F_ECHO, FUNC_NO_WINDOW},
+  {"Engine", engine_func, F_ENGINE, FUNC_NO_WINDOW},
   {"Exec", exec_function, F_EXEC, FUNC_NO_WINDOW},
   {"ExecUseSHELL", exec_setup, F_EXEC_SETUP, FUNC_NO_WINDOW},
   {"FlipFocus", flip_focus_func, F_FLIP_FOCUS, FUNC_NEEDS_WINDOW},
@@ -74,6 +95,7 @@ static struct functions func_config[] = {
   {"FocusMode", SetFocusMode, F_SETFOCUSMODE, FUNC_NO_WINDOW},
   {"ForceFocus", SetForceFocus, F_SETFORCEFOCUS, FUNC_NO_WINDOW},
   {"Function", ComplexFunction, F_FUNCTION, FUNC_NO_WINDOW},
+  {"HonorWMFocusHint", SetHonorWMFocusHint, F_SETHONORWMFOCUSHINT, FUNC_NO_WINDOW},
   {"IconFont", LoadIconFont, F_ICONFONT, FUNC_NO_WINDOW},
   {"IconGrid", SetIconGrid, F_ICONGRID, FUNC_NO_WINDOW},
   {"Iconify", iconify_function, F_ICONIFY, FUNC_NEEDS_WINDOW},
@@ -84,6 +106,8 @@ static struct functions func_config[] = {
   {"Key", ParseKeyEntry, F_KEY, FUNC_NO_WINDOW},
   {"KillModule", module_zapper, F_ZAP, FUNC_NO_WINDOW},
   {"Lower", lower_function, F_LOWER, FUNC_NEEDS_WINDOW},
+  {"MapFocus", SetMapFocus, F_SETMAPFOCUS, FUNC_NO_WINDOW},
+  {"Margin", SetMargin, F_MARGIN, FUNC_NO_WINDOW},
   {"Maximize", Maximize, F_MAXIMIZE, FUNC_NEEDS_WINDOW},
   {"Menu", staysup_func, F_STAYSUP, FUNC_POPUP},
   {"MenuColor", SetMenuColor, F_MENUCOLOR, FUNC_NO_WINDOW},
@@ -105,6 +129,7 @@ static struct functions func_config[] = {
   {"Raise", raise_function, F_RAISE, FUNC_NEEDS_WINDOW},
   {"RaiseLower", raiselower_func, F_RAISELOWER, FUNC_NEEDS_WINDOW},
   {"Read", ReadFile, F_READ, FUNC_NO_WINDOW},
+  {"ReadCfg", ReadCfg, F_READCFG, FUNC_NO_WINDOW},
   {"Recapture", Recapture, F_RECAPTURE, FUNC_NO_WINDOW},
   {"Refresh", refresh_function, F_REFRESH, FUNC_NO_WINDOW},
   {"RefreshWindow", refresh_win_function, F_REFRESH, FUNC_NEEDS_WINDOW},
@@ -121,8 +146,10 @@ static struct functions func_config[] = {
   {"SnapSize", SetSnapSize, F_SNAPSIZE, FUNC_NO_WINDOW},
   {"Stick", stick_function, F_STICK, FUNC_NEEDS_WINDOW},
   {"Style", ProcessNewStyle, F_STYLE, FUNC_NO_WINDOW},
+  {"Switch", SwitchFunc, F_SWITCHFUNC, FUNC_NO_WINDOW},
   {"Title", Nop_func, F_TITLE, FUNC_TITLE},
   {"TitleStyle", SetTitleStyle, F_TITLESTYLE, FUNC_NO_WINDOW},
+  {"UseShapedIcons", SetUseShapedIcons, F_SETUSESHAPEDICONS, FUNC_NO_WINDOW},
   {"Wait", wait_func, F_WAIT, FUNC_NO_WINDOW},
   {"WaitSession", wait_session, F_WAITSESSION, FUNC_NO_WINDOW},
   {"WarpToWindow", warp_func, F_WARP, FUNC_NEEDS_WINDOW},
@@ -151,8 +178,7 @@ static struct functions func_config[] = {
  ***********************************************************************/
 
 void
-ExecuteFunction (char *Action, XfwmWindow * tmp_win, XEvent * eventp,
-		 unsigned long context, int Module)
+ExecuteFunction (char *Action, XfwmWindow * tmp_win, XEvent * eventp, unsigned long context, int Module)
 {
   Window w;
   int matched, j;
@@ -170,36 +196,34 @@ ExecuteFunction (char *Action, XfwmWindow * tmp_win, XEvent * eventp,
 
   if ((tmp_win) && (eventp))
     w = eventp->xany.window;
-  if ((tmp_win) && (eventp->xbutton.subwindow != None) &&
-      (eventp->xany.window != tmp_win->w))
+  if ((tmp_win) && (eventp->xbutton.subwindow != None) && (eventp->xany.window != tmp_win->w))
     w = eventp->xbutton.subwindow;
 
   taction = expand (Action, arguments, tmp_win);
   action = GetNextToken (taction, &function);
   j = 0;
-  matched = FALSE;
+  matched = False;
 
   while ((!matched) && (strlen (func_config[j].keyword) > 0))
+  {
+    if (strcasecmp (function, func_config[j].keyword) == 0)
     {
-      if (strcasecmp (function, func_config[j].keyword) == 0)
-	{
-	  matched = TRUE;
-	  /* found key word */
-	  func_config[j].action (eventp, w, tmp_win, context, action,
-				 &Module);
-	}
-      else
-	j++;
+      matched = True;
+      /* found key word */
+      func_config[j].action (eventp, w, tmp_win, context, action, &Module);
     }
+    else
+      j++;
+  }
 
   if (!matched)
-    {
-      desperate = 1;
-      ComplexFunction (eventp, w, tmp_win, context, taction, &Module);
-      if (desperate)
-	executeModule (eventp, w, tmp_win, context, taction, &Module);
-      desperate = 0;
-    }
+  {
+    desperate = 1;
+    ComplexFunction (eventp, w, tmp_win, context, taction, &Module);
+    if (desperate)
+      executeModule (eventp, w, tmp_win, context, taction, &Module);
+    desperate = 0;
+  }
 
   /* Only wait for an all-buttons-up condition after calls from
    * regular built-ins, not from complex-functions or modules. */
@@ -222,20 +246,19 @@ find_func_type (char *action)
     ++endtok;
   len = endtok - action;
   j = 0;
-  matched = FALSE;
+  matched = False;
   while ((!matched) && (strlen (func_config[j].keyword) > 0))
+  {
+    int mlen = strlen (func_config[j].keyword);
+    if ((mlen == len) && (mystrncasecmp (action, func_config[j].keyword, mlen) == 0))
     {
-      int mlen = strlen (func_config[j].keyword);
-      if ((mlen == len)
-	  && (mystrncasecmp (action, func_config[j].keyword, mlen) == 0))
-	{
-	  matched = TRUE;
-	  /* found key word */
-	  return (int) func_config[j].code;
-	}
-      else
-	j++;
+      matched = True;
+      /* found key word */
+      return (int) func_config[j].code;
     }
+    else
+      j++;
+  }
   /* No clue what the function is. Just return "BEEP" */
   return F_BEEP;
 }
