@@ -1,5 +1,19 @@
-
-
+/*  gxfce
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+*/
 
 /****************************************************************************
  * This module was originally based on the twm module of the same name. 
@@ -87,11 +101,17 @@
 #define F_SESSIONMGT            64
 #define F_ICONGRID              65
 #define F_ICONSPACING           66
-#define F_BITMAPBUTTONS         67
+#define F_ENGINE                67
 #define F_SHOWBUTTONS	        68
 #define F_SETCLICKRAISE	        69
 #define F_SETFORCEFOCUS	        70
 #define F_SHOWMEMOUSE	        71
+#define F_SWITCHFUNC	        72
+#define F_SETMAPFOCUS	        73
+#define F_MARGIN	        74
+#define F_READCFG               75
+#define F_SETHONORWMFOCUSHINT   76
+#define F_SETUSESHAPEDICONS     77
 /* Functions which require a target window */
 #define F_RESIZE		100
 #define F_RAISE			101
