@@ -170,15 +170,6 @@ struct functions
 
 #define WindowsCaptured            (1L<<0)
 
-typedef enum
-{
-  VectorButton,
-  SimpleButton,
-  GradButton,
-  SolidButton
-}
-ButtonFaceStyle;
-
 typedef enum
 {
   XFCE_ENGINE,
@@ -189,6 +180,15 @@ typedef enum
 }
 EngineType;
 
+typedef enum
+{
+  PixButton,
+  SimpleButton,
+  GradButton,
+  SolidButton
+}
+ButtonFaceStyle;
+
 typedef struct ButtonFace
 {
   ButtonFaceStyle style;
