@@ -281,6 +281,9 @@ main (int argc, char **argv)
   Bool launch_xfce = True;
   char *temp_path = NULL;
   struct passwd *pwd;
+/* ??? patch 3.8.12c
+  int ruid, euid, suid;
+ ??? patch 3.8.12c */
 
 #if defined(HAVE_X11_EXTENSIONS_XINERAMA_H)
   int xinerama_major, xinerama_minor;
@@ -299,6 +302,11 @@ main (int argc, char **argv)
   g_argv = argv;
   g_argc = argc;
 
+/* ??? patch 3.8.12c
+  getresuid(&ruid, &euid, &suid);
+  fprintf(stderr, "%d %d %d\n", ruid, euid, suid);
+ ??? patch 3.8.12c */
+  
   temp_path = getenv ("SM_SAVE_DIR");
   if (!temp_path)
   {
@@ -827,12 +835,12 @@ SetRCDefaults ()
   char *defaults[] = {
     "XORValue 0",
     "ModulePath $PATH",
-    "ActiveColor white #CDCCCD",
-    "InactiveColor white #CDCCCD",
-    "TitleStyle Active Solid #409941",
-    "TitleStyle Inactive Solid #007EBE",
-    "MenuColor black #CDCCCD white #007EBE",
-    "CursorColor #FFFFFF black",
+    "ActiveColor white #DCDCDC",
+    "InactiveColor black #DCDCDC",
+    "TitleStyle Active Solid #0A5F89",
+    "TitleStyle Inactive Solid #C8C8C8",
+    "MenuColor black #DCDCDC black #F2F2F2",
+    "CursorColor #000000 #FFFFFF",
     "FocusMode Click",
     "AnimateWin Off",
     "OpaqueMove On",
@@ -846,7 +854,7 @@ SetRCDefaults ()
     "IconGrid 10",
     "IconSpacing 5",
     "IconPos Right",
-    "Style \"*\" Title, BorderWidth 6",
+    "Style \"*\" Title, BorderWidth 4",
     "Style \"XFce*\" Sticky",
     "Style \"XFbd*\" Sticky",
     "Style \"Popup*\" Sticky",
@@ -1326,7 +1334,7 @@ LoadDefaultLeftButton (ButtonFace * bf, int i)
 {
   bf->u.ShadowGC = (GC) NULL;
   bf->u.ReliefGC = (GC) NULL;
-  bf->style = VectorButton;
+  bf->style = PixButton;
   switch (i % 3)
   {
   case 0:
@@ -1441,7 +1449,7 @@ LoadDefaultRightButton (ButtonFace * bf, int i)
 {
   bf->u.ShadowGC = (GC) NULL;
   bf->u.ReliefGC = (GC) NULL;
-  bf->style = VectorButton;
+  bf->style = PixButton;
   switch (i % 3)
   {
   case 0:
@@ -1765,7 +1773,7 @@ InitVariables (void)
   Scr.Hilite = NULL;
   Scr.Focus = NULL;
   Scr.Options = (ClickToFocus | AnimateWin | ForceFocus | MapFocus | HonorWMFocusHint);
-  Scr.engine = XFCE_ENGINE;
+  Scr.engine = TRENCH_ENGINE;
   Scr.AutoRaiseDelay = 250;
   Scr.iconbox = 0;
   Scr.StdFont.font = NULL;
