@@ -1,3 +1,20 @@
+/*  gxfce
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+*/
+
 
 /****************************************************************************
  * This module is based on Twm, but has been siginificantly modified 
@@ -38,12 +55,19 @@
 #ifndef _XFWM_
 #define _XFWM_
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
+#include <X11/Intrinsic.h>
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include "utils.h"
+
+#ifdef HAVE_X11_XFT_XFT_H
+#  include <X11/Xft/Xft.h>
 #endif
 
 #ifndef WithdrawnState
@@ -52,8 +76,6 @@
 
 #define MAX_BUTTONS 5
 
-#include <X11/Intrinsic.h>
-
 #if RETSIGTYPE != void
 #define SIGNAL_RETURN return 0
 #else
@@ -64,12 +86,12 @@
 #define BOUNDARY_WIDTH 7	/* border width */
 #define CORNER_WIDTH 16		/* border width */
 
-#define HEIGHT_EXTRA 4		/* Extra height for texts in popus */
+#define HEIGHT_EXTRA 6		/* Extra height for texts in popus */
 #define HEIGHT_EXTRA_TITLE 4	/* Extra height for underlining title */
 #define HEIGHT_SEPARATOR 4	/* Height of separator lines */
 
 #define SCROLL_REGION 2		/* region around screen edge that */
-				/* triggers scrolling */
+/* triggers scrolling */
 
 #ifndef TRUE
 #define TRUE	1
@@ -89,49 +111,41 @@
 #define C_L1         (1<<7)
 #define C_L2         (1<<8)
 #define C_L3         (1<<9)
-#define C_L4         (1<<10)
-#define C_L5         (1<<11)
 #define C_R1         (1<<12)
 #define C_R2         (1<<13)
 #define C_R3         (1<<14)
-#define C_R4         (1<<15)
-#define C_R5         (1<<16)
-#define C_RALL       (C_R1|C_R2|C_R3|C_R4|C_R5)
-#define C_LALL       (C_L1|C_L2|C_L3|C_L4|C_L5)
+#define C_RALL       (C_R1|C_R2|C_R3)
+#define C_LALL       (C_L1|C_L2|C_L3)
 #define C_ALL   (C_WINDOW|C_TITLE|C_ICON|C_ROOT|C_FRAME|C_SIDEBAR|\
-                 C_L1|C_L2|C_L3|C_L4|C_L5|C_R1|C_R2|C_R3|C_R4|C_R5)
+                 C_L1|C_L2|C_L3|C_R1|C_R2|C_R3)
 
 #define XFWM_RUNNING 0		/* running */
 #define XFWM_HALT    1		/* Quit */
 #define XFWM_RESTART 2		/* Restart */
 #define XFWM_END     3		/* Session mgt terminating */
 
+/* This one is a GNOME hint */
+#define WIN_STATE_STICKY          (1L<<0)
+
 /* Define EMULATE_XINERAMA to emulate Xinerama on a systems without Xinerama
  * native support. For DEBUG purpose ONLY !
  */
 #undef EMULATE_XINERAMA
 
 #ifdef EMULATE_XINERAMA
-  #ifndef HAVE_X11_EXTENSIONS_XINERAMA_H
-    /* Define XineramaScreenInfo for systems missing Xinerama support */
-    typedef struct {
-       int   screen_number;
-       short x_org;
-       short y_org;
-       short width;
-       short height;
-    } XineramaScreenInfo;
-  #endif
-# endif
-
-typedef struct MyFont
+#ifndef HAVE_X11_EXTENSIONS_XINERAMA_H
+/* Define XineramaScreenInfo for systems missing Xinerama support */
+typedef struct
 {
-  XFontStruct *font;		/* font structure */
-  XFontSet fontset;		/* fontset for multi-language */
-  int height;			/* height of the font */
-  int y;			/* Y coordinate to draw characters */
+  int screen_number;
+  short x_org;
+  short y_org;
+  short width;
+  short height;
 }
-MyFont;
+XineramaScreenInfo;
+#endif
+# endif
 
 typedef struct ColorPair
 {
@@ -186,6 +200,7 @@ typedef struct XfwmWindow
   int shade_height;		/* height of the shaded window */
   Bool icon_arranged;		/* internal flag */
   Bool triggered;		/* internal flag */
+  Bool deleted;			/* internal flag */
   Pixmap iconPixmap;		/* pixmap for the icon */
   int iconDepth;		/* Drawable depth for the icon */
   Pixmap icon_maskPixmap;	/* pixmap for the icon mask */
@@ -219,72 +234,79 @@ typedef struct XfwmWindow
   Pixel TextPixel;
   Pixel BackPixel;
   unsigned long buttons;
+  int layer;
+  int gravx;			/* Gravity stuff */
+  int gravy;			/* Gravity stuff */
+  short grav_align_y;
 }
 XfwmWindow;
 
+typedef struct XfwmWindowList
+{
+  struct XfwmWindowList *next;	/* next in list */
+  struct XfwmWindowList *prev;	/* prev in list */
+  struct XfwmWindow *win;	/* xfwm window */
+}
+XfwmWindowList;
+
+typedef struct WindowList
+{
+  struct WindowList *next;	/* next in list */
+  Window w;			/* window */
+}
+WindowList;
+
 /***************************************************************************
  * window flags definitions 
  ***************************************************************************/
 
 /* Basic flags (field flags) */
-#define STARTICONIC             (1<<0)
-#define ONTOP                   (1<<1)	/* does window stay on top */
-#define STICKY                  (1<<2)	/* Does window stick to glass? */
-#define WINDOWLISTSKIP          (1<<3)
-#define SUPPRESSICON            (1<<4)
-#define NOICON_TITLE            (1<<5)
-#define Lenience                (1<<6)
-#define StickyIcon              (1<<7)
-#define CirculateSkipIcon       (1<<8)
-#define CirculateSkip           (1<<9)
-#define SHOW_ON_MAP             (1<<10)
-#define BORDER                  (1<<11)
-#define TITLE                   (1<<12)
-#define MAPPED                  (1<<13)
-#define ICONIFIED               (1<<14)
-#define TRANSIENT               (1<<15)
-#define RAISED                  (1<<16)
-#define VISIBLE                 (1<<17)
-#define ICON_OURS               (1<<18)
-#define PIXMAP_OURS             (1<<19)
-#define SHAPED_ICON             (1<<20)
-#define MAXIMIZED               (1<<21)
-#define DoesWmTakeFocus		(1<<22)
-#define DoesWmDeleteWindow	(1<<23)
-#define ICON_MOVED              (1<<24)
-#define ICON_UNMAPPED           (1<<25)
-#define MAP_PENDING             (1<<26)
-#define RAISEDWIN               (1<<27)	/* Used for autoraise facility */
-#define SHADED                  (1<<28)
-#define WM_NAME_CHANGED         (1<<29)
-#define RECAPTURE               (1<<30)
+#define STARTICONIC             (1L<<0)
+#define STICKY                  (1L<<1)	/* Does window stick to glass? */
+#define WINDOWLISTSKIP          (1L<<2)
+#define SUPPRESSICON            (1L<<3)
+#define StickyIcon              (1L<<4)
+#define CirculateSkipIcon       (1L<<5)
+#define CirculateSkip           (1L<<6)
+
+#define BORDER                  (1L<<7)
+#define TITLE                   (1L<<8)
+#define MAPPED                  (1L<<9)
+#define ICONIFIED               (1L<<10)
+#define TRANSIENT               (1L<<11)
+#define RAISED                  (1L<<12)
+#define VISIBLE                 (1L<<13)
+#define ICON_OURS               (1L<<14)
+#define PIXMAP_OURS             (1L<<15)
+#define SHAPED_ICON             (1L<<16)
+#define MAXIMIZED               (1L<<17)
+#define DoesWmTakeFocus		(1L<<18)
+#define DoesWmDeleteWindow	(1L<<19)
+#define ICON_MOVED              (1L<<20)
+#define ICON_UNMAPPED           (1L<<21)
+#define RAISEDWIN               (1L<<22)	/* Used for autoraise facility */
+#define SHADED                  (1L<<23)
+#define WM_NAME_CHANGED         (1L<<24)
+#define RECAPTURE               (1L<<25)
+#define MAP_PENDING             (1L<<26)
 
 
 /* options flags (apply to all windows) */
-#define ClickToFocus            (1<<0)
-#define AnimateWin              (1<<1)
-#define MoveOpaqueWin           (1<<2)
-#define AutoRaiseWin            (1<<3)
-#define ResizeOpaqueWin         (1<<4)
-#define SessionMgt              (1<<5)
-#define BitmapButtons           (1<<6)
-#define ForceFocus           	(1<<7)
-#define ClickRaise	        (1<<8)
+#define ClickToFocus            (1L<<0)
+#define AnimateWin              (1L<<1)
+#define MoveOpaqueWin           (1L<<2)
+#define AutoRaiseWin            (1L<<3)
+#define ResizeOpaqueWin         (1L<<4)
+#define SessionMgt              (1L<<5)
+#define ForceFocus           	(1L<<6)
+#define ClickRaise	        (1L<<7)
+#define MapFocus           	(1L<<8)
+#define HonorWMFocusHint        (1L<<9)
+#define UseShapedIcons		(1L<<10)
+#define ALL_COMMON_FLAGS (STARTICONIC|STICKY|WINDOWLISTSKIP| \
+			  StickyIcon|CirculateSkipIcon|CirculateSkip)
 
 
-#define ALL_COMMON_FLAGS (STARTICONIC|ONTOP|STICKY|WINDOWLISTSKIP| \
-			  SUPPRESSICON|NOICON_TITLE|Lenience|StickyIcon| \
-			  CirculateSkipIcon|CirculateSkip|SHOW_ON_MAP)
-
-
-/* flags to suppress/enable title bar buttons */
-#define BUTTON1     1
-#define BUTTON2     2
-#define BUTTON3     4
-#define BUTTON4     8
-#define BUTTON5    16
-#define BUTTON6    32
-
 #include <stdlib.h>
 extern void Reborder (void);
 extern RETSIGTYPE SigDone (int);
@@ -303,11 +325,7 @@ extern XContext XfwmContext;
 
 extern Window BlackoutWin;
 
-extern Boolean ShapesSupported;
-
-extern Window JunkRoot, JunkChild;
-extern int JunkX, JunkY;
-extern unsigned int JunkWidth, JunkHeight, JunkBW, JunkDepth, JunkMask;
+extern Bool ShapesSupported;
 
 extern Atom _XA_MIT_PRIORITY_COLORS;
 extern Atom _XA_WM_CHANGE_STATE;
@@ -335,10 +353,13 @@ extern Atom _XA_OL_DECOR_HEADER;
 extern Atom _XA_OL_DECOR_ICON_NAME;
 extern Atom _XA_WIN_WORKSPACE_COUNT;
 extern Atom _XA_WIN_WORKSPACE;
+extern Atom _XA_WIN_LAYER;
+extern Atom _XA_WIN_STATE;
 
 extern Atom _XA_WM_WINDOW_ROLE;
 extern Atom _XA_WM_CLIENT_LEADER;
 extern Atom _XA_SM_CLIENT_ID;
+extern Atom _WIN_DESKTOP_BUTTON_PROXY;
 
 extern unsigned int KeyMask;
 extern unsigned int ButtonMask;
